@@ -28,7 +28,12 @@ import org.kie.workbench.common.dmn.api.property.dmn.QName;
 @Portable
 public class FunctionDefinition extends Expression implements HasExpression {
 
-    public static final QName KIND_QNAME = new QName("{" + DMNModelInstrumentedBase.URI_KIE + "}kind");
+    public static final String DROOLS_PREFIX = "drools";
+
+    public static final String KIND_LOCAL_PART = "kind";
+
+    public static final QName KIND_QNAME = new QName(Namespace.KIE.getUri(),
+                                                     KIND_LOCAL_PART);
 
     private Expression expression;
 
@@ -65,6 +70,11 @@ public class FunctionDefinition extends Expression implements HasExpression {
         this.expression = expression;
     }
 
+    @Override
+    public DMNModelInstrumentedBase asDMNModelInstrumentedBase() {
+        return this;
+    }
+
     public List<InformationItem> getFormalParameter() {
         if (formalParameter == null) {
             formalParameter = new ArrayList<>();
