@@ -18,15 +18,18 @@ package org.kie.workbench.common.dmn.client.editors.expressions;
 import java.util.Optional;
 
 import javax.enterprise.context.Dependent;
+import javax.enterprise.event.Observes;
 import javax.inject.Inject;
 
 import org.jboss.errai.common.client.dom.HTMLElement;
 import org.kie.workbench.common.dmn.api.definition.HasExpression;
 import org.kie.workbench.common.dmn.api.definition.HasName;
+import org.kie.workbench.common.dmn.client.decision.DecisionNavigatorPresenter;
+import org.kie.workbench.common.dmn.client.widgets.toolbar.DMNEditorToolbar;
 import org.kie.workbench.common.stunner.client.widgets.presenters.session.SessionPresenter;
 import org.kie.workbench.common.stunner.client.widgets.toolbar.ToolbarCommand;
-import org.kie.workbench.common.stunner.client.widgets.toolbar.impl.EditorToolbar;
-import org.kie.workbench.common.stunner.core.client.session.impl.AbstractClientFullSession;
+import org.kie.workbench.common.stunner.core.client.canvas.event.selection.CanvasSelectionEvent;
+import org.kie.workbench.common.stunner.core.client.session.impl.EditorSession;
 import org.kie.workbench.common.stunner.core.diagram.Diagram;
 import org.uberfire.mvp.Command;
 
@@ -35,18 +38,22 @@ public class ExpressionEditor implements ExpressionEditorView.Presenter {
 
     private ExpressionEditorView view;
 
-    private Optional<Command> exitCommand;
+    private Optional<Command> exitCommand = Optional.empty();
 
     private ToolbarCommandStateHandler toolbarCommandStateHandler;
 
+    private DecisionNavigatorPresenter decisionNavigator;
+
     public ExpressionEditor() {
         //CDI proxy
     }
 
     @Inject
     @SuppressWarnings("unchecked")
-    public ExpressionEditor(final ExpressionEditorView view) {
+    public ExpressionEditor(final ExpressionEditorView view,
+                            final DecisionNavigatorPresenter decisionNavigator) {
         this.view = view;
+        this.decisionNavigator = decisionNavigator;
         this.view.init(this);
     }
 
@@ -61,8 +68,8 @@ public class ExpressionEditor implements ExpressionEditorView.Presenter {
     }
 
     @Override
-    public void init(final SessionPresenter<AbstractClientFullSession, ?, Diagram> presenter) {
-        this.toolbarCommandStateHandler = new ToolbarCommandStateHandler((EditorToolbar) presenter.getToolbar());
+    public void init(final SessionPresenter<EditorSession, ?, Diagram> presenter) {
+        this.toolbarCommandStateHandler = new ToolbarCommandStateHandler((DMNEditorToolbar) presenter.getToolbar());
     }
 
     @Override
@@ -83,12 +90,22 @@ public class ExpressionEditor implements ExpressionEditorView.Presenter {
 
     @Override
     public void exit() {
-        exitCommand.ifPresent(c -> {
+        exitCommand.ifPresent(command -> {
+            decisionNavigator.clearSelections();
             toolbarCommandStateHandler.exit();
-            c.execute();
+            command.execute();
+            exitCommand = Optional.empty();
         });
     }
 
+    public void onCanvasFocusedSelectionEvent(@Observes CanvasSelectionEvent event) {
+        exit();
+    }
+
+    Optional<Command> getExitCommand() {
+        return exitCommand;
+    }
+
     //Package-protected for Unit Tests
     ToolbarCommandStateHandler getToolbarCommandStateHandler() {
         return toolbarCommandStateHandler;
@@ -97,12 +114,11 @@ public class ExpressionEditor implements ExpressionEditorView.Presenter {
     @SuppressWarnings("unchecked")
     static class ToolbarCommandStateHandler {
 
-        private EditorToolbar toolbar;
+        private DMNEditorToolbar toolbar;
 
         //Package-protected for Unit Tests
         boolean visitGraphToolbarCommandEnabled = false;
         boolean clearToolbarCommandEnabled = false;
-        boolean clearStatesToolbarCommandEnabled = false;
         boolean deleteSelectionToolbarCommandEnabled = false;
         boolean switchGridToolbarCommandEnabled = false;
         boolean undoToolbarCommandEnabled = false;
@@ -114,33 +130,32 @@ public class ExpressionEditor implements ExpressionEditorView.Presenter {
         boolean copyCommandEnabled = false;
         boolean cutCommandEnabled = false;
         boolean pasteCommandEnabled = false;
+        boolean saveCommandEnabled = false;
 
-        private ToolbarCommandStateHandler(final EditorToolbar toolbar) {
+        private ToolbarCommandStateHandler(final DMNEditorToolbar toolbar) {
             this.toolbar = toolbar;
         }
 
         private void enter() {
             this.visitGraphToolbarCommandEnabled = toolbar.isEnabled((ToolbarCommand) toolbar.getVisitGraphToolbarCommand());
             this.clearToolbarCommandEnabled = toolbar.isEnabled((ToolbarCommand) toolbar.getClearToolbarCommand());
-            this.clearStatesToolbarCommandEnabled = toolbar.isEnabled((ToolbarCommand) toolbar.getClearStatesToolbarCommand());
             this.deleteSelectionToolbarCommandEnabled = toolbar.isEnabled((ToolbarCommand) toolbar.getDeleteSelectionToolbarCommand());
             this.switchGridToolbarCommandEnabled = toolbar.isEnabled((ToolbarCommand) toolbar.getSwitchGridToolbarCommand());
             this.undoToolbarCommandEnabled = toolbar.isEnabled((ToolbarCommand) toolbar.getUndoToolbarCommand());
             this.redoToolbarCommandEnabled = toolbar.isEnabled((ToolbarCommand) toolbar.getRedoToolbarCommand());
-            this.validateToolbarCommandEnabled = toolbar.isEnabled(toolbar.getValidateToolbarCommand());
+            this.validateToolbarCommandEnabled = toolbar.isEnabled(toolbar.getValidateCommand());
             this.exportToPngToolbarCommandEnabled = toolbar.isEnabled((ToolbarCommand) toolbar.getExportToPngToolbarCommand());
             this.exportToJpgToolbarCommandEnabled = toolbar.isEnabled((ToolbarCommand) toolbar.getExportToJpgToolbarCommand());
             this.exportToPdfToolbarCommandEnabled = toolbar.isEnabled((ToolbarCommand) toolbar.getExportToPdfToolbarCommand());
             this.copyCommandEnabled = toolbar.isEnabled((ToolbarCommand) toolbar.getCopyToolbarCommand());
             this.cutCommandEnabled = toolbar.isEnabled((ToolbarCommand) toolbar.getCutToolbarCommand());
             this.pasteCommandEnabled = toolbar.isEnabled((ToolbarCommand) toolbar.getPasteToolbarCommand());
+            this.saveCommandEnabled = toolbar.isEnabled((ToolbarCommand) toolbar.getSaveToolbarCommand());
 
             enableToolbarCommand(toolbar.getVisitGraphToolbarCommand(),
                                  false);
             enableToolbarCommand(toolbar.getClearToolbarCommand(),
                                  false);
-            enableToolbarCommand(toolbar.getClearStatesToolbarCommand(),
-                                 false);
             enableToolbarCommand(toolbar.getDeleteSelectionToolbarCommand(),
                                  false);
             enableToolbarCommand(toolbar.getSwitchGridToolbarCommand(),
@@ -149,7 +164,7 @@ public class ExpressionEditor implements ExpressionEditorView.Presenter {
                                  false);
             enableToolbarCommand(toolbar.getRedoToolbarCommand(),
                                  false);
-            enableToolbarCommand(toolbar.getValidateToolbarCommand(),
+            enableToolbarCommand(toolbar.getValidateCommand(),
                                  false);
             enableToolbarCommand(toolbar.getExportToPngToolbarCommand(),
                                  false);
@@ -163,6 +178,8 @@ public class ExpressionEditor implements ExpressionEditorView.Presenter {
                                  false);
             enableToolbarCommand(toolbar.getPasteToolbarCommand(),
                                  false);
+            enableToolbarCommand(toolbar.getSaveToolbarCommand(),
+                                 false);
         }
 
         private void exit() {
@@ -170,8 +187,6 @@ public class ExpressionEditor implements ExpressionEditorView.Presenter {
                                  visitGraphToolbarCommandEnabled);
             enableToolbarCommand(toolbar.getClearToolbarCommand(),
                                  clearToolbarCommandEnabled);
-            enableToolbarCommand(toolbar.getClearStatesToolbarCommand(),
-                                 clearStatesToolbarCommandEnabled);
             enableToolbarCommand(toolbar.getDeleteSelectionToolbarCommand(),
                                  deleteSelectionToolbarCommandEnabled);
             enableToolbarCommand(toolbar.getSwitchGridToolbarCommand(),
@@ -180,7 +195,7 @@ public class ExpressionEditor implements ExpressionEditorView.Presenter {
                                  undoToolbarCommandEnabled);
             enableToolbarCommand(toolbar.getRedoToolbarCommand(),
                                  redoToolbarCommandEnabled);
-            enableToolbarCommand(toolbar.getValidateToolbarCommand(),
+            enableToolbarCommand(toolbar.getValidateCommand(),
                                  validateToolbarCommandEnabled);
             enableToolbarCommand(toolbar.getExportToPngToolbarCommand(),
                                  exportToPngToolbarCommandEnabled);
@@ -194,6 +209,8 @@ public class ExpressionEditor implements ExpressionEditorView.Presenter {
                                  cutCommandEnabled);
             enableToolbarCommand(toolbar.getPasteToolbarCommand(),
                                  pasteCommandEnabled);
+            enableToolbarCommand(toolbar.getSaveToolbarCommand(),
+                                 saveCommandEnabled);
         }
 
         private void enableToolbarCommand(final ToolbarCommand command,
