@@ -21,22 +21,28 @@ import java.util.List;
 import java.util.Optional;
 import java.util.function.Supplier;
 
+import javax.enterprise.event.Event;
+
+import com.ait.lienzo.client.core.event.NodeMouseClickHandler;
 import com.ait.lienzo.shared.core.types.EventPropagationMode;
 import org.jboss.errai.ui.client.local.spi.TranslationService;
 import org.kie.workbench.common.dmn.api.definition.HasExpression;
 import org.kie.workbench.common.dmn.api.definition.HasName;
 import org.kie.workbench.common.dmn.api.definition.v1_1.Expression;
-import org.kie.workbench.common.dmn.client.commands.general.SetCellValueCommand;
+import org.kie.workbench.common.dmn.client.commands.expressions.types.undefined.SetCellValueCommand;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.ExpressionEditorDefinition;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.ExpressionEditorDefinitions;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.ExpressionType;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.context.ExpressionCellValue;
 import org.kie.workbench.common.dmn.client.widgets.grid.BaseExpressionGrid;
+import org.kie.workbench.common.dmn.client.widgets.grid.ExpressionGridCache;
 import org.kie.workbench.common.dmn.client.widgets.grid.controls.HasCellEditorControls;
 import org.kie.workbench.common.dmn.client.widgets.grid.controls.container.CellEditorControlsView;
 import org.kie.workbench.common.dmn.client.widgets.grid.controls.list.HasListSelectorControl;
 import org.kie.workbench.common.dmn.client.widgets.grid.controls.list.ListSelectorView;
+import org.kie.workbench.common.dmn.client.widgets.grid.model.DMNGridData;
 import org.kie.workbench.common.dmn.client.widgets.grid.model.DMNGridRow;
+import org.kie.workbench.common.dmn.client.widgets.grid.model.ExpressionEditorChanged;
 import org.kie.workbench.common.dmn.client.widgets.grid.model.GridCellTuple;
 import org.kie.workbench.common.dmn.client.widgets.grid.model.GridCellValueTuple;
 import org.kie.workbench.common.dmn.client.widgets.layer.DMNGridLayer;
@@ -47,16 +53,20 @@ import org.kie.workbench.common.stunner.core.client.command.CanvasCommandFactory
 import org.kie.workbench.common.stunner.core.client.command.SessionCommandManager;
 import org.kie.workbench.common.stunner.core.util.DefinitionUtils;
 import org.uberfire.ext.wires.core.grids.client.model.GridCell;
+import org.uberfire.ext.wires.core.grids.client.model.GridCellValue;
 import org.uberfire.ext.wires.core.grids.client.model.GridColumn;
+import org.uberfire.ext.wires.core.grids.client.model.GridData;
 import org.uberfire.ext.wires.core.grids.client.model.impl.BaseHeaderMetaData;
+import org.uberfire.ext.wires.core.grids.client.widget.layer.GridSelectionManager;
 
-public class UndefinedExpressionGrid extends BaseExpressionGrid<Expression, UndefinedExpressionUIModelMapper> implements HasListSelectorControl {
+public class UndefinedExpressionGrid extends BaseExpressionGrid<Expression, DMNGridData, UndefinedExpressionUIModelMapper> implements HasListSelectorControl {
 
     public static final double PADDING = 0.0;
 
     private static final String EXPRESSION_COLUMN_GROUP = "UndefinedExpressionGrid$ExpressionColumn";
 
     private final Supplier<ExpressionEditorDefinitions> expressionEditorDefinitionsSupplier;
+    private final ExpressionGridCache expressionGridCache;
 
     public UndefinedExpressionGrid(final GridCellTuple parent,
                                    final Optional<String> nodeUUID,
@@ -65,15 +75,18 @@ public class UndefinedExpressionGrid extends BaseExpressionGrid<Expression, Unde
                                    final Optional<HasName> hasName,
                                    final DMNGridPanel gridPanel,
                                    final DMNGridLayer gridLayer,
+                                   final DMNGridData gridData,
                                    final DefinitionUtils definitionUtils,
                                    final SessionManager sessionManager,
                                    final SessionCommandManager<AbstractCanvasHandler> sessionCommandManager,
                                    final CanvasCommandFactory<AbstractCanvasHandler> canvasCommandFactory,
+                                   final Event<ExpressionEditorChanged> editorSelectedEvent,
                                    final CellEditorControlsView.Presenter cellEditorControls,
                                    final ListSelectorView.Presenter listSelector,
                                    final TranslationService translationService,
                                    final int nesting,
-                                   final Supplier<ExpressionEditorDefinitions> expressionEditorDefinitionsSupplier) {
+                                   final Supplier<ExpressionEditorDefinitions> expressionEditorDefinitionsSupplier,
+                                   final ExpressionGridCache expressionGridCache) {
         super(parent,
               nodeUUID,
               hasExpression,
@@ -81,16 +94,19 @@ public class UndefinedExpressionGrid extends BaseExpressionGrid<Expression, Unde
               hasName,
               gridPanel,
               gridLayer,
+              gridData,
               new UndefinedExpressionGridRenderer(),
               definitionUtils,
               sessionManager,
               sessionCommandManager,
               canvasCommandFactory,
+              editorSelectedEvent,
               cellEditorControls,
               listSelector,
               translationService,
               nesting);
         this.expressionEditorDefinitionsSupplier = expressionEditorDefinitionsSupplier;
+        this.expressionGridCache = expressionGridCache;
 
         //Render the cell content to Lienzo's SelectionLayer so we can handle Events on child elements
         getRenderer().setColumnRenderConstraint((isSelectionLayer, gridColumn) -> true);
@@ -100,6 +116,32 @@ public class UndefinedExpressionGrid extends BaseExpressionGrid<Expression, Unde
         super.doInitialisation();
     }
 
+    @Override
+    protected NodeMouseClickHandler getGridMouseClickHandler(final GridSelectionManager selectionManager) {
+        return (event) -> gridLayer.select(parent.getGridWidget());
+    }
+
+    @Override
+    public void selectFirstCell() {
+        final GridData uiModel = parent.getGridWidget().getModel();
+        uiModel.clearSelections();
+        uiModel.selectCell(parent.getRowIndex(),
+                           parent.getColumnIndex());
+    }
+
+    @Override
+    public void resizeBasedOnCellExpressionEditor(final int uiRowIndex,
+                                                  final int uiColumnIndex) {
+        final Optional<GridCell<?>> parentCell = Optional.ofNullable(parent.getGridWidget().getModel().getCell(uiRowIndex, uiColumnIndex));
+        parentCell.ifPresent(cell -> {
+            final GridCellValue<?> value = cell.getValue();
+            if (value instanceof ExpressionCellValue) {
+                final Optional<BaseExpressionGrid> grid = ((ExpressionCellValue) value).getValue();
+                grid.ifPresent(BaseExpressionGrid::resizeWhenExpressionEditorChanged);
+            }
+        });
+    }
+
     @Override
     protected void doInitialisation() {
         // Defer initialisation until after the constructor completes as
@@ -111,7 +153,8 @@ public class UndefinedExpressionGrid extends BaseExpressionGrid<Expression, Unde
         return new UndefinedExpressionUIModelMapper(this::getModel,
                                                     () -> expression,
                                                     listSelector,
-                                                    hasExpression);
+                                                    hasExpression,
+                                                    parent);
     }
 
     @Override
@@ -144,6 +187,11 @@ public class UndefinedExpressionGrid extends BaseExpressionGrid<Expression, Unde
         return PADDING;
     }
 
+    @Override
+    public boolean isCacheable() {
+        return false;
+    }
+
     @Override
     @SuppressWarnings("unused")
     public List<ListSelectorItem> getItems(final int uiRowIndex,
@@ -188,21 +236,32 @@ public class UndefinedExpressionGrid extends BaseExpressionGrid<Expression, Unde
 
         final Optional<ExpressionEditorDefinition<Expression>> expressionEditorDefinition = expressionEditorDefinitionsSupplier.get().getExpressionEditorDefinition(expression);
         expressionEditorDefinition.ifPresent(ed -> {
-            final Optional<BaseExpressionGrid> editor = ed.getEditor(parent,
-                                                                     nodeUUID,
-                                                                     hasExpression,
-                                                                     expression,
-                                                                     hasName,
-                                                                     nesting);
-            final GridCellValueTuple gcv = new GridCellValueTuple<>(parent.getRowIndex(),
-                                                                    parent.getColumnIndex(),
-                                                                    parent.getGridWidget(),
-                                                                    new ExpressionCellValue(editor));
+            Optional<BaseExpressionGrid> editor = Optional.empty();
+            if (nodeUUID.isPresent()) {
+                final String uuid = nodeUUID.get();
+                editor = expressionGridCache.getExpressionGrid(uuid);
+            }
+            if (!editor.isPresent()) {
+                editor = ed.getEditor(parent,
+                                      nodeUUID,
+                                      hasExpression,
+                                      expression,
+                                      hasName,
+                                      nesting);
+            }
+
+            final GridCellValueTuple<ExpressionCellValue> gcv = new GridCellValueTuple<>(parent.getRowIndex(),
+                                                                                         parent.getColumnIndex(),
+                                                                                         parent.getGridWidget(),
+                                                                                         new ExpressionCellValue(editor));
 
             sessionCommandManager.execute((AbstractCanvasHandler) sessionManager.getCurrentSession().getCanvasHandler(),
                                           new SetCellValueCommand(gcv,
+                                                                  nodeUUID,
                                                                   () -> uiModelMapper,
-                                                                  () -> synchroniseViewWhenExpressionEditorChanged(editor.get())));
+                                                                  expressionGridCache,
+                                                                  () -> resizeBasedOnCellExpressionEditor(parent.getRowIndex(),
+                                                                                                          parent.getColumnIndex())));
         });
     }
 }
