@@ -22,6 +22,8 @@ import java.util.Optional;
 import java.util.function.Function;
 import java.util.function.Predicate;
 
+import javax.enterprise.event.Event;
+
 import com.ait.lienzo.client.core.event.INodeXYEvent;
 import com.ait.lienzo.client.core.event.NodeMouseDoubleClickHandler;
 import com.ait.lienzo.client.core.shape.Group;
@@ -35,6 +37,7 @@ import org.kie.workbench.common.dmn.client.commands.general.DeleteCellValueComma
 import org.kie.workbench.common.dmn.client.commands.general.DeleteHeaderValueCommand;
 import org.kie.workbench.common.dmn.client.commands.general.SetCellValueCommand;
 import org.kie.workbench.common.dmn.client.commands.general.SetHeaderValueCommand;
+import org.kie.workbench.common.dmn.client.editors.expressions.types.context.ExpressionCellValue;
 import org.kie.workbench.common.dmn.client.widgets.grid.columns.EditableHeaderGridWidgetMouseDoubleClickHandler;
 import org.kie.workbench.common.dmn.client.widgets.grid.columns.EditableHeaderMetaData;
 import org.kie.workbench.common.dmn.client.widgets.grid.columns.factory.TextAreaSingletonDOMElementFactory;
@@ -42,7 +45,7 @@ import org.kie.workbench.common.dmn.client.widgets.grid.columns.factory.TextBoxS
 import org.kie.workbench.common.dmn.client.widgets.grid.controls.container.CellEditorControlsView;
 import org.kie.workbench.common.dmn.client.widgets.grid.controls.list.ListSelectorView;
 import org.kie.workbench.common.dmn.client.widgets.grid.model.BaseUIModelMapper;
-import org.kie.workbench.common.dmn.client.widgets.grid.model.DMNGridData;
+import org.kie.workbench.common.dmn.client.widgets.grid.model.ExpressionEditorChanged;
 import org.kie.workbench.common.dmn.client.widgets.grid.model.GridCellTuple;
 import org.kie.workbench.common.dmn.client.widgets.grid.model.GridCellValueTuple;
 import org.kie.workbench.common.dmn.client.widgets.layer.DMNGridLayer;
@@ -59,6 +62,8 @@ import org.kie.workbench.common.stunner.core.graph.Element;
 import org.kie.workbench.common.stunner.core.graph.content.definition.Definition;
 import org.kie.workbench.common.stunner.core.util.DefinitionUtils;
 import org.uberfire.commons.data.Pair;
+import org.uberfire.ext.wires.core.grids.client.model.GridCell;
+import org.uberfire.ext.wires.core.grids.client.model.GridCellValue;
 import org.uberfire.ext.wires.core.grids.client.model.GridColumn;
 import org.uberfire.ext.wires.core.grids.client.model.GridData;
 import org.uberfire.ext.wires.core.grids.client.widget.grid.GridWidget;
@@ -69,7 +74,7 @@ import org.uberfire.ext.wires.core.grids.client.widget.layer.GridSelectionManage
 import org.uberfire.ext.wires.core.grids.client.widget.layer.impl.GridLayerRedrawManager;
 import org.uberfire.ext.wires.core.grids.client.widget.layer.pinning.GridPinnedModeManager;
 
-public abstract class BaseExpressionGrid<E extends Expression, M extends BaseUIModelMapper<E>> extends BaseGridWidget {
+public abstract class BaseExpressionGrid<E extends Expression, D extends GridData, M extends BaseUIModelMapper<E>> extends BaseGridWidget implements ExpressionGridCache.IsCacheable {
 
     public static final double DEFAULT_PADDING = 10.0;
 
@@ -92,11 +97,10 @@ public abstract class BaseExpressionGrid<E extends Expression, M extends BaseUIM
     protected final ListSelectorView.Presenter listSelector;
 
     protected final TranslationService translationService;
-
+    protected final Event<ExpressionEditorChanged> editorSelectedEvent;
+    protected final int nesting;
     protected M uiModelMapper;
 
-    protected final int nesting;
-
     public BaseExpressionGrid(final GridCellTuple parent,
                               final Optional<String> nodeUUID,
                               final HasExpression hasExpression,
@@ -104,47 +108,13 @@ public abstract class BaseExpressionGrid<E extends Expression, M extends BaseUIM
                               final Optional<HasName> hasName,
                               final DMNGridPanel gridPanel,
                               final DMNGridLayer gridLayer,
+                              final D gridData,
                               final GridRenderer gridRenderer,
                               final DefinitionUtils definitionUtils,
                               final SessionManager sessionManager,
                               final SessionCommandManager<AbstractCanvasHandler> sessionCommandManager,
                               final CanvasCommandFactory<AbstractCanvasHandler> canvasCommandFactory,
-                              final CellEditorControlsView.Presenter cellEditorControls,
-                              final ListSelectorView.Presenter listSelector,
-                              final TranslationService translationService,
-                              final int nesting) {
-        this(parent,
-             nodeUUID,
-             hasExpression,
-             expression,
-             hasName,
-             gridPanel,
-             gridLayer,
-             new DMNGridData(),
-             gridRenderer,
-             definitionUtils,
-             sessionManager,
-             sessionCommandManager,
-             canvasCommandFactory,
-             cellEditorControls,
-             listSelector,
-             translationService,
-             nesting);
-    }
-
-    public BaseExpressionGrid(final GridCellTuple parent,
-                              final Optional<String> nodeUUID,
-                              final HasExpression hasExpression,
-                              final Optional<E> expression,
-                              final Optional<HasName> hasName,
-                              final DMNGridPanel gridPanel,
-                              final DMNGridLayer gridLayer,
-                              final GridData gridData,
-                              final GridRenderer gridRenderer,
-                              final DefinitionUtils definitionUtils,
-                              final SessionManager sessionManager,
-                              final SessionCommandManager<AbstractCanvasHandler> sessionCommandManager,
-                              final CanvasCommandFactory<AbstractCanvasHandler> canvasCommandFactory,
+                              final Event<ExpressionEditorChanged> editorSelectedEvent,
                               final CellEditorControlsView.Presenter cellEditorControls,
                               final ListSelectorView.Presenter listSelector,
                               final TranslationService translationService,
@@ -161,6 +131,7 @@ public abstract class BaseExpressionGrid<E extends Expression, M extends BaseUIM
         this.sessionManager = sessionManager;
         this.sessionCommandManager = sessionCommandManager;
         this.canvasCommandFactory = canvasCommandFactory;
+        this.editorSelectedEvent = editorSelectedEvent;
         this.cellEditorControls = cellEditorControls;
         this.listSelector = listSelector;
         this.translationService = translationService;
@@ -186,6 +157,8 @@ public abstract class BaseExpressionGrid<E extends Expression, M extends BaseUIM
 
     protected abstract void initialiseUiModel();
 
+    protected abstract boolean isHeaderHidden();
+
     protected Function<GridCellTuple, Command> newCellHasNoValueCommand() {
         return (gc) -> new DeleteCellValueCommand(gc,
                                                   () -> uiModelMapper,
@@ -355,12 +328,17 @@ public abstract class BaseExpressionGrid<E extends Expression, M extends BaseUIM
 
     @Override
     public void select() {
-        selectFirstCell();
+        fireExpressionEditorChanged();
         super.select();
     }
 
+    private void fireExpressionEditorChanged() {
+        editorSelectedEvent.fire(new ExpressionEditorChanged());
+    }
+
     @Override
     public void deselect() {
+        fireExpressionEditorChanged();
         getModel().clearSelections();
         super.deselect();
     }
@@ -402,8 +380,6 @@ public abstract class BaseExpressionGrid<E extends Expression, M extends BaseUIM
         super.executeRenderQueueCommands(isSelectionLayer);
     }
 
-    protected abstract boolean isHeaderHidden();
-
     public Optional<E> getExpression() {
         return expression;
     }
@@ -416,6 +392,11 @@ public abstract class BaseExpressionGrid<E extends Expression, M extends BaseUIM
         return parent;
     }
 
+    @Override
+    public boolean isCacheable() {
+        return true;
+    }
+
     public double getMinimumWidth() {
         double minimumWidth = 0;
         final int columnCount = model.getColumnCount();
@@ -430,12 +411,8 @@ public abstract class BaseExpressionGrid<E extends Expression, M extends BaseUIM
         return minimumWidth;
     }
 
-    public void synchroniseView() {
-        gridPanel.refreshScrollPosition();
-        gridPanel.updatePanelSize();
-        parent.onResize();
-
-        gridLayer.batch(new GridLayerRedrawManager.PrioritizedCommand(0) {
+    public void resize() {
+        doResize(new GridLayerRedrawManager.PrioritizedCommand(0) {
             @Override
             public void execute() {
                 gridLayer.draw();
@@ -443,18 +420,36 @@ public abstract class BaseExpressionGrid<E extends Expression, M extends BaseUIM
         });
     }
 
-    public void synchroniseViewWhenExpressionEditorChanged(final BaseExpressionGrid editor) {
-        final double proposedWidth = editor.getWidth() + editor.getPadding() * 2;
+    public void resizeWhenExpressionEditorChanged() {
+        doResize(new GridLayerRedrawManager.PrioritizedCommand(0) {
+            @Override
+            public void execute() {
+                gridLayer.select(BaseExpressionGrid.this);
+                selectFirstCell();
+                gridLayer.draw();
+            }
+        });
+    }
+
+    private void doResize(final GridLayerRedrawManager.PrioritizedCommand command) {
+        final double proposedWidth = getWidth() + getPadding() * 2;
         parent.proposeContainingColumnWidth(proposedWidth);
+
         gridPanel.refreshScrollPosition();
         gridPanel.updatePanelSize();
         parent.onResize();
 
-        gridLayer.batch(new GridLayerRedrawManager.PrioritizedCommand(0) {
-            @Override
-            public void execute() {
-                gridLayer.draw();
-                gridLayer.select(editor);
+        gridLayer.batch(command);
+    }
+
+    public void resizeBasedOnCellExpressionEditor(final int uiRowIndex,
+                                                  final int uiColumnIndex) {
+        final Optional<GridCell<?>> cell = Optional.ofNullable(model.getCell(uiRowIndex, uiColumnIndex));
+        cell.ifPresent(c -> {
+            final GridCellValue<?> value = c.getValue();
+            if (value instanceof ExpressionCellValue) {
+                final Optional<BaseExpressionGrid> grid = ((ExpressionCellValue) value).getValue();
+                grid.ifPresent(BaseExpressionGrid::resizeWhenExpressionEditorChanged);
             }
         });
     }
@@ -462,8 +457,9 @@ public abstract class BaseExpressionGrid<E extends Expression, M extends BaseUIM
     public void selectFirstCell() {
         final GridData uiModel = getModel();
         if (uiModel.getRowCount() == 0 || uiModel.getColumnCount() == 0) {
-            gridLayer.getGridWidgets().forEach(gw -> gw.getModel().clearSelections());
+            return;
         }
+        uiModel.clearSelections();
         uiModel.getColumns()
                 .stream()
                 .filter(c -> !(c instanceof RowNumberColumn))
