@@ -16,6 +16,7 @@
 
 package org.kie.workbench.common.dmn.client.commands.expressions.types.dtable;
 
+import java.util.List;
 import java.util.Optional;
 import java.util.stream.Stream;
 
@@ -148,12 +149,19 @@ public class AddOutputClauseCommandTest {
         assertEquals(1, dtable.getOutput().size());
 
         // first rule
-        assertEquals(1, dtable.getRule().get(0).getOutputEntry().size());
-        assertEquals(AddOutputClauseCommand.OUTPUT_CLAUSE_DEFAULT_VALUE, dtable.getRule().get(0).getOutputEntry().get(0).getText());
+        final List<LiteralExpression> outputEntriesRuleOne = dtable.getRule().get(0).getOutputEntry();
+        assertEquals(1, outputEntriesRuleOne.size());
+        assertEquals(AddOutputClauseCommand.OUTPUT_CLAUSE_DEFAULT_VALUE, outputEntriesRuleOne.get(0).getText());
+        assertEquals(dtable.getRule().get(0), outputEntriesRuleOne.get(0).getParent());
 
         // second rule
-        assertEquals(1, dtable.getRule().get(1).getOutputEntry().size());
-        assertEquals(AddOutputClauseCommand.OUTPUT_CLAUSE_DEFAULT_VALUE, dtable.getRule().get(1).getOutputEntry().get(0).getText());
+        final List<LiteralExpression> outputEntriesRuleTwo = dtable.getRule().get(1).getOutputEntry();
+        assertEquals(1, outputEntriesRuleTwo.size());
+        assertEquals(AddOutputClauseCommand.OUTPUT_CLAUSE_DEFAULT_VALUE, outputEntriesRuleTwo.get(0).getText());
+        assertEquals(dtable.getRule().get(1), outputEntriesRuleTwo.get(0).getParent());
+
+        assertEquals(dtable,
+                     outputClause.getParent());
     }
 
     @Test
@@ -178,14 +186,55 @@ public class AddOutputClauseCommandTest {
         assertEquals(2, dtable.getOutput().size());
 
         // first rule
-        assertEquals(2, dtable.getRule().get(0).getOutputEntry().size());
-        assertEquals(ruleOneOldOutput, dtable.getRule().get(0).getOutputEntry().get(1).getText());
-        assertEquals(AddOutputClauseCommand.OUTPUT_CLAUSE_DEFAULT_VALUE, dtable.getRule().get(0).getOutputEntry().get(0).getText());
+        final List<LiteralExpression> outputEntriesRuleOne = dtable.getRule().get(0).getOutputEntry();
+        assertEquals(2, outputEntriesRuleOne.size());
+        assertEquals(ruleOneOldOutput, outputEntriesRuleOne.get(1).getText());
+        assertEquals(AddOutputClauseCommand.OUTPUT_CLAUSE_DEFAULT_VALUE, outputEntriesRuleOne.get(0).getText());
+        assertEquals(dtable.getRule().get(0), outputEntriesRuleOne.get(0).getParent());
 
         // second rule
-        assertEquals(2, dtable.getRule().get(1).getOutputEntry().size());
-        assertEquals(ruleTwoOldOutput, dtable.getRule().get(1).getOutputEntry().get(1).getText());
-        assertEquals(AddOutputClauseCommand.OUTPUT_CLAUSE_DEFAULT_VALUE, dtable.getRule().get(1).getOutputEntry().get(0).getText());
+        final List<LiteralExpression> outputEntriesRuleTwo = dtable.getRule().get(1).getOutputEntry();
+        assertEquals(2, outputEntriesRuleTwo.size());
+        assertEquals(ruleTwoOldOutput, outputEntriesRuleTwo.get(1).getText());
+        assertEquals(AddOutputClauseCommand.OUTPUT_CLAUSE_DEFAULT_VALUE, outputEntriesRuleTwo.get(0).getText());
+        assertEquals(dtable.getRule().get(1), outputEntriesRuleTwo.get(0).getParent());
+
+        assertEquals(dtable,
+                     outputClause.getParent());
+    }
+
+    @Test
+    public void testGraphCommandExecuteInsertMiddle() throws Exception {
+        makeCommand(DecisionTableUIModelMapperHelper.ROW_INDEX_COLUMN_COUNT + 1);
+
+        final String ruleOutputOne = "rule out 1";
+        final String ruleOutputTwo = "rule out 2";
+
+        dtable.getOutput().add(new OutputClause());
+        dtable.getOutput().add(new OutputClause());
+        addRuleWithOutputClauseValues(ruleOutputOne, ruleOutputTwo);
+
+        assertEquals(2, dtable.getOutput().size());
+
+        //Graph command will insert new OutputClause at index 1 of the OutputEntries
+        final Command<GraphCommandExecutionContext, RuleViolation> graphCommand = command.newGraphCommand(canvasHandler);
+
+        assertEquals(GraphCommandResultBuilder.SUCCESS,
+                     graphCommand.execute(graphCommandExecutionContext));
+
+        assertEquals(3, dtable.getOutput().size());
+
+        final List<LiteralExpression> ruleOutputs = dtable.getRule().get(0).getOutputEntry();
+
+        // first rule
+        assertEquals(3, ruleOutputs.size());
+        assertEquals(ruleOutputOne, ruleOutputs.get(0).getText());
+        assertEquals(AddOutputClauseCommand.OUTPUT_CLAUSE_DEFAULT_VALUE, ruleOutputs.get(1).getText());
+        assertEquals(dtable.getRule().get(0), ruleOutputs.get(1).getParent());
+        assertEquals(ruleOutputTwo, ruleOutputs.get(2).getText());
+
+        assertEquals(dtable,
+                     outputClause.getParent());
     }
 
     @Test(expected = ArrayIndexOutOfBoundsException.class)
