@@ -28,9 +28,11 @@ import org.junit.Test;
 import org.junit.runner.RunWith;
 import org.kie.workbench.common.dmn.api.definition.HasExpression;
 import org.kie.workbench.common.dmn.api.definition.HasName;
+import org.kie.workbench.common.dmn.api.definition.v1_1.DMNModelInstrumentedBase;
+import org.kie.workbench.common.dmn.api.definition.v1_1.Expression;
 import org.kie.workbench.common.dmn.api.definition.v1_1.LiteralExpression;
 import org.kie.workbench.common.dmn.api.property.dmn.Name;
-import org.kie.workbench.common.dmn.client.commands.general.ClearExpressionTypeCommand;
+import org.kie.workbench.common.dmn.client.commands.ClearExpressionTypeCommand;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.ExpressionEditorDefinition;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.ExpressionEditorDefinitions;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.context.ExpressionCellValue;
@@ -39,13 +41,15 @@ import org.kie.workbench.common.dmn.client.editors.expressions.types.undefined.U
 import org.kie.workbench.common.dmn.client.editors.expressions.types.undefined.UndefinedExpressionGrid;
 import org.kie.workbench.common.dmn.client.resources.i18n.DMNEditorConstants;
 import org.kie.workbench.common.dmn.client.widgets.grid.BaseExpressionGrid;
+import org.kie.workbench.common.dmn.client.widgets.grid.ExpressionGridCache;
+import org.kie.workbench.common.dmn.client.widgets.grid.ExpressionGridCacheImpl;
 import org.kie.workbench.common.dmn.client.widgets.grid.controls.container.CellEditorControlsView;
 import org.kie.workbench.common.dmn.client.widgets.grid.controls.list.HasListSelectorControl;
 import org.kie.workbench.common.dmn.client.widgets.grid.controls.list.ListSelectorView;
+import org.kie.workbench.common.dmn.client.widgets.grid.model.DMNGridColumn;
 import org.kie.workbench.common.dmn.client.widgets.grid.model.DMNGridData;
 import org.kie.workbench.common.dmn.client.widgets.grid.model.GridCellTuple;
 import org.kie.workbench.common.dmn.client.widgets.layer.DMNGridLayer;
-import org.kie.workbench.common.dmn.client.widgets.panel.DMNGridPanel;
 import org.kie.workbench.common.stunner.core.client.api.SessionManager;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
 import org.kie.workbench.common.stunner.core.client.command.SessionCommandManager;
@@ -72,6 +76,8 @@ import static org.mockito.Mockito.doAnswer;
 import static org.mockito.Mockito.doReturn;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.never;
+import static org.mockito.Mockito.reset;
+import static org.mockito.Mockito.spy;
 import static org.mockito.Mockito.verify;
 import static org.mockito.Mockito.when;
 
@@ -82,11 +88,7 @@ public class ExpressionContainerGridTest {
 
     private static final String NAME = "name";
 
-    @Mock
-    private DMNGridPanel gridPanel;
-
-    @Mock
-    private DMNGridLayer gridLayer;
+    private static final double COLUMN_NEW_WIDTH = 200.0;
 
     @Mock
     private CellEditorControlsView.Presenter cellEditorControls;
@@ -136,9 +138,15 @@ public class ExpressionContainerGridTest {
     @Mock
     private ParameterizedCommand<Optional<HasName>> onHasNameChanged;
 
+    @Mock
+    private ParameterizedCommand<Optional<Expression>> onHasExpressionChanged;
+
     @Captor
     private ArgumentCaptor<Optional<HasName>> hasNameCaptor;
 
+    @Captor
+    private ArgumentCaptor<ClearExpressionTypeCommand> clearExpressionTypeCommandCaptor;
+
     private HasName hasName = new HasName() {
 
         private Name name = new Name(NAME);
@@ -156,21 +164,30 @@ public class ExpressionContainerGridTest {
 
     private LiteralExpression literalExpression = new LiteralExpression();
 
+    private ExpressionGridCache expressionGridCache;
+
+    private DMNGridLayer gridLayer;
+
     private ExpressionContainerGrid grid;
 
     @Before
     @SuppressWarnings("unchecked")
     public void setup() {
-        this.grid = new ExpressionContainerGrid(gridPanel,
-                                                gridLayer,
+        this.expressionGridCache = new ExpressionGridCacheImpl();
+        this.gridLayer = spy(new DMNGridLayer());
+        this.grid = new ExpressionContainerGrid(gridLayer,
                                                 cellEditorControls,
                                                 translationService,
                                                 listSelector,
                                                 sessionManager,
                                                 sessionCommandManager,
                                                 expressionEditorDefinitionsSupplier,
+                                                () -> expressionGridCache,
+                                                onHasExpressionChanged,
                                                 onHasNameChanged);
 
+        this.gridLayer.add(grid);
+
         final ExpressionEditorDefinitions expressionEditorDefinitions = new ExpressionEditorDefinitions();
         expressionEditorDefinitions.add(undefinedExpressionEditorDefinition);
         expressionEditorDefinitions.add(literalExpressionEditorDefinition);
@@ -241,6 +258,9 @@ public class ExpressionContainerGridTest {
         final ExpressionCellValue expressionCellValue = (ExpressionCellValue) gridCellValue;
         assertThat(expressionCellValue.getValue().isPresent()).isTrue();
         assertThat(expressionCellValue.getValue().get()).isSameAs(undefinedExpressionEditor);
+
+        verify(undefinedExpressionEditor).selectFirstCell();
+        verify(gridLayer).batch();
     }
 
     @Test
@@ -256,6 +276,28 @@ public class ExpressionContainerGridTest {
         final ExpressionCellValue expressionCellValue = (ExpressionCellValue) gridCellValue;
         assertThat(expressionCellValue.getValue().isPresent()).isTrue();
         assertThat(expressionCellValue.getValue().get()).isSameAs(literalExpressionEditor);
+
+        verify(literalExpressionEditor).selectFirstCell();
+        verify(gridLayer).batch();
+    }
+
+    @Test
+    public void testSetDefinedExpressionWhenReopeningWithResizedColumn() {
+        //Emulate User setting expression and resizing column
+        when(hasExpression.getExpression()).thenReturn(literalExpression);
+
+        grid.setExpression(NODE_UUID,
+                           hasExpression,
+                           Optional.of(hasName));
+        grid.getModel().getColumns().get(0).setWidth(COLUMN_NEW_WIDTH);
+
+        //Emulate re-opening editor
+        grid.setExpression(NODE_UUID,
+                           hasExpression,
+                           Optional.of(hasName));
+
+        //Verify width is preserved
+        assertThat(grid.getModel().getColumns().get(0).getWidth()).isEqualTo(COLUMN_NEW_WIDTH);
     }
 
     @Test
@@ -289,13 +331,48 @@ public class ExpressionContainerGridTest {
         verify(command).execute();
     }
 
+    @Test
+    public void testOnClearExpressionItemSelected() {
+        //Emulate User setting expression and resizing column
+        when(hasExpression.getExpression()).thenReturn(literalExpression);
+
+        grid.setExpression(NODE_UUID,
+                           hasExpression,
+                           Optional.of(hasName));
+        verify(literalExpressionEditor).selectFirstCell();
+        verify(gridLayer).batch();
+
+        grid.getModel().getColumns().get(0).setWidth(COLUMN_NEW_WIDTH);
+
+        //Get and select ClearExpression item
+        final List<HasListSelectorControl.ListSelectorItem> items = grid.getItems(0, 0);
+        final HasListSelectorControl.ListSelectorItem item = items.get(0);
+        final HasListSelectorControl.ListSelectorTextItem ti = (HasListSelectorControl.ListSelectorTextItem) item;
+
+        ti.getCommand().execute();
+
+        verify(sessionCommandManager).execute(eq(canvasHandler),
+                                              clearExpressionTypeCommandCaptor.capture());
+
+        final ClearExpressionTypeCommand clearExpressionTypeCommand = clearExpressionTypeCommandCaptor.getValue();
+        //We're using a mock HasExpression therefore the ClearExpressionCommand does not change mocked behaviour. Reset mock.
+        reset(hasExpression, gridLayer);
+
+        clearExpressionTypeCommand.execute(canvasHandler);
+
+        //Verify Expression has been cleared and UndefinedExpressionEditor
+        assertThat(grid.getModel().getColumns().get(0).getWidth()).isEqualTo(DMNGridColumn.DEFAULT_WIDTH);
+        verify(undefinedExpressionEditor).selectFirstCell();
+        verify(gridLayer).batch();
+    }
+
     @Test
     public void testSpyHasNameWithHasNameGet() {
         grid.setExpression(NODE_UUID,
                            hasExpression,
                            Optional.of(hasName));
 
-        final Optional<HasName> spy = grid.spyHasName(onHasNameChanged);
+        final Optional<HasName> spy = grid.spyHasName(Optional.of(hasName));
 
         assertThat(spy.isPresent()).isTrue();
         assertThat(spy.get().getName().getValue()).isEqualTo(NAME);
@@ -309,7 +386,7 @@ public class ExpressionContainerGridTest {
                            hasExpression,
                            Optional.of(hasName));
 
-        final Optional<HasName> spy = grid.spyHasName(onHasNameChanged);
+        final Optional<HasName> spy = grid.spyHasName(Optional.of(hasName));
 
         assertThat(spy.isPresent()).isTrue();
         spy.get().getName().setValue(NEW_NAME);
@@ -329,7 +406,7 @@ public class ExpressionContainerGridTest {
                            hasExpression,
                            Optional.of(hasName));
 
-        final Optional<HasName> spy = grid.spyHasName(onHasNameChanged);
+        final Optional<HasName> spy = grid.spyHasName(Optional.of(hasName));
 
         assertThat(spy.isPresent()).isTrue();
         spy.get().setName(newName);
@@ -345,7 +422,7 @@ public class ExpressionContainerGridTest {
                            hasExpression,
                            Optional.empty());
 
-        final Optional<HasName> spy = grid.spyHasName(onHasNameChanged);
+        final Optional<HasName> spy = grid.spyHasName(Optional.empty());
 
         assertThat(spy.isPresent()).isTrue();
         assertThat(spy.get().getName().getValue()).isEqualTo(HasName.NOP.getName().getValue());
@@ -360,7 +437,7 @@ public class ExpressionContainerGridTest {
                            hasExpression,
                            Optional.empty());
 
-        final Optional<HasName> spy = grid.spyHasName(onHasNameChanged);
+        final Optional<HasName> spy = grid.spyHasName(Optional.empty());
 
         assertThat(spy.isPresent()).isTrue();
         spy.get().getName().setValue(NEW_NAME);
@@ -380,7 +457,7 @@ public class ExpressionContainerGridTest {
                            hasExpression,
                            Optional.empty());
 
-        final Optional<HasName> spy = grid.spyHasName(onHasNameChanged);
+        final Optional<HasName> spy = grid.spyHasName(Optional.empty());
 
         assertThat(spy.isPresent()).isTrue();
         spy.get().setName(newName);
@@ -388,4 +465,61 @@ public class ExpressionContainerGridTest {
         assertThat(hasName.getName().getValue()).isEqualTo(NAME);
         verify(onHasNameChanged, never()).execute(any(Optional.class));
     }
+
+    @Test
+    public void testSpyHasExpressionWithExpressionGet() {
+        when(hasExpression.getExpression()).thenReturn(literalExpression);
+
+        grid.setExpression(NODE_UUID,
+                           hasExpression,
+                           Optional.of(hasName));
+
+        final HasExpression spy = grid.spyHasExpression(hasExpression);
+
+        assertThat(spy.getExpression()).isEqualTo(literalExpression);
+    }
+
+    @Test
+    public void testSpyHasExpressionWithoutExpressionGet() {
+        grid.setExpression(NODE_UUID,
+                           hasExpression,
+                           Optional.of(hasName));
+
+        final HasExpression spy = grid.spyHasExpression(hasExpression);
+
+        assertThat(spy.getExpression()).isNull();
+    }
+
+    @Test
+    public void testSpyHasExpressionWithExpressionSet() {
+        final HasExpression hasExpression = new HasExpression() {
+
+            private Expression expression = new LiteralExpression();
+
+            @Override
+            public Expression getExpression() {
+                return expression;
+            }
+
+            @Override
+            public void setExpression(final Expression expression) {
+                this.expression = expression;
+            }
+
+            @Override
+            public DMNModelInstrumentedBase asDMNModelInstrumentedBase() {
+                return null;
+            }
+        };
+
+        grid.setExpression(NODE_UUID,
+                           hasExpression,
+                           Optional.of(hasName));
+
+        final HasExpression spy = grid.spyHasExpression(hasExpression);
+
+        spy.setExpression(null);
+
+        assertThat(hasExpression.getExpression()).isNull();
+    }
 }
