@@ -24,15 +24,24 @@ import org.junit.Test;
 import org.junit.runner.RunWith;
 import org.kie.workbench.common.dmn.api.definition.HasExpression;
 import org.kie.workbench.common.dmn.api.definition.HasName;
+import org.kie.workbench.common.dmn.client.decision.DecisionNavigatorPresenter;
+import org.kie.workbench.common.dmn.client.widgets.grid.ExpressionGridCache;
+import org.kie.workbench.common.dmn.client.widgets.grid.ExpressionGridCacheImpl;
+import org.kie.workbench.common.dmn.client.widgets.toolbar.DMNEditorToolbar;
 import org.kie.workbench.common.stunner.client.widgets.presenters.session.SessionPresenter;
 import org.kie.workbench.common.stunner.client.widgets.toolbar.ToolbarCommand;
-import org.kie.workbench.common.stunner.client.widgets.toolbar.impl.EditorToolbar;
+import org.kie.workbench.common.stunner.core.client.canvas.CanvasHandler;
+import org.kie.workbench.common.stunner.core.client.canvas.event.selection.CanvasSelectionEvent;
+import org.kie.workbench.common.stunner.core.client.session.impl.ManagedSession;
 import org.mockito.Mock;
 import org.uberfire.mvp.Command;
 
+import static org.junit.Assert.assertEquals;
 import static org.mockito.Matchers.any;
 import static org.mockito.Matchers.eq;
 import static org.mockito.Mockito.atLeast;
+import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.spy;
 import static org.mockito.Mockito.verify;
 import static org.mockito.Mockito.when;
 
@@ -48,7 +57,10 @@ public class ExpressionEditorTest {
     private SessionPresenter sessionPresenter;
 
     @Mock
-    private EditorToolbar editorToolbar;
+    private DecisionNavigatorPresenter decisionNavigator;
+
+    @Mock
+    private DMNEditorToolbar editorToolbar;
 
     @Mock
     private HasName hasName;
@@ -59,14 +71,23 @@ public class ExpressionEditorTest {
     @Mock
     private Command command;
 
+    @Mock
+    private ManagedSession session;
+
     private ExpressionEditor testedEditor;
 
+    private ExpressionGridCache expressionGridCache;
+
     @Before
     @SuppressWarnings("unchecked")
     public void setUp() throws Exception {
-        testedEditor = new ExpressionEditor(view);
+        this.expressionGridCache = new ExpressionGridCacheImpl();
+
+        testedEditor = spy(new ExpressionEditor(view,
+                                                decisionNavigator));
         when(sessionPresenter.getToolbar()).thenReturn(editorToolbar);
         when(editorToolbar.isEnabled(any(ToolbarCommand.class))).thenReturn(true);
+        when(session.getCanvasControl(eq(ExpressionGridCache.class))).thenReturn(expressionGridCache);
     }
 
     @Test
@@ -103,7 +124,21 @@ public class ExpressionEditorTest {
 
         testedEditor.exit();
 
+        verify(decisionNavigator).clearSelections();
         verify(editorToolbar, atLeast(1)).enable(any(ToolbarCommand.class));
         verify(command).execute();
+        assertEquals(Optional.empty(), testedEditor.getExitCommand());
+    }
+
+    @Test
+    public void testOnCanvasFocusedSelectionEvent() {
+
+        final CanvasHandler canvasHandler = mock(CanvasHandler.class);
+        final String uuid = "uuid";
+        final CanvasSelectionEvent event = new CanvasSelectionEvent(canvasHandler, uuid);
+
+        testedEditor.onCanvasFocusedSelectionEvent(event);
+
+        verify(testedEditor).exit();
     }
 }
