@@ -35,6 +35,7 @@ import org.kie.workbench.common.dmn.client.resources.i18n.DMNEditorConstants;
 import org.kie.workbench.common.dmn.client.widgets.grid.BaseExpressionGrid;
 import org.kie.workbench.common.dmn.client.widgets.grid.controls.container.CellEditorControlsView;
 import org.kie.workbench.common.dmn.client.widgets.grid.controls.list.ListSelectorView;
+import org.kie.workbench.common.dmn.client.widgets.grid.model.ExpressionEditorChanged;
 import org.kie.workbench.common.dmn.client.widgets.grid.model.GridCellTuple;
 import org.kie.workbench.common.dmn.client.widgets.layer.DMNGridLayer;
 import org.kie.workbench.common.dmn.client.widgets.panel.DMNGridPanel;
@@ -45,6 +46,7 @@ import org.kie.workbench.common.stunner.core.client.command.SessionCommandManage
 import org.kie.workbench.common.stunner.core.util.DefinitionUtils;
 import org.mockito.Mock;
 import org.uberfire.ext.wires.core.grids.client.widget.grid.GridWidget;
+import org.uberfire.mocks.EventSourceMock;
 
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertNotNull;
@@ -93,6 +95,9 @@ public class ContextEditorDefinitionTest {
     @Mock
     private HasExpression hasExpression;
 
+    @Mock
+    private EventSourceMock<ExpressionEditorChanged> editorSelectedEvent;
+
     private Optional<HasName> hasName = Optional.empty();
 
     private ContextEditorDefinition definition;
@@ -106,6 +111,7 @@ public class ContextEditorDefinitionTest {
                                                       sessionManager,
                                                       sessionCommandManager,
                                                       canvasCommandFactory,
+                                                      editorSelectedEvent,
                                                       cellEditorControls,
                                                       listSelector,
                                                       translationService,
@@ -142,6 +148,13 @@ public class ContextEditorDefinitionTest {
 
         assertNull(model.getContextEntry().get(1).getVariable());
         assertTrue(model.getContextEntry().get(1).getExpression() instanceof LiteralExpression);
+
+        model.getContextEntry().forEach(ce -> assertEquals(model, ce.getParent()));
+
+        assertEquals(model.getContextEntry().get(0),
+                     model.getContextEntry().get(0).getVariable().getParent());
+        assertEquals(model.getContextEntry().get(1),
+                     model.getContextEntry().get(1).getExpression().getParent());
     }
 
     @Test
