@@ -54,6 +54,7 @@ import org.kie.workbench.common.dmn.client.widgets.grid.columns.factory.TextBoxS
 import org.kie.workbench.common.dmn.client.widgets.grid.controls.container.CellEditorControlsView;
 import org.kie.workbench.common.dmn.client.widgets.grid.controls.list.HasListSelectorControl;
 import org.kie.workbench.common.dmn.client.widgets.grid.controls.list.ListSelectorView;
+import org.kie.workbench.common.dmn.client.widgets.grid.model.ExpressionEditorChanged;
 import org.kie.workbench.common.dmn.client.widgets.grid.model.GridCellTuple;
 import org.kie.workbench.common.dmn.client.widgets.grid.model.GridCellValueTuple;
 import org.kie.workbench.common.dmn.client.widgets.layer.DMNGridLayer;
@@ -81,11 +82,13 @@ import org.uberfire.ext.wires.core.grids.client.model.impl.BaseGridData;
 import org.uberfire.ext.wires.core.grids.client.model.impl.BaseHeaderMetaData;
 import org.uberfire.ext.wires.core.grids.client.widget.grid.GridWidget;
 import org.uberfire.ext.wires.core.grids.client.widget.layer.impl.GridLayerRedrawManager;
+import org.uberfire.mocks.EventSourceMock;
 import org.uberfire.mvp.Command;
 
 import static org.assertj.core.api.Assertions.assertThat;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertNull;
 import static org.junit.Assert.assertTrue;
 import static org.kie.workbench.common.dmn.client.editors.expressions.types.GridFactoryCommandUtils.assertCommands;
 import static org.mockito.Matchers.any;
@@ -183,6 +186,9 @@ public class DecisionTableGridTest {
     @Mock
     private Command command;
 
+    @Mock
+    private EventSourceMock<ExpressionEditorChanged> editorSelectedEvent;
+
     @Captor
     private ArgumentCaptor<AddInputClauseCommand> addInputClauseCommandCaptor;
 
@@ -225,6 +231,7 @@ public class DecisionTableGridTest {
                                                             sessionManager,
                                                             sessionCommandManager,
                                                             canvasCommandFactory,
+                                                            editorSelectedEvent,
                                                             cellEditorControls,
                                                             listSelector,
                                                             translationService,
@@ -305,6 +312,13 @@ public class DecisionTableGridTest {
         assertFalse(grid.isHeaderHidden());
     }
 
+    @Test
+    public void testCacheable() {
+        setupGrid(Optional.empty(), 0);
+
+        assertTrue(grid.isCacheable());
+    }
+
     @Test
     public void testColumn0MetaData() {
         setupGrid(makeHasNameForDecision(), 0);
@@ -394,7 +408,7 @@ public class DecisionTableGridTest {
     public void testGetItemsRowNumberColumn() {
         setupGrid(makeHasNameForDecision(), 0);
 
-        assertDefaultListItems(grid.getItems(0, 0));
+        assertDefaultListItems(grid.getItems(0, 0), true);
     }
 
     @Test
@@ -404,14 +418,17 @@ public class DecisionTableGridTest {
         final List<HasListSelectorControl.ListSelectorItem> items = grid.getItems(0, 1);
 
         assertThat(items.size()).isEqualTo(7);
-        assertDefaultListItems(items.subList(4, 7));
+        assertDefaultListItems(items.subList(4, 7), true);
 
         assertListSelectorItem(items.get(INSERT_COLUMN_BEFORE),
-                               DMNEditorConstants.DecisionTableEditor_InsertInputClauseBefore);
+                               DMNEditorConstants.DecisionTableEditor_InsertInputClauseBefore,
+                               true);
         assertListSelectorItem(items.get(INSERT_COLUMN_AFTER),
-                               DMNEditorConstants.DecisionTableEditor_InsertInputClauseAfter);
+                               DMNEditorConstants.DecisionTableEditor_InsertInputClauseAfter,
+                               true);
         assertListSelectorItem(items.get(DELETE_COLUMN),
-                               DMNEditorConstants.DecisionTableEditor_DeleteInputClause);
+                               DMNEditorConstants.DecisionTableEditor_DeleteInputClause,
+                               false);
         assertThat(items.get(DIVIDER)).isInstanceOf(HasListSelectorControl.ListSelectorDividerItem.class);
 
         grid.onItemSelected(items.get(INSERT_COLUMN_BEFORE));
@@ -431,14 +448,17 @@ public class DecisionTableGridTest {
         final List<HasListSelectorControl.ListSelectorItem> items = grid.getItems(0, 2);
 
         assertThat(items.size()).isEqualTo(7);
-        assertDefaultListItems(items.subList(4, 7));
+        assertDefaultListItems(items.subList(4, 7), true);
 
         assertListSelectorItem(items.get(INSERT_COLUMN_BEFORE),
-                               DMNEditorConstants.DecisionTableEditor_InsertOutputClauseBefore);
+                               DMNEditorConstants.DecisionTableEditor_InsertOutputClauseBefore,
+                               true);
         assertListSelectorItem(items.get(INSERT_COLUMN_AFTER),
-                               DMNEditorConstants.DecisionTableEditor_InsertOutputClauseAfter);
+                               DMNEditorConstants.DecisionTableEditor_InsertOutputClauseAfter,
+                               true);
         assertListSelectorItem(items.get(DELETE_COLUMN),
-                               DMNEditorConstants.DecisionTableEditor_DeleteOutputClause);
+                               DMNEditorConstants.DecisionTableEditor_DeleteOutputClause,
+                               false);
         assertThat(items.get(DIVIDER)).isInstanceOf(HasListSelectorControl.ListSelectorDividerItem.class);
 
         grid.onItemSelected(items.get(INSERT_COLUMN_BEFORE));
@@ -455,24 +475,91 @@ public class DecisionTableGridTest {
     public void testGetItemsDescriptionColumn() {
         setupGrid(makeHasNameForDecision(), 0);
 
-        assertDefaultListItems(grid.getItems(0, 3));
+        assertDefaultListItems(grid.getItems(0, 3), true);
     }
 
-    private void assertDefaultListItems(final List<HasListSelectorControl.ListSelectorItem> items) {
+    @Test
+    public void testGetItemsWithCellSelectionsCoveringMultipleRows() {
+        setupGrid(makeHasNameForDecision(), 0);
+
+        addDecisionRule(0);
+        grid.getModel().selectCell(0, 0);
+        grid.getModel().selectCell(1, 0);
+
+        assertDefaultListItems(grid.getItems(0, 0), false);
+    }
+
+    @Test
+    public void testGetItemsInputClauseColumnWithCellSelectionsCoveringMultipleColumns() {
+        setupGrid(makeHasNameForDecision(), 0);
+
+        addInputClause(1);
+        grid.getModel().selectCell(0, 0);
+        grid.getModel().selectCell(0, 1);
+
+        final List<HasListSelectorControl.ListSelectorItem> items = grid.getItems(0, 1);
+
+        assertThat(items.size()).isEqualTo(7);
+        assertDefaultListItems(items.subList(4, 7), true);
+
+        assertListSelectorItem(items.get(INSERT_COLUMN_BEFORE),
+                               DMNEditorConstants.DecisionTableEditor_InsertInputClauseBefore,
+                               false);
+        assertListSelectorItem(items.get(INSERT_COLUMN_AFTER),
+                               DMNEditorConstants.DecisionTableEditor_InsertInputClauseAfter,
+                               false);
+        assertListSelectorItem(items.get(DELETE_COLUMN),
+                               DMNEditorConstants.DecisionTableEditor_DeleteInputClause,
+                               false);
+        assertThat(items.get(DIVIDER)).isInstanceOf(HasListSelectorControl.ListSelectorDividerItem.class);
+    }
+
+    @Test
+    public void testGetItemsOutputClauseColumnWithCellSelectionsCoveringMultipleColumns() {
+        setupGrid(makeHasNameForDecision(), 0);
+
+        addOutputClause(2);
+        grid.getModel().selectCell(0, 0);
+        grid.getModel().selectCell(0, 2);
+
+        final List<HasListSelectorControl.ListSelectorItem> items = grid.getItems(0, 2);
+
+        assertThat(items.size()).isEqualTo(7);
+        assertDefaultListItems(items.subList(4, 7), true);
+
+        assertListSelectorItem(items.get(INSERT_COLUMN_BEFORE),
+                               DMNEditorConstants.DecisionTableEditor_InsertOutputClauseBefore,
+                               false);
+        assertListSelectorItem(items.get(INSERT_COLUMN_AFTER),
+                               DMNEditorConstants.DecisionTableEditor_InsertOutputClauseAfter,
+                               false);
+        assertListSelectorItem(items.get(DELETE_COLUMN),
+                               DMNEditorConstants.DecisionTableEditor_DeleteOutputClause,
+                               false);
+        assertThat(items.get(DIVIDER)).isInstanceOf(HasListSelectorControl.ListSelectorDividerItem.class);
+    }
+
+    private void assertDefaultListItems(final List<HasListSelectorControl.ListSelectorItem> items,
+                                        final boolean enabled) {
         assertThat(items.size()).isEqualTo(3);
         assertListSelectorItem(items.get(DEFAULT_INSERT_RULE_ABOVE),
-                               DMNEditorConstants.DecisionTableEditor_InsertDecisionRuleAbove);
+                               DMNEditorConstants.DecisionTableEditor_InsertDecisionRuleAbove,
+                               enabled);
         assertListSelectorItem(items.get(DEFAULT_INSERT_RULE_BELOW),
-                               DMNEditorConstants.DecisionTableEditor_InsertDecisionRuleBelow);
+                               DMNEditorConstants.DecisionTableEditor_InsertDecisionRuleBelow,
+                               enabled);
         assertListSelectorItem(items.get(DEFAULT_DELETE_RULE),
-                               DMNEditorConstants.DecisionTableEditor_DeleteDecisionRule);
+                               DMNEditorConstants.DecisionTableEditor_DeleteDecisionRule,
+                               enabled && grid.getModel().getRowCount() > 1);
     }
 
     private void assertListSelectorItem(final HasListSelectorControl.ListSelectorItem item,
-                                        final String text) {
+                                        final String text,
+                                        final boolean enabled) {
         assertThat(item).isInstanceOf(HasListSelectorControl.ListSelectorTextItem.class);
         final HasListSelectorControl.ListSelectorTextItem ti = (HasListSelectorControl.ListSelectorTextItem) item;
         assertThat(ti.getText()).isEqualTo(text);
+        assertThat(ti.isEnabled()).isEqualTo(enabled);
     }
 
     @Test
@@ -531,16 +618,20 @@ public class DecisionTableGridTest {
     public void testAddInputClause() {
         setupGrid(makeHasNameForDecision(), 0);
 
-        grid.addInputClause(1);
+        addInputClause(1);
+
+        verify(parent).proposeContainingColumnWidth(eq(grid.getWidth() + grid.getPadding() * 2));
+        verifyGridPanelRefresh();
+    }
+
+    private void addInputClause(final int index) {
+        grid.addInputClause(index);
 
         verify(sessionCommandManager).execute(eq(canvasHandler),
                                               addInputClauseCommandCaptor.capture());
 
         final AddInputClauseCommand addInputClauseCommand = addInputClauseCommandCaptor.getValue();
         addInputClauseCommand.execute(canvasHandler);
-
-        verify(parent).proposeContainingColumnWidth(eq(grid.getWidth() + grid.getPadding() * 2));
-        verifyGridPanelRefresh();
     }
 
     @Test
@@ -563,16 +654,20 @@ public class DecisionTableGridTest {
     public void testAddOutputClause() {
         setupGrid(makeHasNameForDecision(), 0);
 
-        grid.addOutputClause(2);
+        addOutputClause(2);
+
+        verify(parent).proposeContainingColumnWidth(eq(grid.getWidth() + grid.getPadding() * 2));
+        verifyGridPanelRefresh();
+    }
+
+    private void addOutputClause(final int index) {
+        grid.addOutputClause(index);
 
         verify(sessionCommandManager).execute(eq(canvasHandler),
                                               addOutputClauseCommandCaptor.capture());
 
         final AddOutputClauseCommand addOutputClauseCommand = addOutputClauseCommandCaptor.getValue();
         addOutputClauseCommand.execute(canvasHandler);
-
-        verify(parent).proposeContainingColumnWidth(eq(grid.getWidth() + grid.getPadding() * 2));
-        verifyGridPanelRefresh();
     }
 
     @Test
@@ -595,15 +690,19 @@ public class DecisionTableGridTest {
     public void testAddDecisionRule() {
         setupGrid(makeHasNameForDecision(), 0);
 
-        grid.addDecisionRule(0);
+        addDecisionRule(0);
+
+        verifyGridPanelRefresh();
+    }
+
+    private void addDecisionRule(final int index) {
+        grid.addDecisionRule(index);
 
         verify(sessionCommandManager).execute(eq(canvasHandler),
                                               addDecisionRuleCommandCaptor.capture());
 
         final AddDecisionRuleCommand addDecisionRuleCommand = addDecisionRuleCommandCaptor.getValue();
         addDecisionRuleCommand.execute(canvasHandler);
-
-        verifyGridPanelRefresh();
     }
 
     @Test
@@ -634,69 +733,18 @@ public class DecisionTableGridTest {
                                               setHitPolicyCommandCaptor.capture());
 
         final CompositeCommand<AbstractCanvasHandler, CanvasViolation> setHitPolicyCommand = setHitPolicyCommandCaptor.getValue();
-        assertEquals(1,
+        assertEquals(2,
                      setHitPolicyCommand.getCommands().size());
-        assertTrue(setHitPolicyCommand.getCommands().get(0) instanceof SetHitPolicyCommand);
+        assertTrue(setHitPolicyCommand.getCommands().get(0) instanceof SetBuiltinAggregatorCommand);
+        assertTrue(setHitPolicyCommand.getCommands().get(1) instanceof SetHitPolicyCommand);
 
         setHitPolicyCommand.execute(canvasHandler);
 
         verify(gridLayer, atLeast(1)).batch();
         verify(command).execute();
-    }
 
-    @Test
-    public void testSetHitPolicyRequiresBuiltInAggregator() {
-        final HitPolicy hitPolicy = HitPolicy.COLLECT;
-        final BuiltinAggregator aggregator = BuiltinAggregator.SUM;
-
-        setupGrid(makeHasNameForDecision(), 0);
-
-        expression.get().setAggregation(aggregator);
-
-        grid.setHitPolicy(hitPolicy,
-                          command);
-
-        verify(sessionCommandManager).execute(eq(canvasHandler),
-                                              setHitPolicyCommandCaptor.capture());
-
-        final CompositeCommand<AbstractCanvasHandler, CanvasViolation> setHitPolicyCommand = setHitPolicyCommandCaptor.getValue();
-        assertEquals(2,
-                     setHitPolicyCommand.getCommands().size());
-        assertTrue(setHitPolicyCommand.getCommands().get(0) instanceof SetBuiltinAggregatorCommand);
-        assertTrue(setHitPolicyCommand.getCommands().get(1) instanceof SetHitPolicyCommand);
-
-        setHitPolicyCommand.execute(canvasHandler);
-
-        assertEquals(hitPolicy,
-                     expression.get().getHitPolicy());
-        assertEquals(aggregator,
-                     expression.get().getAggregation());
-    }
-
-    @Test
-    public void testSetHitPolicyRequiresBuiltInAggregatorUseDefaultWhenNotSet() {
-        final HitPolicy hitPolicy = HitPolicy.COLLECT;
-
-        setupGrid(makeHasNameForDecision(), 0);
-
-        grid.setHitPolicy(hitPolicy,
-                          command);
-
-        verify(sessionCommandManager).execute(eq(canvasHandler),
-                                              setHitPolicyCommandCaptor.capture());
-
-        final CompositeCommand<AbstractCanvasHandler, CanvasViolation> setHitPolicyCommand = setHitPolicyCommandCaptor.getValue();
-        assertEquals(2,
-                     setHitPolicyCommand.getCommands().size());
-        assertTrue(setHitPolicyCommand.getCommands().get(0) instanceof SetBuiltinAggregatorCommand);
-        assertTrue(setHitPolicyCommand.getCommands().get(1) instanceof SetHitPolicyCommand);
-
-        setHitPolicyCommand.execute(canvasHandler);
-
-        assertEquals(hitPolicy,
-                     expression.get().getHitPolicy());
-        assertEquals(DecisionTableGrid.DEFAULT_AGGREGATOR,
-                     expression.get().getAggregation());
+        assertEquals(hitPolicy, expression.get().getHitPolicy());
+        assertNull(expression.get().getAggregation());
     }
 
     @Test
