@@ -26,7 +26,7 @@ import org.junit.Test;
 import org.junit.runner.RunWith;
 import org.kie.workbench.common.dmn.api.definition.HasExpression;
 import org.kie.workbench.common.dmn.api.definition.HasName;
-import org.kie.workbench.common.dmn.api.definition.v1_1.DMNModelInstrumentedBase;
+import org.kie.workbench.common.dmn.api.definition.v1_1.DMNModelInstrumentedBase.Namespace;
 import org.kie.workbench.common.dmn.api.definition.v1_1.FunctionDefinition;
 import org.kie.workbench.common.dmn.api.definition.v1_1.LiteralExpression;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.ExpressionEditorDefinition;
@@ -37,6 +37,7 @@ import org.kie.workbench.common.dmn.client.resources.i18n.DMNEditorConstants;
 import org.kie.workbench.common.dmn.client.widgets.grid.BaseExpressionGrid;
 import org.kie.workbench.common.dmn.client.widgets.grid.controls.container.CellEditorControlsView;
 import org.kie.workbench.common.dmn.client.widgets.grid.controls.list.ListSelectorView;
+import org.kie.workbench.common.dmn.client.widgets.grid.model.ExpressionEditorChanged;
 import org.kie.workbench.common.dmn.client.widgets.grid.model.GridCellTuple;
 import org.kie.workbench.common.dmn.client.widgets.layer.DMNGridLayer;
 import org.kie.workbench.common.dmn.client.widgets.panel.DMNGridPanel;
@@ -47,6 +48,7 @@ import org.kie.workbench.common.stunner.core.client.command.SessionCommandManage
 import org.kie.workbench.common.stunner.core.util.DefinitionUtils;
 import org.mockito.Mock;
 import org.uberfire.ext.wires.core.grids.client.widget.grid.GridWidget;
+import org.uberfire.mocks.EventSourceMock;
 
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertTrue;
@@ -99,6 +101,9 @@ public class FunctionEditorDefinitionTest {
     @Mock
     private HasExpression hasExpression;
 
+    @Mock
+    private EventSourceMock<ExpressionEditorChanged> editorSelectedEvent;
+
     private Optional<HasName> hasName = Optional.empty();
 
     private FunctionEditorDefinition definition;
@@ -112,6 +117,7 @@ public class FunctionEditorDefinitionTest {
                                                        sessionManager,
                                                        sessionCommandManager,
                                                        canvasCommandFactory,
+                                                       editorSelectedEvent,
                                                        cellEditorControls,
                                                        listSelector,
                                                        translationService,
@@ -144,7 +150,7 @@ public class FunctionEditorDefinitionTest {
         assertTrue(oModel.isPresent());
 
         final FunctionDefinition model = oModel.get();
-        assertEquals(DMNModelInstrumentedBase.URI_KIE,
+        assertEquals(Namespace.KIE.getUri(),
                      model.getNsContext().get(FunctionDefinition.DROOLS_PREFIX));
         assertEquals(FunctionDefinition.Kind.FEEL.code(),
                      model.getAdditionalAttributes().get(FunctionDefinition.KIND_QNAME));
