@@ -27,6 +27,7 @@ import org.junit.Test;
 import org.junit.runner.RunWith;
 import org.kie.workbench.common.dmn.api.definition.HasExpression;
 import org.kie.workbench.common.dmn.api.definition.HasName;
+import org.kie.workbench.common.dmn.api.definition.v1_1.Context;
 import org.kie.workbench.common.dmn.api.definition.v1_1.Decision;
 import org.kie.workbench.common.dmn.api.definition.v1_1.Expression;
 import org.kie.workbench.common.dmn.api.definition.v1_1.FunctionDefinition;
@@ -46,6 +47,9 @@ import org.kie.workbench.common.dmn.client.editors.expressions.types.ExpressionT
 import org.kie.workbench.common.dmn.client.editors.expressions.types.context.ExpressionCellValue;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.context.ExpressionEditorColumn;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.function.parameters.ParametersEditorView;
+import org.kie.workbench.common.dmn.client.editors.expressions.types.function.supplementary.FunctionSupplementaryGrid;
+import org.kie.workbench.common.dmn.client.editors.expressions.types.literal.LiteralExpressionEditorDefinition;
+import org.kie.workbench.common.dmn.client.editors.expressions.types.literal.LiteralExpressionGrid;
 import org.kie.workbench.common.dmn.client.resources.i18n.DMNEditorConstants;
 import org.kie.workbench.common.dmn.client.widgets.grid.BaseExpressionGrid;
 import org.kie.workbench.common.dmn.client.widgets.grid.columns.factory.TextBoxSingletonDOMElementFactory;
@@ -53,6 +57,7 @@ import org.kie.workbench.common.dmn.client.widgets.grid.controls.container.CellE
 import org.kie.workbench.common.dmn.client.widgets.grid.controls.list.HasListSelectorControl;
 import org.kie.workbench.common.dmn.client.widgets.grid.controls.list.ListSelectorView;
 import org.kie.workbench.common.dmn.client.widgets.grid.model.DMNGridData;
+import org.kie.workbench.common.dmn.client.widgets.grid.model.ExpressionEditorChanged;
 import org.kie.workbench.common.dmn.client.widgets.grid.model.GridCellTuple;
 import org.kie.workbench.common.dmn.client.widgets.grid.model.GridCellValueTuple;
 import org.kie.workbench.common.dmn.client.widgets.layer.DMNGridLayer;
@@ -76,6 +81,7 @@ import org.uberfire.ext.wires.core.grids.client.model.impl.BaseGridCellValue;
 import org.uberfire.ext.wires.core.grids.client.model.impl.BaseGridData;
 import org.uberfire.ext.wires.core.grids.client.widget.grid.GridWidget;
 import org.uberfire.ext.wires.core.grids.client.widget.layer.impl.GridLayerRedrawManager;
+import org.uberfire.mocks.EventSourceMock;
 import org.uberfire.mvp.Command;
 
 import static org.assertj.core.api.Assertions.assertThat;
@@ -90,6 +96,7 @@ import static org.mockito.Matchers.eq;
 import static org.mockito.Mockito.doAnswer;
 import static org.mockito.Mockito.doReturn;
 import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.reset;
 import static org.mockito.Mockito.spy;
 import static org.mockito.Mockito.verify;
 import static org.mockito.Mockito.when;
@@ -173,20 +180,33 @@ public class FunctionGridTest {
     private HasExpression hasExpression;
 
     @Mock
-    private ExpressionEditorDefinition literalExpressionEditorDefinition;
-
-    @Mock
-    private BaseExpressionGrid literalExpressionEditor;
-
-    private LiteralExpression literalExpression = new LiteralExpression();
+    private EventSourceMock<ExpressionEditorChanged> editorSelectedEvent;
 
     @Mock
     private ExpressionEditorDefinition supplementaryLiteralExpressionEditorDefinition;
 
     @Mock
-    private GridWidget supplementaryLiteralExpressionEditor;
+    private FunctionSupplementaryGrid supplementaryLiteralExpressionEditor;
 
-    private LiteralExpression supplementaryLiteralExpression = new LiteralExpression();
+    @Mock
+    private Command onSuccess;
+
+    private Context supplementaryLiteralExpression = new Context();
+
+    @Captor
+    private ArgumentCaptor<AddParameterCommand> addParameterCommandCaptor;
+
+    @Captor
+    private ArgumentCaptor<RemoveParameterCommand> removeParameterCommandCaptor;
+
+    @Captor
+    private ArgumentCaptor<UpdateParameterNameCommand> updateParameterNameCommandCaptor;
+
+    @Captor
+    private ArgumentCaptor<SetKindCommand> setKindCommandCaptor;
+
+    @Captor
+    private ArgumentCaptor<ClearExpressionTypeCommand> clearExpressionTypeCommandCaptor;
 
     @Captor
     private ArgumentCaptor<Optional<Expression>> expressionCaptor;
@@ -197,6 +217,17 @@ public class FunctionGridTest {
     @Captor
     private ArgumentCaptor<GridLayerRedrawManager.PrioritizedCommand> redrawCaptor;
 
+    @Captor
+    private ArgumentCaptor<GridCellTuple> parentCaptor;
+
+    @Captor
+    private ArgumentCaptor<Optional<LiteralExpression>> literalExpressionCaptor;
+
+    @Captor
+    private ArgumentCaptor<Optional<Context>> contextExpressionCaptor;
+
+    private LiteralExpressionEditorDefinition literalExpressionEditorDefinition;
+
     private Optional<FunctionDefinition> expression = Optional.empty();
 
     private Optional<HasName> hasName = Optional.empty();
@@ -219,12 +250,23 @@ public class FunctionGridTest {
                                                   sessionManager,
                                                   sessionCommandManager,
                                                   canvasCommandFactory,
+                                                  editorSelectedEvent,
                                                   cellEditorControls,
                                                   listSelector,
                                                   translationService,
                                                   expressionEditorDefinitionsSupplier,
                                                   supplementaryEditorDefinitionsSupplier,
                                                   parametersEditor);
+        literalExpressionEditorDefinition = spy(new LiteralExpressionEditorDefinition(gridPanel,
+                                                                                      gridLayer,
+                                                                                      definitionUtils,
+                                                                                      sessionManager,
+                                                                                      sessionCommandManager,
+                                                                                      canvasCommandFactory,
+                                                                                      editorSelectedEvent,
+                                                                                      cellEditorControls,
+                                                                                      listSelector,
+                                                                                      translationService));
 
         expression = definition.getModelClass();
         expression.get().getFormalParameter().add(parameter);
@@ -232,7 +274,7 @@ public class FunctionGridTest {
 
         final ExpressionEditorDefinitions expressionEditorDefinitions = new ExpressionEditorDefinitions();
         expressionEditorDefinitions.add((ExpressionEditorDefinition) definition);
-        expressionEditorDefinitions.add(literalExpressionEditorDefinition);
+        expressionEditorDefinitions.add((ExpressionEditorDefinition) literalExpressionEditorDefinition);
         expressionEditorDefinitions.add(supplementaryLiteralExpressionEditorDefinition);
 
         final Decision decision = new Decision();
@@ -242,15 +284,6 @@ public class FunctionGridTest {
         doReturn(expressionEditorDefinitions).when(expressionEditorDefinitionsSupplier).get();
         doReturn(expressionEditorDefinitions).when(supplementaryEditorDefinitionsSupplier).get();
 
-        doReturn(ExpressionType.LITERAL_EXPRESSION).when(literalExpressionEditorDefinition).getType();
-        doReturn(Optional.of(literalExpression)).when(literalExpressionEditorDefinition).getModelClass();
-        doReturn(Optional.of(literalExpressionEditor)).when(literalExpressionEditorDefinition).getEditor(any(GridCellTuple.class),
-                                                                                                         any(Optional.class),
-                                                                                                         any(HasExpression.class),
-                                                                                                         any(Optional.class),
-                                                                                                         any(Optional.class),
-                                                                                                         anyInt());
-
         doReturn(Optional.of(supplementaryLiteralExpression)).when(supplementaryLiteralExpressionEditorDefinition).getModelClass();
         doReturn(Optional.of(supplementaryLiteralExpressionEditor)).when(supplementaryLiteralExpressionEditorDefinition).getEditor(any(GridCellTuple.class),
                                                                                                                                    any(Optional.class),
@@ -258,8 +291,6 @@ public class FunctionGridTest {
                                                                                                                                    any(Optional.class),
                                                                                                                                    any(Optional.class),
                                                                                                                                    anyInt());
-        final GridData uiLiteralExpressionModel = new BaseGridData();
-        doReturn(uiLiteralExpressionModel).when(literalExpressionEditor).getModel();
 
         doReturn(session).when(sessionManager).getCurrentSession();
         doReturn(canvasHandler).when(session).getCanvasHandler();
@@ -273,6 +304,8 @@ public class FunctionGridTest {
                                                       anyString(),
                                                       any())).thenReturn(mock(UpdateElementPropertyCommand.class));
 
+        when(parent.getGridWidget()).thenReturn(mock(GridWidget.class));
+
         doAnswer((i) -> i.getArguments()[0].toString()).when(translationService).format(anyString());
     }
 
@@ -301,8 +334,7 @@ public class FunctionGridTest {
 
         assertTrue(uiModel.getCell(0, 0).getValue() instanceof ExpressionCellValue);
         final ExpressionCellValue dcv = (ExpressionCellValue) uiModel.getCell(0, 0).getValue();
-        assertEquals(literalExpressionEditor,
-                     dcv.getValue().get());
+        assertTrue(dcv.getValue().get() instanceof LiteralExpressionGrid);
     }
 
     @Test
@@ -319,6 +351,13 @@ public class FunctionGridTest {
         assertFalse(grid.isHeaderHidden());
     }
 
+    @Test
+    public void testCacheable() {
+        setupGrid(0);
+
+        assertTrue(grid.isCacheable());
+    }
+
     @Test
     public void testColumnMetaData() {
         setupGrid(0);
@@ -359,7 +398,7 @@ public class FunctionGridTest {
         ((HasListSelectorControl.ListSelectorTextItem) items.get(CLEAR_EXPRESSION_TYPE)).getCommand().execute();
         verify(cellEditorControls).hide();
         verify(sessionCommandManager).execute(eq(canvasHandler),
-                                              any(org.kie.workbench.common.dmn.client.commands.general.ClearExpressionTypeCommand.class));
+                                              any(ClearExpressionTypeCommand.class));
     }
 
     @Test
@@ -465,10 +504,16 @@ public class FunctionGridTest {
     public void testAddParameter() {
         setupGrid(0);
 
-        grid.addParameter(() -> {/*Nothing*/});
+        grid.addParameter(onSuccess);
 
         verify(sessionCommandManager).execute(eq(canvasHandler),
-                                              any(AddParameterCommand.class));
+                                              addParameterCommandCaptor.capture());
+
+        final AddParameterCommand addParameterCommand = addParameterCommandCaptor.getValue();
+        addParameterCommand.execute(canvasHandler);
+
+        verify(gridLayer).batch();
+        verify(onSuccess).execute();
     }
 
     @Test
@@ -476,10 +521,16 @@ public class FunctionGridTest {
         setupGrid(0);
 
         grid.removeParameter(parameter,
-                             () -> {/*Nothing*/});
+                             onSuccess);
 
         verify(sessionCommandManager).execute(eq(canvasHandler),
-                                              any(RemoveParameterCommand.class));
+                                              removeParameterCommandCaptor.capture());
+
+        final RemoveParameterCommand removeParameterCommand = removeParameterCommandCaptor.getValue();
+        removeParameterCommand.execute(canvasHandler);
+
+        verify(gridLayer).batch();
+        verify(onSuccess).execute();
     }
 
     @Test
@@ -490,21 +541,40 @@ public class FunctionGridTest {
                                  "name");
 
         verify(sessionCommandManager).execute(eq(canvasHandler),
-                                              any(UpdateParameterNameCommand.class));
+                                              updateParameterNameCommandCaptor.capture());
+
+        final UpdateParameterNameCommand updateParameterNameCommand = updateParameterNameCommandCaptor.getValue();
+        updateParameterNameCommand.execute(canvasHandler);
+
+        verify(gridLayer).batch();
     }
 
     @Test
     public void testSetKindFEEL() {
         setupGrid(0);
 
+        reset(literalExpressionEditorDefinition);
+
         grid.setKind(FunctionDefinition.Kind.FEEL);
 
+        verify(literalExpressionEditorDefinition).getEditor(parentCaptor.capture(),
+                                                            eq(Optional.empty()),
+                                                            eq(hasExpression),
+                                                            literalExpressionCaptor.capture(),
+                                                            eq(hasName),
+                                                            eq(1));
+
+        final Optional<LiteralExpression> literalExpression = literalExpressionCaptor.getValue();
+        //Since we're using a concrete LiteralExpressionEditorDefinition we can only check the model is present
+        assertTrue(literalExpression.isPresent());
+
         assertSetKind(FunctionDefinition.Kind.FEEL,
-                      literalExpression,
-                      literalExpressionEditor);
+                      LiteralExpression.class,
+                      LiteralExpressionGrid.class);
     }
 
     @Test
+    @SuppressWarnings("unchecked")
     public void testSetKindJava() {
         setupGrid(0);
 
@@ -512,12 +582,24 @@ public class FunctionGridTest {
 
         grid.setKind(FunctionDefinition.Kind.JAVA);
 
+        verify(supplementaryLiteralExpressionEditorDefinition).getEditor(parentCaptor.capture(),
+                                                                         eq(Optional.empty()),
+                                                                         eq(hasExpression),
+                                                                         contextExpressionCaptor.capture(),
+                                                                         eq(hasName),
+                                                                         eq(1));
+
+        final Optional<Context> contextExpression = contextExpressionCaptor.getValue();
+        assertTrue(contextExpression.isPresent());
+        assertEquals(supplementaryLiteralExpression, contextExpression.get());
+
         assertSetKind(FunctionDefinition.Kind.JAVA,
-                      supplementaryLiteralExpression,
-                      supplementaryLiteralExpressionEditor);
+                      Context.class,
+                      FunctionSupplementaryGrid.class);
     }
 
     @Test
+    @SuppressWarnings("unchecked")
     public void testSetKindPMML() {
         setupGrid(0);
 
@@ -525,25 +607,44 @@ public class FunctionGridTest {
 
         grid.setKind(FunctionDefinition.Kind.PMML);
 
+        verify(supplementaryLiteralExpressionEditorDefinition).getEditor(parentCaptor.capture(),
+                                                                         eq(Optional.empty()),
+                                                                         eq(hasExpression),
+                                                                         contextExpressionCaptor.capture(),
+                                                                         eq(hasName),
+                                                                         eq(1));
+
+        final Optional<Context> contextExpression = contextExpressionCaptor.getValue();
+        assertTrue(contextExpression.isPresent());
+        assertEquals(supplementaryLiteralExpression, contextExpression.get());
+
         assertSetKind(FunctionDefinition.Kind.PMML,
-                      supplementaryLiteralExpression,
-                      supplementaryLiteralExpressionEditor);
+                      Context.class,
+                      FunctionSupplementaryGrid.class);
     }
 
     private void assertSetKind(final FunctionDefinition.Kind expectedKind,
-                               final Expression expectedExpression,
-                               final GridWidget expectedEditor) {
+                               final Class<?> expectedExpressionType,
+                               final Class<?> expectedEditorType) {
         verify(grid).doSetKind(eq(expectedKind),
                                eq(expression.get()),
                                expressionCaptor.capture(),
                                gridWidgetCaptor.capture());
-        assertEquals(expectedExpression,
-                     expressionCaptor.getValue().get());
-        assertEquals(expectedEditor,
-                     gridWidgetCaptor.getValue().get());
+        assertTrue(expectedExpressionType.isAssignableFrom(expressionCaptor.getValue().get().getClass()));
+        assertTrue(expectedEditorType.isAssignableFrom(gridWidgetCaptor.getValue().get().getClass()));
 
         verify(sessionCommandManager).execute(eq(canvasHandler),
-                                              any(SetKindCommand.class));
+                                              setKindCommandCaptor.capture());
+
+        final SetKindCommand setKindCommand = setKindCommandCaptor.getValue();
+        setKindCommand.execute(canvasHandler);
+
+        verify(grid).resizeBasedOnCellExpressionEditor(eq(0), eq(0));
+
+        final GridCellTuple parent = parentCaptor.getValue();
+        assertEquals(grid, parent.getGridWidget());
+        assertEquals(0, parent.getRowIndex());
+        assertEquals(0, parent.getColumnIndex());
     }
 
     @Test
@@ -553,21 +654,25 @@ public class FunctionGridTest {
         grid.clearExpressionType();
 
         verify(sessionCommandManager).execute(eq(canvasHandler),
-                                              any(ClearExpressionTypeCommand.class));
+                                              clearExpressionTypeCommandCaptor.capture());
+
+        final ClearExpressionTypeCommand clearExpressionTypeCommand = clearExpressionTypeCommandCaptor.getValue();
+        clearExpressionTypeCommand.execute(canvasHandler);
+
+        verify(grid).resizeBasedOnCellExpressionEditor(eq(0),
+                                                       eq(0));
     }
 
     @Test
-    public void testSynchroniseViewWhenExpressionEditorChanged() {
+    public void testResizeWhenExpressionEditorChanged() {
         setupGrid(0);
 
-        final double literalWidth = 123.0;
-        final double literalPadding = 1.0;
-        final double columnWidth = literalWidth + 2 * literalPadding;
+        final double literalWidth = 200.0;
+        final double columnWidth = literalWidth + 2 * grid.getPadding();
 
-        doReturn(literalWidth).when(literalExpressionEditor).getWidth();
-        doReturn(literalPadding).when(literalExpressionEditor).getPadding();
+        grid.getModel().getColumns().get(0).setWidth(literalWidth);
 
-        grid.synchroniseViewWhenExpressionEditorChanged(literalExpressionEditor);
+        grid.resizeWhenExpressionEditorChanged();
 
         verify(parent).onResize();
         verify(parent).proposeContainingColumnWidth(columnWidth);
@@ -579,7 +684,7 @@ public class FunctionGridTest {
         command.execute();
 
         verify(gridLayer).draw();
-        verify(gridLayer).select(eq(literalExpressionEditor));
+        verify(gridLayer).select(eq(grid));
     }
 
     @Test
@@ -603,4 +708,4 @@ public class FunctionGridTest {
         assertCommands(factory.getHasValueCommand().apply(tupleWithValue),
                        SetHeaderValueCommand.class, UpdateElementPropertyCommand.class);
     }
-}
+}
\ No newline at end of file
