@@ -41,12 +41,13 @@ import org.kie.workbench.common.dmn.client.commands.general.DeleteHeaderValueCom
 import org.kie.workbench.common.dmn.client.commands.general.SetCellValueCommand;
 import org.kie.workbench.common.dmn.client.commands.general.SetHeaderValueCommand;
 import org.kie.workbench.common.dmn.client.resources.i18n.DMNEditorConstants;
-import org.kie.workbench.common.dmn.client.session.DMNClientFullSession;
+import org.kie.workbench.common.dmn.client.session.DMNEditorSession;
 import org.kie.workbench.common.dmn.client.widgets.grid.columns.factory.TextAreaSingletonDOMElementFactory;
 import org.kie.workbench.common.dmn.client.widgets.grid.columns.factory.TextBoxSingletonDOMElementFactory;
 import org.kie.workbench.common.dmn.client.widgets.grid.controls.container.CellEditorControlsView;
 import org.kie.workbench.common.dmn.client.widgets.grid.controls.list.HasListSelectorControl;
 import org.kie.workbench.common.dmn.client.widgets.grid.controls.list.ListSelectorView;
+import org.kie.workbench.common.dmn.client.widgets.grid.model.ExpressionEditorChanged;
 import org.kie.workbench.common.dmn.client.widgets.grid.model.GridCellTuple;
 import org.kie.workbench.common.dmn.client.widgets.grid.model.GridCellValueTuple;
 import org.kie.workbench.common.dmn.client.widgets.layer.DMNGridLayer;
@@ -67,6 +68,7 @@ import org.uberfire.ext.wires.core.grids.client.model.impl.BaseGridRow;
 import org.uberfire.ext.wires.core.grids.client.widget.grid.GridWidget;
 import org.uberfire.ext.wires.core.grids.client.widget.grid.columns.RowNumberColumn;
 import org.uberfire.ext.wires.core.grids.client.widget.layer.impl.GridLayerRedrawManager;
+import org.uberfire.mocks.EventSourceMock;
 import org.uberfire.mvp.Command;
 
 import static org.assertj.core.api.Assertions.assertThat;
@@ -134,7 +136,7 @@ public class RelationGridTest {
     private SessionManager sessionManager;
 
     @Mock
-    private DMNClientFullSession dmnClientFullSession;
+    private DMNEditorSession dmnEditorSession;
 
     @Mock
     private AbstractCanvasHandler canvasHandler;
@@ -154,6 +156,9 @@ public class RelationGridTest {
     @Mock
     private TranslationService translationService;
 
+    @Mock
+    private EventSourceMock<ExpressionEditorChanged> editorSelectedEvent;
+
     @Captor
     private ArgumentCaptor<AddRelationColumnCommand> addColumnCommand;
 
@@ -189,6 +194,7 @@ public class RelationGridTest {
                                                   sessionManager,
                                                   sessionCommandManager,
                                                   canvasCommandFactory,
+                                                  editorSelectedEvent,
                                                   cellEditorControls,
                                                   listSelector,
                                                   translationService);
@@ -198,8 +204,8 @@ public class RelationGridTest {
         hasName = Optional.of(decision);
         expression = definition.getModelClass();
 
-        doReturn(canvasHandler).when(dmnClientFullSession).getCanvasHandler();
-        doReturn(dmnClientFullSession).when(sessionManager).getCurrentSession();
+        doReturn(canvasHandler).when(dmnEditorSession).getCanvasHandler();
+        doReturn(dmnEditorSession).when(sessionManager).getCurrentSession();
         doReturn(parentGridData).when(parentGridWidget).getModel();
         doReturn(Collections.singletonList(parentGridColumn)).when(parentGridData).getColumns();
 
@@ -311,6 +317,13 @@ public class RelationGridTest {
         assertFalse(grid.isHeaderHidden());
     }
 
+    @Test
+    public void testCacheable() {
+        setupGrid(0);
+
+        assertTrue(grid.isCacheable());
+    }
+
     @Test
     public void testGetItems() {
         setupGrid(0);
@@ -484,6 +497,32 @@ public class RelationGridTest {
         assertListSelectorItemEnabled(1, 0, DELETE_ROW, true);
     }
 
+    @Test
+    public void testGetItemsWithCellSelectionsCoveringMultipleRows() {
+        setupGrid(0);
+
+        addRow(0);
+        grid.getModel().selectCell(0, 0);
+        grid.getModel().selectCell(1, 0);
+
+        assertListSelectorItemEnabled(0, 0, INSERT_ROW_ABOVE, false);
+        assertListSelectorItemEnabled(0, 0, INSERT_ROW_BELOW, false);
+        assertListSelectorItemEnabled(0, 0, DELETE_ROW, false);
+    }
+
+    @Test
+    public void testGetItemsWithCellSelectionsCoveringMultipleColumns() {
+        setupGrid(0);
+
+        addColumn(0);
+        grid.getModel().selectCell(0, 0);
+        grid.getModel().selectCell(0, 1);
+
+        assertListSelectorItemEnabled(0, 0, INSERT_COLUMN_BEFORE, false);
+        assertListSelectorItemEnabled(0, 0, INSERT_COLUMN_AFTER, false);
+        assertListSelectorItemEnabled(0, 0, DELETE_COLUMN, false);
+    }
+
     private void assertListSelectorItemEnabled(final int uiRowIndex,
                                                final int uiColumnIndex,
                                                final int listItemIndex,
@@ -497,11 +536,8 @@ public class RelationGridTest {
     public void testAddColumn() throws Exception {
         setupGrid(0);
 
-        grid.addColumn(0);
+        addColumn(0);
 
-        verify(sessionCommandManager).execute(eq(canvasHandler), addColumnCommand.capture());
-
-        addColumnCommand.getValue().execute(canvasHandler);
         verify(parent).proposeContainingColumnWidth(grid.getWidth() + grid.getPadding() * 2);
         verify(parentGridColumn).setWidth(grid.getWidth() + grid.getPadding() * 2);
         verify(gridLayer).batch(any(GridLayerRedrawManager.PrioritizedCommand.class));
@@ -509,6 +545,14 @@ public class RelationGridTest {
         verify(gridPanel).updatePanelSize();
     }
 
+    private void addColumn(final int index) {
+        grid.addColumn(index);
+
+        verify(sessionCommandManager).execute(eq(canvasHandler), addColumnCommand.capture());
+
+        addColumnCommand.getValue().execute(canvasHandler);
+    }
+
     @Test
     public void testDeleteColumn() throws Exception {
         relation.getColumn().add(new InformationItem());
@@ -531,14 +575,19 @@ public class RelationGridTest {
     public void testAddRow() throws Exception {
         setupGrid(0);
 
-        grid.addRow(0);
+        addRow(0);
+
+        verify(gridLayer).batch(any(GridLayerRedrawManager.PrioritizedCommand.class));
+        verify(gridPanel).refreshScrollPosition();
+        verify(gridPanel).updatePanelSize();
+    }
+
+    private void addRow(final int index) {
+        grid.addRow(index);
 
         verify(sessionCommandManager).execute(eq(canvasHandler), addRowCommand.capture());
 
         addRowCommand.getValue().execute(canvasHandler);
-        verify(gridLayer).batch(any(GridLayerRedrawManager.PrioritizedCommand.class));
-        verify(gridPanel).refreshScrollPosition();
-        verify(gridPanel).updatePanelSize();
     }
 
     @Test
