@@ -21,6 +21,8 @@ import java.util.List;
 import java.util.Optional;
 import java.util.function.Supplier;
 
+import com.ait.lienzo.client.core.event.NodeMouseClickEvent;
+import com.ait.lienzo.client.core.event.NodeMouseClickHandler;
 import com.ait.lienzo.test.LienzoMockitoTestRunner;
 import org.jboss.errai.ui.client.local.spi.TranslationService;
 import org.junit.Before;
@@ -30,19 +32,24 @@ import org.kie.workbench.common.dmn.api.definition.HasExpression;
 import org.kie.workbench.common.dmn.api.definition.HasName;
 import org.kie.workbench.common.dmn.api.definition.v1_1.Expression;
 import org.kie.workbench.common.dmn.api.definition.v1_1.LiteralExpression;
-import org.kie.workbench.common.dmn.client.commands.general.SetCellValueCommand;
+import org.kie.workbench.common.dmn.client.commands.expressions.types.undefined.SetCellValueCommand;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.ExpressionEditorDefinition;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.ExpressionEditorDefinitions;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.ExpressionType;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.context.ContextGrid;
+import org.kie.workbench.common.dmn.client.editors.expressions.types.context.ExpressionCellValue;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.literal.LiteralExpressionCell;
+import org.kie.workbench.common.dmn.client.session.DMNEditorSession;
 import org.kie.workbench.common.dmn.client.widgets.grid.BaseExpressionGrid;
+import org.kie.workbench.common.dmn.client.widgets.grid.ExpressionGridCache;
+import org.kie.workbench.common.dmn.client.widgets.grid.ExpressionGridCacheImpl;
 import org.kie.workbench.common.dmn.client.widgets.grid.controls.container.CellEditorControlsView;
 import org.kie.workbench.common.dmn.client.widgets.grid.controls.list.HasListSelectorControl;
 import org.kie.workbench.common.dmn.client.widgets.grid.controls.list.HasListSelectorControl.ListSelectorDividerItem;
 import org.kie.workbench.common.dmn.client.widgets.grid.controls.list.HasListSelectorControl.ListSelectorTextItem;
 import org.kie.workbench.common.dmn.client.widgets.grid.controls.list.ListSelectorView;
 import org.kie.workbench.common.dmn.client.widgets.grid.model.DMNGridData;
+import org.kie.workbench.common.dmn.client.widgets.grid.model.ExpressionEditorChanged;
 import org.kie.workbench.common.dmn.client.widgets.grid.model.GridCellTuple;
 import org.kie.workbench.common.dmn.client.widgets.layer.DMNGridLayer;
 import org.kie.workbench.common.dmn.client.widgets.panel.DMNGridPanel;
@@ -50,21 +57,26 @@ import org.kie.workbench.common.stunner.core.client.api.SessionManager;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
 import org.kie.workbench.common.stunner.core.client.command.CanvasCommandFactory;
 import org.kie.workbench.common.stunner.core.client.command.SessionCommandManager;
-import org.kie.workbench.common.stunner.core.client.session.ClientSession;
+import org.kie.workbench.common.stunner.core.client.session.impl.ManagedSession;
 import org.kie.workbench.common.stunner.core.util.DefinitionUtils;
 import org.mockito.ArgumentCaptor;
 import org.mockito.Captor;
 import org.mockito.Mock;
+import org.uberfire.ext.wires.core.grids.client.model.GridCell;
 import org.uberfire.ext.wires.core.grids.client.model.GridData;
 import org.uberfire.ext.wires.core.grids.client.model.impl.BaseGridCell;
 import org.uberfire.ext.wires.core.grids.client.widget.grid.GridWidget;
+import org.uberfire.ext.wires.core.grids.client.widget.layer.GridSelectionManager;
 import org.uberfire.ext.wires.core.grids.client.widget.layer.impl.GridLayerRedrawManager;
+import org.uberfire.mocks.EventSourceMock;
 import org.uberfire.mvp.Command;
 
 import static org.assertj.core.api.Assertions.assertThat;
+import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertTrue;
 import static org.mockito.Matchers.any;
 import static org.mockito.Matchers.anyInt;
+import static org.mockito.Matchers.anyString;
 import static org.mockito.Matchers.eq;
 import static org.mockito.Mockito.doReturn;
 import static org.mockito.Mockito.mock;
@@ -92,7 +104,7 @@ public class UndefinedExpressionGridTest {
     private SessionManager sessionManager;
 
     @Mock
-    private ClientSession session;
+    private DMNEditorSession session;
 
     @Mock
     private AbstractCanvasHandler handler;
@@ -121,6 +133,9 @@ public class UndefinedExpressionGridTest {
     @Mock
     private GridWidget parentGridWidget;
 
+    @Mock
+    private GridData parentGridUiModel;
+
     @Mock
     private HasExpression hasExpression;
 
@@ -130,6 +145,18 @@ public class UndefinedExpressionGridTest {
     @Mock
     private BaseExpressionGrid literalExpressionEditor;
 
+    @Mock
+    private GridSelectionManager selectionManager;
+
+    @Mock
+    private NodeMouseClickEvent mouseClickEvent;
+
+    @Mock
+    private EventSourceMock<ExpressionEditorChanged> editorSelectedEvent;
+
+    @Mock
+    private ManagedSession managedSession;
+
     @Captor
     private ArgumentCaptor<SetCellValueCommand> setCellValueCommandArgumentCaptor;
 
@@ -142,6 +169,8 @@ public class UndefinedExpressionGridTest {
 
     private Optional<HasName> hasName = Optional.empty();
 
+    private ExpressionGridCache expressionGridCache;
+
     private UndefinedExpressionEditorDefinition definition;
 
     private UndefinedExpressionGrid grid;
@@ -149,18 +178,24 @@ public class UndefinedExpressionGridTest {
     @Before
     @SuppressWarnings("unchecked")
     public void setup() {
+        expressionGridCache = spy(new ExpressionGridCacheImpl());
+        when(sessionManager.getCurrentSession()).thenReturn(session);
+        when(session.getExpressionGridCache()).thenReturn(expressionGridCache);
+
         definition = new UndefinedExpressionEditorDefinition(gridPanel,
                                                              gridLayer,
                                                              definitionUtils,
                                                              sessionManager,
                                                              sessionCommandManager,
                                                              canvasCommandFactory,
+                                                             editorSelectedEvent,
                                                              cellEditorControls,
                                                              listSelector,
                                                              translationService,
                                                              expressionEditorDefinitionsSupplier);
 
         expression = definition.getModelClass();
+
         final ExpressionEditorDefinitions expressionEditorDefinitions = new ExpressionEditorDefinitions();
         expressionEditorDefinitions.add(definition);
         expressionEditorDefinitions.add(literalExpressionEditorDefinition);
@@ -176,13 +211,13 @@ public class UndefinedExpressionGridTest {
                                                                                                          any(Optional.class),
                                                                                                          anyInt());
 
-        doReturn(0).when(parent).getRowIndex();
-        doReturn(0).when(parent).getColumnIndex();
-        doReturn(parentGridWidget).when(parent).getGridWidget();
-        doReturn(mock(GridData.class)).when(parentGridWidget).getModel();
-
         doReturn(session).when(sessionManager).getCurrentSession();
         doReturn(handler).when(session).getCanvasHandler();
+
+        when(parentGridWidget.getModel()).thenReturn(parentGridUiModel);
+        when(parent.getGridWidget()).thenReturn(parentGridWidget);
+        when(parent.getRowIndex()).thenReturn(0);
+        when(parent.getColumnIndex()).thenReturn(1);
     }
 
     private void setupGrid(final int nesting) {
@@ -194,6 +229,45 @@ public class UndefinedExpressionGridTest {
                                                                        nesting).get());
     }
 
+    @Test
+    public void testGridMouseClickHandler() {
+        setupGrid(0);
+
+        final NodeMouseClickHandler handler = grid.getGridMouseClickHandler(selectionManager);
+
+        handler.onNodeMouseClick(mouseClickEvent);
+
+        verify(gridLayer).select(parentGridWidget);
+    }
+
+    @Test
+    public void testSelectFirstCell() {
+        setupGrid(0);
+
+        grid.selectFirstCell();
+
+        verify(parentGridUiModel).clearSelections();
+        verify(parentGridUiModel).selectCell(eq(0), eq(1));
+    }
+
+    @Test
+    @SuppressWarnings("unchecked")
+    public void testResizeBasedOnCellExpressionEditor() {
+        setupGrid(0);
+
+        final GridCell parentCell = mock(GridCell.class);
+        final ExpressionCellValue parentValue = mock(ExpressionCellValue.class);
+        final BaseExpressionGrid parentGrid = mock(BaseExpressionGrid.class);
+
+        when(parentGridUiModel.getCell(0, 1)).thenReturn(parentCell);
+        when(parentCell.getValue()).thenReturn(parentValue);
+        when(parentValue.getValue()).thenReturn(Optional.of(parentGrid));
+
+        grid.resizeBasedOnCellExpressionEditor(0, 1);
+
+        verify(parentGrid).resizeWhenExpressionEditorChanged();
+    }
+
     @Test
     public void testInitialSetupFromDefinition() {
         setupGrid(0);
@@ -225,6 +299,13 @@ public class UndefinedExpressionGridTest {
         assertTrue(grid.isHeaderHidden());
     }
 
+    @Test
+    public void testCacheable() {
+        setupGrid(0);
+
+        assertFalse(grid.isCacheable());
+    }
+
     @Test
     public void testPaddingWithParent() {
         setupGrid(0);
@@ -354,18 +435,29 @@ public class UndefinedExpressionGridTest {
     @SuppressWarnings("unchecked")
     public void testOnExpressionTypeChangedWhenNested() {
         assertOnExpressionTypeChanged(1);
+
+        verify(expressionGridCache, never()).getExpressionGrid(anyString());
     }
 
     @Test
     @SuppressWarnings("unchecked")
     public void testOnExpressionTypeChangedWhenNotNested() {
         assertOnExpressionTypeChanged(0);
+
+        verify(expressionGridCache).getExpressionGrid(eq(NODE_UUID));
     }
 
     @SuppressWarnings("unchecked")
     private void assertOnExpressionTypeChanged(final int nesting) {
         setupGrid(nesting);
 
+        final GridCell parentCell = mock(GridCell.class);
+        final ExpressionCellValue parentCellValue = mock(ExpressionCellValue.class);
+        final BaseExpressionGrid parentGridEditor = mock(BaseExpressionGrid.class);
+        when(parentGridUiModel.getCell(anyInt(), anyInt())).thenReturn(parentCell);
+        when(parentCell.getValue()).thenReturn(parentCellValue);
+        when(parentCellValue.getValue()).thenReturn(Optional.of(parentGridEditor));
+
         grid.onExpressionTypeChanged(ExpressionType.LITERAL_EXPRESSION);
 
         verify(literalExpressionEditorDefinition).getEditor(eq(parent),
@@ -381,16 +473,6 @@ public class UndefinedExpressionGridTest {
         final SetCellValueCommand setCellValueCommand = setCellValueCommandArgumentCaptor.getValue();
         setCellValueCommand.execute(handler);
 
-        verify(parent).onResize();
-        verify(gridPanel).refreshScrollPosition();
-        verify(gridPanel).updatePanelSize();
-
-        verify(gridLayer).batch(redrawCommandArgumentCaptor.capture());
-
-        final GridLayerRedrawManager.PrioritizedCommand redrawCommand = redrawCommandArgumentCaptor.getValue();
-        redrawCommand.execute();
-
-        verify(gridLayer).draw();
-        verify(gridLayer).select(eq(literalExpressionEditor));
+        verify(parentGridEditor).resizeWhenExpressionEditorChanged();
     }
 }
