@@ -19,6 +19,7 @@ package org.kie.workbench.common.forms.dynamic.backend.server.context.generation
 import java.util.Arrays;
 import java.util.HashMap;
 import java.util.Map;
+
 import javax.enterprise.context.SessionScoped;
 import javax.inject.Inject;
 
@@ -64,7 +65,7 @@ public class BackendFormRenderingContextManagerImpl implements BackendFormRender
                                                        Map<String, String> params,
                                                        FormDefinition... nestedForms) {
 
-        MapModelRenderingContext clientRenderingContext = new MapModelRenderingContext();
+        MapModelRenderingContext clientRenderingContext = new MapModelRenderingContext(String.valueOf(System.currentTimeMillis()));
 
         clientRenderingContext.setRootForm(rootForm);
 
