@@ -34,11 +34,13 @@ import org.jboss.errai.ioc.client.api.ManagedInstance;
 import org.jboss.errai.ui.client.local.spi.TranslationService;
 import org.kie.workbench.common.forms.dynamic.client.rendering.FieldLayoutComponent;
 import org.kie.workbench.common.forms.editor.client.editor.changes.ChangesNotificationDisplayer;
+import org.kie.workbench.common.forms.editor.client.editor.errorMessage.ErrorMessageDisplayer;
 import org.kie.workbench.common.forms.editor.client.editor.events.FormEditorSyncPaletteEvent;
 import org.kie.workbench.common.forms.editor.client.editor.rendering.EditorFieldLayoutComponent;
 import org.kie.workbench.common.forms.editor.client.resources.i18n.FormEditorConstants;
 import org.kie.workbench.common.forms.editor.client.type.FormDefinitionResourceType;
 import org.kie.workbench.common.forms.editor.model.FormModelerContent;
+import org.kie.workbench.common.forms.editor.model.FormModelerContentError;
 import org.kie.workbench.common.forms.editor.service.shared.FormEditorService;
 import org.kie.workbench.common.forms.model.FieldDefinition;
 import org.kie.workbench.common.forms.model.FormDefinition;
@@ -55,6 +57,7 @@ import org.uberfire.client.annotations.WorkbenchPartTitle;
 import org.uberfire.client.annotations.WorkbenchPartView;
 import org.uberfire.ext.editor.commons.client.file.CommandWithFileNameAndCommitMessage;
 import org.uberfire.ext.editor.commons.client.file.FileNameAndCommitMessage;
+import org.uberfire.ext.editor.commons.client.file.popups.CopyPopUpPresenter;
 import org.uberfire.ext.editor.commons.client.file.popups.RenamePopUpPresenter;
 import org.uberfire.ext.layout.editor.api.editor.LayoutTemplate;
 import org.uberfire.ext.layout.editor.client.api.ComponentRemovedEvent;
@@ -62,6 +65,7 @@ import org.uberfire.ext.layout.editor.client.api.LayoutDragComponentGroup;
 import org.uberfire.ext.layout.editor.client.api.LayoutDragComponentPalette;
 import org.uberfire.ext.layout.editor.client.api.LayoutEditor;
 import org.uberfire.ext.plugin.client.perspective.editor.layout.editor.HTMLLayoutDragComponent;
+import org.uberfire.ext.widgets.common.client.callbacks.DefaultErrorCallback;
 import org.uberfire.ext.widgets.common.client.callbacks.HasBusyIndicatorDefaultErrorCallback;
 import org.uberfire.ext.widgets.common.client.common.BusyIndicatorView;
 import org.uberfire.lifecycle.OnFocus;
@@ -96,12 +100,15 @@ public class FormEditorPresenter extends KieEditor<FormModelerContent> {
     protected LayoutDragComponentPalette layoutDragComponentPalette;
     @Inject
     protected Event<LayoutEditorFocusEvent> layoutFocusEvent;
+
     private ShowAssetUsagesDisplayer showAssetUsagesDisplayer;
     private FormEditorView view;
     private ChangesNotificationDisplayer changesNotificationDisplayer;
     private FormDefinitionResourceType resourceType;
     private Caller<FormEditorService> editorService;
     private TranslationService translationService;
+    private ErrorMessageDisplayer errorMessageDisplayer;
+
     protected boolean setActiveOnLoad = false;
 
     @Inject
@@ -111,7 +118,8 @@ public class FormEditorPresenter extends KieEditor<FormModelerContent> {
                                Caller<FormEditorService> editorService,
                                TranslationService translationService,
                                ManagedInstance<EditorFieldLayoutComponent> editorFieldLayoutComponents,
-                               ShowAssetUsagesDisplayer showAssetUsagesDisplayer) {
+                               ShowAssetUsagesDisplayer showAssetUsagesDisplayer,
+                               ErrorMessageDisplayer errorMessageDisplayer) {
         super(view);
         this.view = view;
         this.changesNotificationDisplayer = changesNotificationDisplayer;
@@ -120,6 +128,7 @@ public class FormEditorPresenter extends KieEditor<FormModelerContent> {
         this.translationService = translationService;
         this.editorFieldLayoutComponents = editorFieldLayoutComponents;
         this.showAssetUsagesDisplayer = showAssetUsagesDisplayer;
+        this.errorMessageDisplayer = errorMessageDisplayer;
     }
 
     @OnStartup
@@ -150,12 +159,7 @@ public class FormEditorPresenter extends KieEditor<FormModelerContent> {
 
     @Override
     protected void loadContent() {
-        editorService.call(new RemoteCallback<FormModelerContent>() {
-                               @Override
-                               public void callback(FormModelerContent content) {
-                                   doLoadContent(content);
-                               }
-                           },
+        editorService.call((RemoteCallback<FormModelerContent>) content -> doLoadContent(content),
                            getNoSuchFileExceptionErrorCallback()).loadContent(versionRecordManager.getCurrentPath());
     }
 
@@ -173,7 +177,7 @@ public class FormEditorPresenter extends KieEditor<FormModelerContent> {
         editorHelper.getFormDefinition().setLayoutTemplate(layoutEditor.getLayout());
     }
 
-    public void doLoadContent(FormModelerContent content) {
+    public void doLoadContent(final FormModelerContent content) {
         busyIndicatorView.hideBusyIndicator();
 
         // Clear LayoutEditor before loading new content.
@@ -183,22 +187,38 @@ public class FormEditorPresenter extends KieEditor<FormModelerContent> {
 
         editorHelper.initHelper(content);
 
-        if (content.getDefinition().getLayoutTemplate() == null) {
-            content.getDefinition().setLayoutTemplate(new LayoutTemplate());
-        }
-
         resetEditorPages(content.getOverview());
 
-        setOriginalHash(content.getDefinition().hashCode());
-
         view.init(this);
 
-        loadLayoutEditor();
+        if (content.getError() != null) {
+            FormModelerContentError error = content.getError();
 
-        view.setupLayoutEditor(layoutEditor);
+            errorMessageDisplayer.show(error.getShortMessage(), error.getFullMessage(), error.getSourceType(), () -> placeManager.forceClosePlace(place));
 
-        changesNotificationDisplayer.show(content,
-                                          this::synchronizeLayoutEditor);
+            errorMessageDisplayer.enableContinue(content.getDefinition() != null);
+        }
+
+        if (content.getDefinition() != null) {
+            loadEditor(content);
+        }
+    }
+
+    private void loadEditor(FormModelerContent content) {
+        if (content.getDefinition() != null) {
+            if (content.getDefinition().getLayoutTemplate() == null) {
+                content.getDefinition().setLayoutTemplate(new LayoutTemplate());
+            }
+
+            setOriginalHash(content.getDefinition().hashCode());
+
+            loadLayoutEditor();
+
+            view.setupLayoutEditor(layoutEditor);
+
+            changesNotificationDisplayer.show(content,
+                                              this::synchronizeLayoutEditor);
+        }
 
         if (setActiveOnLoad) {
             setActiveInstance();
@@ -267,8 +287,7 @@ public class FormEditorPresenter extends KieEditor<FormModelerContent> {
         if (canUpdateProject()) {
             fileMenuBuilder
                     .addSave(versionRecordManager.newSaveMenuItem(() -> saveAction()))
-                    .addCopy(versionRecordManager.getCurrentPath(),
-                             assetUpdateValidator)
+                    .addCopy(this::safeCopy)
                     .addRename(this::safeRename)
                     .addDelete(this::safeDelete);
         }
@@ -283,6 +302,62 @@ public class FormEditorPresenter extends KieEditor<FormModelerContent> {
                              } )*/
     }
 
+    protected void safeCopy() {
+        if (this.isDirty(editorHelper.getContent().getDefinition().hashCode())) {
+
+            view.showSavePopup(versionRecordManager.getCurrentPath(),
+                               () -> copy(true),
+                               () -> copy(false));
+        } else {
+            copy(false);
+        }
+    }
+
+    public void copy(boolean save) {
+        if (save) {
+            synchronizeFormLayout();
+        }
+        copyPopUpPresenter.show(versionRecordManager.getPathToLatest(), assetUpdateValidator, getCopyCommand(save));
+    }
+
+    protected CommandWithFileNameAndCommitMessage getCopyCommand(boolean save) {
+        return details -> copyCommand(details, save);
+    }
+
+    protected void copyCommand(FileNameAndCommitMessage details, boolean save) {
+        view.showBusyIndicator(org.kie.workbench.common.widgets.client.resources.i18n.CommonConstants.INSTANCE.Copying());
+
+        editorService.call(getCopySuccessCallback(copyPopUpPresenter.getView()),
+                           getCopyErrorCallback(copyPopUpPresenter.getView())).copy(versionRecordManager.getPathToLatest(),
+                                                                                    details.getNewFileName(),
+                                                                                    details.getCommitMessage(),
+                                                                                    save,
+                                                                                    editorHelper.getContent(),
+                                                                                    metadata);
+    }
+
+    private RemoteCallback<Path> getCopySuccessCallback(final CopyPopUpPresenter.View copyPopupView) {
+        return response -> {
+            copyPopupView.hide();
+            view.hideBusyIndicator();
+            notification.fire(new NotificationEvent(org.kie.workbench.common.widgets.client.resources.i18n.CommonConstants.INSTANCE.ItemCopiedSuccessfully(),
+                                                    NotificationEvent.NotificationType.SUCCESS));
+        };
+    }
+
+    protected DefaultErrorCallback getCopyErrorCallback(final CopyPopUpPresenter.View copyPopupView) {
+        return new DefaultErrorCallback() {
+
+            @Override
+            public boolean error(final Message message,
+                                 final Throwable throwable) {
+                copyPopupView.hide();
+                return super.error(message,
+                                   throwable);
+            }
+        };
+    }
+
     protected void safeRename() {
 
         if (this.isDirty(editorHelper.getContent().getDefinition().hashCode())) {
@@ -305,8 +380,7 @@ public class FormEditorPresenter extends KieEditor<FormModelerContent> {
     }
 
     protected CommandWithFileNameAndCommitMessage getRenameCommand(boolean save) {
-        return details -> renameCommand(details,
-                                        save);
+        return details -> renameCommand(details, save);
     }
 
     protected void renameCommand(FileNameAndCommitMessage details,
@@ -471,9 +545,9 @@ public class FormEditorPresenter extends KieEditor<FormModelerContent> {
 
     public interface FormEditorView extends KieEditorView {
 
-        public void init(FormEditorPresenter presenter);
+        void init(FormEditorPresenter presenter);
 
-        public void setupLayoutEditor(LayoutEditor layoutEditor);
+        void setupLayoutEditor(LayoutEditor layoutEditor);
 
         void showSavePopup(Path path,
                            Command saveCommand,
