@@ -18,18 +18,21 @@ package org.kie.workbench.common.screens.impl;
 import java.util.Collections;
 import java.util.HashSet;
 import java.util.Set;
+import java.util.stream.Collectors;
+import java.util.stream.StreamSupport;
+
 import javax.enterprise.context.ApplicationScoped;
+import javax.enterprise.inject.Instance;
 import javax.inject.Inject;
 
 import org.guvnor.common.services.project.model.Package;
+import org.kie.workbench.common.screens.library.api.index.Constants;
 import org.kie.workbench.common.screens.library.api.index.LibraryFileNameIndexTerm;
-import org.kie.workbench.common.screens.library.api.index.LibraryModuleRootPathIndexTerm;
+import org.kie.workbench.common.screens.library.api.index.LibraryRepositoryRootIndexTerm;
 import org.kie.workbench.common.services.refactoring.KPropertyImpl;
 import org.kie.workbench.common.services.refactoring.backend.server.indexing.AbstractFileIndexer;
-import org.kie.workbench.common.services.refactoring.backend.server.indexing.DefaultIndexBuilder;
+import org.kie.workbench.common.services.refactoring.backend.server.indexing.IndexBuilder;
 import org.kie.workbench.common.services.refactoring.backend.server.util.KObjectUtil;
-import org.kie.workbench.common.services.refactoring.model.index.terms.ModuleNameIndexTerm;
-import org.kie.workbench.common.services.refactoring.model.index.terms.PackageNameIndexTerm;
 import org.kie.workbench.common.services.shared.project.KieModule;
 import org.kie.workbench.common.services.shared.project.KieModuleService;
 import org.slf4j.Logger;
@@ -40,7 +43,10 @@ import org.uberfire.ext.metadata.model.KObject;
 import org.uberfire.ext.metadata.model.KObjectKey;
 import org.uberfire.ext.metadata.model.KProperty;
 import org.uberfire.io.IOService;
+import org.uberfire.java.nio.file.Files;
 import org.uberfire.java.nio.file.Path;
+import org.uberfire.workbench.annotations.VisibleAsset;
+import org.uberfire.workbench.type.ResourceTypeDefinition;
 
 @ApplicationScoped
 public class LibraryIndexer extends AbstractFileIndexer {
@@ -49,15 +55,19 @@ public class LibraryIndexer extends AbstractFileIndexer {
 
     private static final String LIBRARY_CLASSIFIER = "library";
 
-    private LibraryAssetTypeDefinition filter;
+    private Set<ResourceTypeDefinition> visibleResourceTypes;
 
     // For proxying
     public LibraryIndexer() {
+        visibleResourceTypes = new HashSet<>();
     }
 
     @Inject
-    public LibraryIndexer(final LibraryAssetTypeDefinition filter) {
-        this.filter = filter;
+    public LibraryIndexer(@VisibleAsset final Instance<ResourceTypeDefinition> visibleResourceTypeDefinitions) {
+        this.visibleResourceTypes = StreamSupport
+                .stream(visibleResourceTypeDefinitions.spliterator(),
+                        false)
+                .collect(Collectors.toSet());
     }
 
     void setIOService(final IOService ioService) {
@@ -70,69 +80,60 @@ public class LibraryIndexer extends AbstractFileIndexer {
 
     @Override
     public boolean supportsPath(final Path path) {
-        return filter.accept(Paths.convert(path));
+        return !(this.isFolder(path) || this.isHidden(path)) && this.isSupportedByAnyResourceType(path);
+    }
+
+    private boolean isSupportedByAnyResourceType(Path path) {
+        org.uberfire.backend.vfs.Path convertedPath = convertPath(path);
+        return this.getVisibleResourceTypes()
+                .stream()
+                .anyMatch(resourceTypeDefinition ->
+                                  resourceTypeDefinition.accept(convertedPath));
     }
 
     @Override
-    protected DefaultIndexBuilder fillIndexBuilder(final Path path) throws Exception {
-        final KieModule module = getModule(path);
-        if (module == null) {
-            logger.debug("Unable to index " + path.toUri().toString() + ": module could not be resolved.");
-            return null;
-        }
+    public String getIndexerId() {
+        return Constants.INDEXER_ID;
+    }
 
-        final Package pkg = getPackage(path);
-        if (pkg == null) {
-            logger.debug("Unable to index " + path.toUri().toString() + ": package could not be resolved.");
-            return null;
-        }
+    @Override
+    protected IndexBuilder fillIndexBuilder(final Path path) throws Exception {
+        // responsible for basic index info: file name, project root path
+        final String fileName = Paths.convert(path).getFileName();
+        final String repoRoot = getRootBackendPath(path);
 
-        // responsible for basic index info: module name, branch, etc
-        final DefaultIndexBuilder builder = new DefaultIndexBuilder(Paths.convert(path).getFileName(),
-                                                                    module,
-                                                                    pkg) {
-            @Override
-            public Set<KProperty<?>> build() {
-                final Set<KProperty<?>> indexElements = new HashSet<>();
+        final IndexBuilder builder = () -> {
+            final Set<KProperty<?>> indexElements = new HashSet<>();
 
-                indexElements.add(new KPropertyImpl<>(LibraryFileNameIndexTerm.TERM,
-                                                      fileName));
-                indexElements.add(new KPropertyImpl<>(FieldFactory.FILE_NAME_FIELD_SORTED,
-                                                      fileName.toLowerCase(),
-                                                      false,
-                                                      true));
+            indexElements.add(new KPropertyImpl<>(LibraryFileNameIndexTerm.TERM,
+                                                  fileName));
+            indexElements.add(new KPropertyImpl<>(FieldFactory.FILE_NAME_FIELD_SORTED,
+                                                  fileName.toLowerCase(),
+                                                  false,
+                                                  true));
+            indexElements.add(new KPropertyImpl<>(LibraryRepositoryRootIndexTerm.TERM, repoRoot));
 
-                if (module.getRootPath() != null) {
-                    final String moduleRootUri = module.getRootPath().toURI();
-                    indexElements.add(new KPropertyImpl<>(LibraryModuleRootPathIndexTerm.TERM,
-                                                          moduleRootUri));
-                }
-                if (module.getModuleName() != null) {
-                    final String moduleName = module.getModuleName();
-                    indexElements.add(new KPropertyImpl<>(ModuleNameIndexTerm.TERM,
-                                                          moduleName));
-                }
-
-                if (pkgName == null) {
-                    pkgName = pkg.getPackageName();
-                }
-                if (pkgName != null) {
-                    indexElements.add(new KPropertyImpl<>(PackageNameIndexTerm.TERM,
-                                                          pkgName));
-                }
-                return indexElements;
-            }
+            return indexElements;
         };
         return builder;
     }
 
+    private String getRootBackendPath(final Path path) {
+        Path root = path;
+        while (root.getParent() != null) {
+            root = root.getParent();
+        }
+
+        return Paths.convert(root).toURI();
+    }
+
     @Override
     public KObject toKObject(final Path path) {
         KObject index = null;
 
         try {
             // create a builder with the default information
-            DefaultIndexBuilder builder = fillIndexBuilder(path);
+            IndexBuilder builder = fillIndexBuilder(path);
 
             Set<KProperty<?>> indexElements = null;
             if (builder != null) {
@@ -161,12 +162,28 @@ public class LibraryIndexer extends AbstractFileIndexer {
                                         LIBRARY_CLASSIFIER);
     }
 
+    protected org.uberfire.backend.vfs.Path convertPath(Path path) {
+        return Paths.convert(path);
+    }
+
     protected KieModule getModule(final Path path) {
-        return moduleService.resolveModule(Paths.convert(path));
+        return moduleService.resolveModule(Paths.convert(path), false);
     }
 
     protected Package getPackage(final Path path) {
         return moduleService.resolvePackage(Paths.convert(path));
     }
+
+    protected boolean isFolder(final Path path) {
+        return Files.isDirectory(path);
+    }
+
+    protected boolean isHidden(Path path) {
+        return path.getFileName().startsWith(".");
+    }
+
+    protected Set<ResourceTypeDefinition> getVisibleResourceTypes() {
+        return this.visibleResourceTypes;
+    }
 }
 
