@@ -20,7 +20,9 @@ package org.kie.workbench.common.screens.library.client.screens.project;
 import javax.enterprise.event.Event;
 
 import elemental2.dom.HTMLElement;
+import org.guvnor.common.services.project.client.context.WorkspaceProjectContext;
 import org.guvnor.common.services.project.client.security.ProjectController;
+import org.guvnor.common.services.project.context.WorkspaceProjectContextChangeEvent;
 import org.guvnor.common.services.project.model.Module;
 import org.guvnor.common.services.project.model.WorkspaceProject;
 import org.guvnor.messageconsole.client.console.widget.button.ViewHideAlertsButtonPresenter;
@@ -34,7 +36,6 @@ import org.kie.workbench.common.screens.defaulteditor.client.editor.NewFileUploa
 import org.kie.workbench.common.screens.library.api.LibraryService;
 import org.kie.workbench.common.screens.library.client.screens.ProjectScreenTestBase;
 import org.kie.workbench.common.screens.library.client.screens.assets.AssetsScreen;
-import org.kie.workbench.common.screens.library.client.screens.assets.EmptyAssetsScreen;
 import org.kie.workbench.common.screens.library.client.screens.organizationalunit.contributors.edit.EditContributorsPopUpPresenter;
 import org.kie.workbench.common.screens.library.client.screens.organizationalunit.contributors.tab.ContributorsListPresenter;
 import org.kie.workbench.common.screens.library.client.screens.project.delete.DeleteProjectPopUpScreen;
@@ -56,7 +57,18 @@ import org.uberfire.mocks.CallerMock;
 import org.uberfire.promise.SyncPromises;
 import org.uberfire.workbench.events.NotificationEvent;
 
-import static org.mockito.Mockito.*;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertTrue;
+import static org.mockito.Mockito.any;
+import static org.mockito.Mockito.anyString;
+import static org.mockito.Mockito.doNothing;
+import static org.mockito.Mockito.doReturn;
+import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.never;
+import static org.mockito.Mockito.spy;
+import static org.mockito.Mockito.times;
+import static org.mockito.Mockito.verify;
+import static org.mockito.Mockito.when;
 
 @RunWith(MockitoJUnitRunner.class)
 public class ProjectScreenTest extends ProjectScreenTestBase {
@@ -69,9 +81,6 @@ public class ProjectScreenTest extends ProjectScreenTestBase {
     @Mock
     private LibraryPlaces libraryPlaces;
 
-    @Mock
-    private EmptyAssetsScreen emptyAssetsScree;
-
     @Mock
     private AssetsScreen assetsScreen;
 
@@ -142,6 +151,9 @@ public class ProjectScreenTest extends ProjectScreenTestBase {
     @Mock
     private ViewHideAlertsButtonPresenter.View viewHideAlertsButtonView;
 
+    @Mock
+    private WorkspaceProject workspaceProject;
+
     private SyncPromises promises;
 
     @Before
@@ -156,34 +168,36 @@ public class ProjectScreenTest extends ProjectScreenTestBase {
         when(deleteProjectPopUpScreenInstance.get()).thenReturn(deleteProjectPopUpScreen);
         when(renameProjectPopUpScreenInstance.get()).thenReturn(renameProjectPopUpScreen);
 
-        final WorkspaceProject workspaceProject = mock(WorkspaceProject.class);
         final Module module = mock(Module.class);
-        when(module.getModuleName()).thenReturn("module-name");
+        when(workspaceProject.getName()).thenReturn("module-name");
         when(workspaceProject.getMainModule()).thenReturn(module);
-        when(libraryPlaces.getActiveWorkspaceContext()).thenReturn(workspaceProject);
+        when(libraryPlaces.getActiveWorkspace()).thenReturn(workspaceProject);
 
-        this.presenter = spy(new ProjectScreen(this.view,
-                                               this.libraryPlaces,
-                                               this.emptyAssetsScree,
-                                               this.assetsScreen,
-                                               this.contributorsListScreen,
-                                               this.projectMetrictsScreen,
-                                               this.projectController,
-                                               this.settingsPresenter,
-                                               this.organizationalUnitController,
-                                               this.newFileUploader,
-                                               this.newResourcePresenter,
-                                               this.buildExecutor,
-                                               this.editContributorsPopUpPresenterInstance,
-                                               this.deleteProjectPopUpScreenInstance,
-                                               this.renameProjectPopUpScreenInstance,
-                                               new CallerMock<>(this.libraryService),
-                                               projectScreenServiceCaller,
-                                               copyPopUpPresenter,
-                                               projectNameValidator,
-                                               promises,
-                                               notificationEvent,
-                                               viewHideAlertsButtonPresenter));
+        final WorkspaceProjectContext projectContext = mock(WorkspaceProjectContext.class);
+        when(libraryPlaces.getWorkbenchContext()).thenReturn(projectContext);
+
+        final ProjectScreen projectScreen = new ProjectScreen(this.view,
+                                                              this.libraryPlaces,
+                                                              this.assetsScreen,
+                                                              this.contributorsListScreen,
+                                                              this.projectMetrictsScreen,
+                                                              this.projectController,
+                                                              this.settingsPresenter,
+                                                              this.organizationalUnitController,
+                                                              this.newFileUploader,
+                                                              this.newResourcePresenter,
+                                                              this.buildExecutor,
+                                                              this.editContributorsPopUpPresenterInstance,
+                                                              this.deleteProjectPopUpScreenInstance,
+                                                              this.renameProjectPopUpScreenInstance,
+                                                              new CallerMock<>(this.libraryService),
+                                                              projectScreenServiceCaller,
+                                                              copyPopUpPresenter,
+                                                              projectNameValidator,
+                                                              promises,
+                                                              notificationEvent,
+                                                              viewHideAlertsButtonPresenter);
+        this.presenter = spy(projectScreen);
 
         this.presenter.workspaceProject = createProject();
     }
@@ -198,6 +212,106 @@ public class ProjectScreenTest extends ProjectScreenTestBase {
         verify(view).addMainAction(viewHideAlertsButtonView);
     }
 
+    @Test
+    public void testActionsVisibilityWithPermissionToUpdateProjectOnly() {
+        doReturn(true).when(this.presenter).userCanUpdateProject();
+
+        presenter.initialize();
+
+        verify(view).setAddAssetVisible(true);
+        verify(view).setImportAssetVisible(true);
+        verify(view).setEditContributorsVisible(false);
+        verify(view).setDuplicateVisible(false);
+        verify(view).setReimportVisible(true);
+        verify(view).setDeleteProjectVisible(false);
+        verify(view).setBuildEnabled(false);
+        verify(view).setDeployEnabled(false);
+        verify(view).setActionsVisible(true);
+    }
+
+    @Test
+    public void testActionsVisibilityWithPermissionToUpdateSpaceOnly() {
+        doReturn(true).when(this.presenter).canEditContributors();
+
+        presenter.initialize();
+
+        verify(view).setAddAssetVisible(false);
+        verify(view).setImportAssetVisible(false);
+        verify(view).setEditContributorsVisible(true);
+        verify(view).setDuplicateVisible(false);
+        verify(view).setReimportVisible(false);
+        verify(view).setDeleteProjectVisible(false);
+        verify(view).setBuildEnabled(false);
+        verify(view).setDeployEnabled(false);
+        verify(view).setActionsVisible(true);
+    }
+
+    @Test
+    public void testActionsVisibilityWithPermissionToDeleteProjectOnly() {
+        doReturn(true).when(this.presenter).userCanDeleteProject();
+
+        presenter.initialize();
+
+        verify(view).setAddAssetVisible(false);
+        verify(view).setImportAssetVisible(false);
+        verify(view).setEditContributorsVisible(false);
+        verify(view).setDuplicateVisible(false);
+        verify(view).setReimportVisible(false);
+        verify(view).setDeleteProjectVisible(true);
+        verify(view).setBuildEnabled(false);
+        verify(view).setDeployEnabled(false);
+        verify(view).setActionsVisible(true);
+    }
+
+    @Test
+    public void testActionsVisibilityWithPermissionToBuildProjectOnly() {
+        doReturn(true).when(this.presenter).userCanBuildProject();
+
+        presenter.initialize();
+
+        verify(view).setAddAssetVisible(false);
+        verify(view).setImportAssetVisible(false);
+        verify(view).setEditContributorsVisible(false);
+        verify(view).setDuplicateVisible(false);
+        verify(view).setReimportVisible(false);
+        verify(view).setDeleteProjectVisible(false);
+        verify(view).setBuildEnabled(true);
+        verify(view).setDeployEnabled(true);
+        verify(view).setActionsVisible(true);
+    }
+
+    @Test
+    public void testActionsVisibilityWithPermissionToCreateProjectsOnly() {
+        doReturn(true).when(this.presenter).userCanCreateProjects();
+
+        presenter.initialize();
+
+        verify(view).setAddAssetVisible(false);
+        verify(view).setImportAssetVisible(false);
+        verify(view).setEditContributorsVisible(false);
+        verify(view).setDuplicateVisible(true);
+        verify(view).setReimportVisible(false);
+        verify(view).setDeleteProjectVisible(false);
+        verify(view).setBuildEnabled(false);
+        verify(view).setDeployEnabled(false);
+        verify(view).setActionsVisible(true);
+    }
+
+    @Test
+    public void testActionsVisibilityWithoutAllPermissions() {
+        presenter.initialize();
+
+        verify(view).setAddAssetVisible(false);
+        verify(view).setImportAssetVisible(false);
+        verify(view).setEditContributorsVisible(false);
+        verify(view).setDuplicateVisible(false);
+        verify(view).setReimportVisible(false);
+        verify(view).setDeleteProjectVisible(false);
+        verify(view).setBuildEnabled(false);
+        verify(view).setDeployEnabled(false);
+        verify(view).setActionsVisible(false);
+    }
+
     @Test
     public void testAddAsset() {
         {
@@ -232,23 +346,14 @@ public class ProjectScreenTest extends ProjectScreenTestBase {
 
     @Test
     public void testShowSettings() {
-
         SettingsPresenter.View settingsView = mock(SettingsPresenter.View.class);
         when(settingsView.getElement()).thenReturn(new HTMLElement());
         when(this.settingsPresenter.getView()).thenReturn(settingsView);
+        doReturn(promises.resolve()).when(settingsPresenter).setupUsingCurrentSection();
 
-        {
-            doReturn(false).when(this.presenter).userCanUpdateProject();
-            this.presenter.showSettings();
-            verify(this.settingsPresenter,
-                   never()).onOpen();
-        }
-        {
-            doReturn(true).when(this.presenter).userCanUpdateProject();
-            this.presenter.showSettings();
-            verify(this.settingsPresenter,
-                   times(1)).onOpen();
-        }
+        this.presenter.showSettings();
+
+        verify(view).setContent(any());
     }
 
     @Test
@@ -330,7 +435,7 @@ public class ProjectScreenTest extends ProjectScreenTestBase {
             CommandWithFileNameAndCommitMessage duplicateCommand = mock(CommandWithFileNameAndCommitMessage.class);
             doReturn(duplicateCommand).when(presenter).getDuplicateCommand();
             this.presenter.duplicate();
-            verify(this.copyPopUpPresenter).show(presenter.workspaceProject.getMainModule().getPomXMLPath(),
+            verify(this.copyPopUpPresenter).show(presenter.workspaceProject.getRootPath(),
                                                  projectNameValidator,
                                                  duplicateCommand);
         }
@@ -378,4 +483,48 @@ public class ProjectScreenTest extends ProjectScreenTestBase {
             verify(promises).resolve();
         }
     }
+
+    @Test
+    public void canBuild() throws Exception {
+        doReturn(true).when(projectController).canBuildProject(any(WorkspaceProject.class));
+        assertTrue(presenter.userCanBuildProject());
+    }
+
+    @Test
+    public void notAllowedToBuild() throws Exception {
+        doReturn(false).when(projectController).canBuildProject(any(WorkspaceProject.class));
+        assertFalse(presenter.userCanBuildProject());
+    }
+
+    @Test
+    public void allowedToBuildButNoModule() throws Exception {
+        doReturn(null).when(workspaceProject).getMainModule();
+        presenter.initialize();
+        doReturn(true).when(projectController).canBuildProject(workspaceProject);
+
+        assertFalse(presenter.userCanBuildProject());
+    }
+
+    @Test
+    public void titleIsUpdatedWhenContextModuleIsUpdated() throws Exception {
+        final WorkspaceProject workspaceProject = mock(WorkspaceProject.class);
+        doReturn("module name").when(workspaceProject).getName();
+
+        presenter.changeProjectAndTitleWhenContextChange(new WorkspaceProjectContextChangeEvent(workspaceProject));
+
+        verify(view).setTitle("module name");
+    }
+
+    @Test
+    public void shouldNotChangeProjectAndTitleWhenContextChange() throws Exception {
+
+        presenter.changeProjectAndTitleWhenContextChange(new WorkspaceProjectContextChangeEvent() {
+            @Override
+            public WorkspaceProject getWorkspaceProject() {
+                return null;
+            }
+        });
+
+        verify(view, never()).setTitle(any());
+    }
 }
\ No newline at end of file
