@@ -16,7 +16,12 @@
 
 package org.kie.workbench.common.screens.library.client.util;
 
+import java.util.ArrayList;
+import java.util.HashMap;
+import java.util.List;
+import java.util.Map;
 import java.util.Optional;
+import java.util.Set;
 
 import javax.enterprise.event.Event;
 
@@ -25,8 +30,9 @@ import org.ext.uberfire.social.activities.model.SocialFileSelectedEvent;
 import org.guvnor.common.services.project.client.context.WorkspaceProjectContext;
 import org.guvnor.common.services.project.client.preferences.ProjectScopedResolutionStrategySupplier;
 import org.guvnor.common.services.project.context.WorkspaceProjectContextChangeEvent;
-import org.guvnor.common.services.project.events.RenameModuleEvent;
+import org.guvnor.common.services.project.model.GAV;
 import org.guvnor.common.services.project.model.Module;
+import org.guvnor.common.services.project.model.POM;
 import org.guvnor.common.services.project.model.Package;
 import org.guvnor.common.services.project.model.WorkspaceProject;
 import org.guvnor.common.services.project.service.WorkspaceProjectService;
@@ -36,17 +42,21 @@ import org.guvnor.structure.repositories.Branch;
 import org.guvnor.structure.repositories.Repository;
 import org.jboss.errai.common.client.api.Caller;
 import org.jboss.errai.ioc.client.api.ManagedInstance;
+import org.jboss.errai.security.shared.exception.UnauthorizedException;
 import org.jboss.errai.ui.client.local.spi.TranslationService;
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
+import org.kie.workbench.common.screens.examples.model.ExampleProject;
 import org.kie.workbench.common.screens.explorer.model.URIStructureExplorerModel;
 import org.kie.workbench.common.screens.library.api.LibraryService;
 import org.kie.workbench.common.screens.library.api.ProjectAssetListUpdated;
 import org.kie.workbench.common.screens.library.client.events.AssetDetailEvent;
 import org.kie.workbench.common.screens.library.client.events.WorkbenchProjectMetricsEvent;
 import org.kie.workbench.common.screens.library.client.perspective.LibraryPerspective;
+import org.kie.workbench.common.screens.library.client.screens.importrepository.ImportProjectsSetupEvent;
 import org.kie.workbench.common.screens.library.client.screens.importrepository.ImportRepositoryPopUpPresenter;
+import org.kie.workbench.common.screens.library.client.screens.project.close.CloseUnsavedProjectAssetsPopUpPresenter;
 import org.kie.workbench.common.screens.library.client.widgets.library.LibraryToolbarPresenter;
 import org.kie.workbench.common.services.shared.project.KieModuleService;
 import org.kie.workbench.common.workbench.client.docks.AuthoringWorkbenchDocks;
@@ -56,6 +66,7 @@ import org.mockito.Mock;
 import org.mockito.runners.MockitoJUnitRunner;
 import org.uberfire.backend.vfs.ObservablePath;
 import org.uberfire.backend.vfs.Path;
+import org.uberfire.backend.vfs.PathFactory;
 import org.uberfire.backend.vfs.VFSService;
 import org.uberfire.client.mvp.PlaceManager;
 import org.uberfire.client.mvp.PlaceStatus;
@@ -67,19 +78,22 @@ import org.uberfire.ext.preferences.client.event.PreferencesCentralSaveEvent;
 import org.uberfire.ext.preferences.client.event.PreferencesCentralUndoChangesEvent;
 import org.uberfire.ext.widgets.common.client.breadcrumbs.UberfireBreadcrumbs;
 import org.uberfire.mocks.CallerMock;
+import org.uberfire.mvp.Command;
 import org.uberfire.mvp.PlaceRequest;
 import org.uberfire.mvp.impl.DefaultPlaceRequest;
 import org.uberfire.mvp.impl.PathPlaceRequest;
-import org.uberfire.preferences.shared.impl.PreferenceScopeResolutionStrategyInfo;
 import org.uberfire.workbench.events.NotificationEvent;
 import org.uberfire.workbench.model.PanelDefinition;
 import org.uberfire.workbench.model.impl.PartDefinitionImpl;
 
+import static java.util.Collections.emptyList;
+import static java.util.Collections.singleton;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertNull;
 import static org.mockito.Matchers.any;
 import static org.mockito.Matchers.anyString;
 import static org.mockito.Matchers.eq;
+import static org.mockito.Mockito.doAnswer;
 import static org.mockito.Mockito.doNothing;
 import static org.mockito.Mockito.doReturn;
 import static org.mockito.Mockito.mock;
@@ -164,6 +178,12 @@ public class LibraryPlacesTest {
     @Mock
     private Event<ProjectAssetListUpdated> assetListUpdateEvent;
 
+    @Mock
+    private CloseUnsavedProjectAssetsPopUpPresenter closeUnsavedProjectAssetsPopUpPresenter;
+
+    @Mock
+    private Event<ImportProjectsSetupEvent> projectsSetupEvent;
+
     @Captor
     private ArgumentCaptor<WorkspaceProjectContextChangeEvent> projectContextChangeEventArgumentCaptor;
 
@@ -174,9 +194,11 @@ public class LibraryPlacesTest {
     private Branch activeBranch;
     private Module activeModule;
     private WorkspaceProject activeProject;
+    private HashMap<String, List<String>> windowParameters;
 
     @Before
     public void setup() {
+        windowParameters = new HashMap<>();
         libraryServiceCaller = new CallerMock<>(libraryService);
         vfsServiceCaller = new CallerMock<>(vfsService);
 
@@ -202,7 +224,15 @@ public class LibraryPlacesTest {
                                               projectScopedResolutionStrategySupplier,
                                               preferencesCentralInitializationEvent,
                                               importRepositoryPopUpPresenters,
-                                              assetListUpdateEvent));
+                                              assetListUpdateEvent,
+                                              closeUnsavedProjectAssetsPopUpPresenter,
+                                              projectsSetupEvent) {
+
+            @Override
+            protected Map<String, List<String>> getParameterMap() {
+                return windowParameters;
+            }
+        });
         libraryPlaces.setup();
 
         verify(libraryToolBarView).getElement();
@@ -241,8 +271,6 @@ public class LibraryPlacesTest {
         doReturn(mock(ObservablePath.class)).when(pathPlaceRequest).getPath();
         doReturn(pathPlaceRequest).when(libraryPlaces).createPathPlaceRequest(any());
 
-        doReturn(true).when(placeManager).closeAllPlacesOrNothing();
-
         doReturn(importRepositoryPopUpPresenter).when(importRepositoryPopUpPresenters).get();
     }
 
@@ -296,7 +324,17 @@ public class LibraryPlacesTest {
         verify(libraryPlaces,
                never()).goToProject();
         verify(libraryPlaces,
-               never()).closeAllPlacesOrNothing();
+               never()).closeAllPlacesOrNothing(any());
+    }
+
+    @Test
+    public void onChangeStandaloneActive() {
+        windowParameters.put("standalone", null);
+        when(current.getModule()).thenReturn(null);
+        libraryPlaces.onChange(previous,
+                               current);
+
+        verify(libraryPlaces, never()).goToProject();
     }
 
     @Test
@@ -461,7 +499,7 @@ public class LibraryPlacesTest {
         final WorkspaceProjectContextChangeEvent event = eventArgumentCaptor.getValue();
         assertNull(event.getOrganizationalUnit());
         assertNull(event.getWorkspaceProject());
-        verify(placeManager).closeAllPlacesOrNothing();
+        verify(placeManager).closeAllPlaces();
         verify(placeManager).goTo(eq(part),
                                   any(PanelDefinition.class));
         verify(libraryPlaces).setupLibraryBreadCrumbs();
@@ -597,6 +635,14 @@ public class LibraryPlacesTest {
                never()).fire(any(WorkspaceProjectContextChangeEvent.class));
     }
 
+    @Test
+    public void goToLibraryWhenUserIsNotAuthorizedToCreateProjectsTest() {
+        doReturn(Optional.ofNullable(null)).when(projectContext).getActiveOrganizationalUnit();
+        when(libraryService.getDefaultOrganizationalUnit()).thenThrow(new UnauthorizedException());
+        libraryPlaces.goToLibrary();
+        verify(libraryPlaces).goToOrganizationalUnits();
+    }
+
     @Test
     public void goToProjectTest() {
         final PlaceRequest projectScreen = new DefaultPlaceRequest(LibraryPlaces.PROJECT_SCREEN);
@@ -641,20 +687,43 @@ public class LibraryPlacesTest {
 
     @Test
     public void goToTrySamplesTest() {
-        doReturn(true).when(libraryPlaces).closeAllPlacesOrNothing();
-
         final PlaceRequest trySamplesScreen = new DefaultPlaceRequest(LibraryPlaces.IMPORT_SAMPLE_PROJECTS_SCREEN);
         final PartDefinitionImpl part = new PartDefinitionImpl(trySamplesScreen);
         part.setSelectable(false);
 
         libraryPlaces.goToTrySamples();
 
-        verify(libraryPlaces).closeAllPlacesOrNothing();
+        verify(libraryPlaces).closeAllPlacesOrNothing(any());
         verify(placeManager).goTo(eq(part),
                                   any(PanelDefinition.class));
         verify(libraryPlaces).setupLibraryBreadCrumbsForTrySamples();
     }
 
+    @Test
+    public void goToExternalImportProjectsTest() {
+        doAnswer(inv -> {
+            final Command command = inv.getArgumentAt(0,
+                                                      Command.class);
+            command.execute();
+            return null;
+        }).when(libraryPlaces).closeAllPlacesOrNothing(any());
+
+        final PlaceRequest trySamplesScreen = new DefaultPlaceRequest(LibraryPlaces.IMPORT_PROJECTS_SCREEN);
+        final PartDefinitionImpl part = new PartDefinitionImpl(trySamplesScreen);
+        part.setSelectable(false);
+
+        final Set<ExampleProject> projects = singleton(new ExampleProject(PathFactory.newPath("example",
+                                                                                              "default://master@system/repo/example"),
+                                                                          "example",
+                                                                          "description",
+                                                                          emptyList()));
+        libraryPlaces.goToExternalImportPresenter(projects);
+
+        verify(placeManager).goTo(eq(part),
+                                  any(PanelDefinition.class));
+        verify(libraryPlaces).setupExternalImportBreadCrumbs();
+    }
+
     @Test
     public void goToImportRepositoryPopUpTest() {
         libraryPlaces.goToImportRepositoryPopUp();
@@ -683,8 +752,7 @@ public class LibraryPlacesTest {
         libraryPlaces.goToProject(project);
 
         verify(projectContextChangeEvent).fire(any(WorkspaceProjectContextChangeEvent.class));
-
-        verify(placeManager).closeAllPlacesOrNothing();
+        verify(placeManager).closeAllPlaces();
     }
 
     @Test
@@ -698,62 +766,39 @@ public class LibraryPlacesTest {
 
         verify(projectContextChangeEvent,
                never()).fire(any(WorkspaceProjectContextChangeEvent.class));
-
         verify(placeManager,
-               never()).closeAllPlacesOrNothing();
-    }
-
-    @Test
-    public void goToPreferencesTest() {
-        final PreferenceScopeResolutionStrategyInfo scopeResolutionStrategyInfo = mock(PreferenceScopeResolutionStrategyInfo.class);
-        doReturn(scopeResolutionStrategyInfo).when(projectScopedResolutionStrategySupplier).get();
-
-        final DefaultPlaceRequest placeRequest = new DefaultPlaceRequest(PreferencesRootScreen.IDENTIFIER);
-        final PartDefinitionImpl part = new PartDefinitionImpl(placeRequest);
-        part.setSelectable(false);
-
-        libraryPlaces.goToPreferences();
-
-        verify(placeManager).goTo(eq(part),
-                                  any(PanelDefinition.class));
-        verify(preferencesCentralInitializationEvent).fire(new PreferencesCentralInitializationEvent("ProjectPreferences",
-                                                                                                     scopeResolutionStrategyInfo,
-                                                                                                     null));
-        verify(libraryPlaces).setupLibraryBreadCrumbsForPreferences();
+               never()).forceCloseAllPlaces();
     }
 
     @Test
     public void placesAreUpdatedWhenActiveModuleIsRenamedTest() {
-        final Module renamedModule = mock(Module.class);
-        final RenameModuleEvent renameModuleEvent = mock(RenameModuleEvent.class);
 
-        doReturn(PlaceStatus.OPEN).when(placeManager).getStatus(LibraryPlaces.LIBRARY_PERSPECTIVE);
-
-        doReturn(activeModule).when(renameModuleEvent).getOldModule();
-        doReturn(renamedModule).when(renameModuleEvent).getNewModule();
-
-        libraryPlaces.onProjectRenamed(renameModuleEvent);
+        libraryPlaces.onChange(new WorkspaceProjectContextChangeEvent(mock(WorkspaceProject.class),
+                                                                      activeModule),
+                               new WorkspaceProjectContextChangeEvent(mock(WorkspaceProject.class),
+                                                                      mock(Module.class)));
 
         verify(breadcrumbs).clearBreadcrumbs(LibraryPlaces.LIBRARY_PERSPECTIVE);
+        verify(libraryPlaces).setupLibraryBreadCrumbs(any());
     }
 
     @Test
     public void breadcrumbIsNotUpdatedWhenInactiveModuleIsRenamedTest() {
-        final Module activeModule = mock(Module.class);
-        final Module renamedModule = mock(Module.class);
-        final Module otherModule = mock(Module.class);
-        final RenameModuleEvent renameModuleEvent = mock(RenameModuleEvent.class);
 
-        doReturn(PlaceStatus.OPEN).when(placeManager).getStatus(LibraryPlaces.LIBRARY_PERSPECTIVE);
-
-        doReturn(Optional.of(activeModule)).when(projectContext).getActiveModule();
-        doReturn(otherModule).when(renameModuleEvent).getOldModule();
-        doReturn(renamedModule).when(renameModuleEvent).getNewModule();
-
-        libraryPlaces.onProjectRenamed(renameModuleEvent);
+        final WorkspaceProjectContextChangeEvent workspaceProjectContextChangeEvent = new WorkspaceProjectContextChangeEvent(mock(WorkspaceProject.class),
+                                                                                                                             new Module(mock(Path.class),
+                                                                                                                                        mock(Path.class),
+                                                                                                                                        new POM("moduleName",
+                                                                                                                                                "description",
+                                                                                                                                                "url",
+                                                                                                                                                new GAV())));
+        libraryPlaces.onChange(workspaceProjectContextChangeEvent,
+                               workspaceProjectContextChangeEvent);
 
         verify(libraryPlaces,
                never()).setupLibraryBreadCrumbsForAsset(any());
+        verify(libraryPlaces,
+               never()).setupLibraryBreadCrumbs(any());
     }
 
     @Test
@@ -804,4 +849,42 @@ public class LibraryPlacesTest {
         verify(placeManager).goTo(libraryPerspective);
         verify(libraryPlaces).goToAsset(any(Path.class));
     }
+
+    @Test
+    public void closeAllPlacesOrNothingWithUncloseablePlacesTest() {
+        final Command successCallback = mock(Command.class);
+
+        final List<PlaceRequest> uncloseablePlaces = new ArrayList<>();
+        uncloseablePlaces.add(mock(PlaceRequest.class));
+        doReturn(uncloseablePlaces).when(placeManager).getUncloseablePlaces();
+
+        libraryPlaces.closeAllPlacesOrNothing(successCallback);
+
+        verify(placeManager,
+               never()).forceCloseAllPlaces();
+        verify(successCallback,
+               never()).execute();
+        verify(closeUnsavedProjectAssetsPopUpPresenter).show(eq(activeProject),
+                                                             eq(uncloseablePlaces),
+                                                             any(),
+                                                             any());
+    }
+
+    @Test
+    public void closeAllPlacesOrNothingWithoutUncloseablePlacesTest() {
+        final Command successCallback = mock(Command.class);
+
+        final List<PlaceRequest> uncloseablePlaces = new ArrayList<>();
+        uncloseablePlaces.add(mock(PlaceRequest.class));
+
+        libraryPlaces.closeAllPlacesOrNothing(successCallback);
+
+        verify(placeManager).closeAllPlaces();
+        verify(successCallback).execute();
+        verify(closeUnsavedProjectAssetsPopUpPresenter,
+               never()).show(any(),
+                             any(),
+                             any(),
+                             any());
+    }
 }
