@@ -16,16 +16,6 @@
 
 package org.kie.workbench.common.workbench.client.admin;
 
-import static org.mockito.Matchers.any;
-import static org.mockito.Matchers.anyString;
-import static org.mockito.Matchers.eq;
-import static org.mockito.Mockito.RETURNS_DEFAULTS;
-import static org.mockito.Mockito.doReturn;
-import static org.mockito.Mockito.mock;
-import static org.mockito.Mockito.never;
-import static org.mockito.Mockito.times;
-import static org.mockito.Mockito.verify;
-
 import com.google.gwtmockito.GwtMockitoTestRunner;
 import org.guvnor.common.services.shared.preferences.GuvnorPreferenceScopes;
 import org.jboss.errai.security.shared.api.identity.User;
@@ -46,9 +36,23 @@ import org.uberfire.rpc.SessionInfo;
 import org.uberfire.security.ResourceRef;
 import org.uberfire.security.authz.AuthorizationManager;
 
+import static org.mockito.Matchers.any;
+import static org.mockito.Matchers.anyString;
+import static org.mockito.Matchers.eq;
+import static org.mockito.Mockito.RETURNS_DEFAULTS;
+import static org.mockito.Mockito.doReturn;
+import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.never;
+import static org.mockito.Mockito.times;
+import static org.mockito.Mockito.verify;
+
 @RunWith(GwtMockitoTestRunner.class)
 public class DefaultAdminPageHelperTest {
 
+    private static String LIBRARY_PREFERENCES = "LibraryPreferences";
+    private static String ARTIFACT_REPOSITORY_PREFERENCES = "ArtifactRepositoryPreference";
+    private static String STUNNER_PREFERENCES = "StunnerPreferences";
+
     @Mock
     private AdminPage adminPage;
 
@@ -67,6 +71,9 @@ public class DefaultAdminPageHelperTest {
     @InjectMocks
     private DefaultAdminPageHelper defaultAdminPageHelper;
 
+    @Mock
+    private PreferenceScope globalScope;
+
     @Before
     public void setup() {
         mockConstants();
@@ -80,7 +87,7 @@ public class DefaultAdminPageHelperTest {
         verify(adminPage).addTool(eq("root"),
                                   eq(languages),
                                   any(),
-                                  eq("general"),
+                                  eq("preferences"),
                                   any());
     }
 
@@ -214,36 +221,18 @@ public class DefaultAdminPageHelperTest {
 
     @Test
     public void preferencesShouldBeSavedOnGlobalScopeWhenUserHasPermissionTest() {
-        final PreferenceScope globalScope = mock(PreferenceScope.class);
         doReturn(globalScope).when(scopeFactory).createScope(GuvnorPreferenceScopes.GLOBAL);
 
         doReturn(true).when(authorizationManager).authorize(eq(WorkbenchFeatures.EDIT_GLOBAL_PREFERENCES),
                                                             any());
 
         defaultAdminPageHelper.setup();
-
-        verify(adminPage,
-               times(3)).addPreference(anyString(),
-                                       anyString(),
-                                       anyString(),
-                                       anyString(),
-                                       anyString(),
-                                       any(PreferenceScope.class),
-                                       eq(AdminPageOptions.WITH_BREADCRUMBS));
-
-        verify(adminPage,
-               times(3)).addPreference(anyString(),
-                                       anyString(),
-                                       anyString(),
-                                       anyString(),
-                                       anyString(),
-                                       eq(globalScope),
-                                       eq(AdminPageOptions.WITH_BREADCRUMBS));
+        verifyLibraryPreferencesWasAddedInGlobalScope();
+        verifyArtifactRepositoryPreferencesWasAddedInGlobalScope();
     }
 
     @Test
     public void preferencesShouldBeSavedOnGlobalScopeWhenUserHasPermissionAndEnabledTest() {
-        final PreferenceScope globalScope = mock(PreferenceScope.class);
         doReturn(globalScope).when(scopeFactory).createScope(GuvnorPreferenceScopes.GLOBAL);
 
         doReturn(true).when(authorizationManager).authorize(eq(WorkbenchFeatures.EDIT_GLOBAL_PREFERENCES),
@@ -252,43 +241,20 @@ public class DefaultAdminPageHelperTest {
         defaultAdminPageHelper.setup(true,
                                      true,
                                      true);
-
-        verify(adminPage,
-               times(3)).addPreference(anyString(),
-                                       anyString(),
-                                       anyString(),
-                                       anyString(),
-                                       anyString(),
-                                       any(PreferenceScope.class),
-                                       eq(AdminPageOptions.WITH_BREADCRUMBS));
-
-        verify(adminPage,
-               times(3)).addPreference(anyString(),
-                                       anyString(),
-                                       anyString(),
-                                       anyString(),
-                                       anyString(),
-                                       eq(globalScope),
-                                       eq(AdminPageOptions.WITH_BREADCRUMBS));
+        verifyLibraryPreferencesWasAddedInGlobalScope();
+        verifyArtifactRepositoryPreferencesWasAddedInGlobalScope();
     }
 
     @Test
     public void preferencesShouldNotBeAddedWhenUserHasPermissionAndDisabledTest() {
         doReturn(true).when(authorizationManager).authorize(eq(WorkbenchFeatures.EDIT_GLOBAL_PREFERENCES),
-                                                             any());
+                                                            any());
 
         defaultAdminPageHelper.setup(false,
                                      false,
                                      false);
-
-        verify(adminPage,
-               never()).addPreference(anyString(),
-                                      anyString(),
-                                      anyString(),
-                                      anyString(),
-                                      anyString(),
-                                      any(PreferenceScope.class),
-                                      any());
+        verifyLibraryPreferencesWasNotAdded();
+        verifyArtifactRepositoryPreferencesWasNotAdded();
     }
 
     @Test
@@ -297,15 +263,8 @@ public class DefaultAdminPageHelperTest {
                                                              any());
 
         defaultAdminPageHelper.setup();
-
-        verify(adminPage,
-               never()).addPreference(anyString(),
-                                      anyString(),
-                                      anyString(),
-                                      anyString(),
-                                      anyString(),
-                                      any(PreferenceScope.class),
-                                      any());
+        verifyLibraryPreferencesWasNotAdded();
+        verifyArtifactRepositoryPreferencesWasNotAdded();
     }
 
     @Test
@@ -317,14 +276,83 @@ public class DefaultAdminPageHelperTest {
                                      false,
                                      false);
 
+        verifyLibraryPreferencesWasNotAdded();
+        verifyArtifactRepositoryPreferencesWasNotAdded();
+    }
+
+    @Test
+    public void stunnerPreferencesWasAddedTest() {
+        defaultAdminPageHelper.setup();
+        defaultAdminPageHelper.setup(false,
+                                     false,
+                                     false);
+        defaultAdminPageHelper.setup(true,
+                                     true,
+                                     true);
+        verifyStunnerPreferencesWasAdded(2);
+    }
+
+    @Test
+    public void stunnerPreferencesWasNotAddedTest() {
+        defaultAdminPageHelper.setup(true,
+                                     true,
+                                     false);
+        verifyStunnerPreferencesWasAdded(0);
+    }
+
+    private void verifyLibraryPreferencesWasAddedInGlobalScope() {
         verify(adminPage,
-               never()).addPreference(anyString(),
-                                      anyString(),
+               times(1)).addPreference(eq("root"),
+                                       eq(LIBRARY_PREFERENCES),
+                                       anyString(),
+                                       anyString(),
+                                       anyString(),
+                                       eq(globalScope),
+                                       eq(AdminPageOptions.WITH_BREADCRUMBS));
+    }
+
+    private void verifyLibraryPreferencesWasNotAdded() {
+        verify(adminPage,
+               never()).addPreference(eq("root"),
+                                      eq(LIBRARY_PREFERENCES),
                                       anyString(),
                                       anyString(),
                                       anyString(),
                                       any(PreferenceScope.class),
-                                      any());
+                                      eq(AdminPageOptions.WITH_BREADCRUMBS));
+    }
+
+    private void verifyArtifactRepositoryPreferencesWasAddedInGlobalScope() {
+        verify(adminPage,
+               times(1)).addPreference(eq("root"),
+                                       eq(ARTIFACT_REPOSITORY_PREFERENCES),
+                                       anyString(),
+                                       anyString(),
+                                       anyString(),
+                                       eq(globalScope),
+                                       eq(AdminPageOptions.WITH_BREADCRUMBS));
+    }
+
+    private void verifyArtifactRepositoryPreferencesWasNotAdded() {
+        verify(adminPage,
+               never()).addPreference(eq("root"),
+                                      eq(ARTIFACT_REPOSITORY_PREFERENCES),
+                                      anyString(),
+                                      anyString(),
+                                      anyString(),
+                                      any(PreferenceScope.class),
+                                      eq(AdminPageOptions.WITH_BREADCRUMBS));
+    }
+
+    private void verifyStunnerPreferencesWasAdded(int timesAdded) {
+        verify(adminPage,
+               times(timesAdded)).addPreference(eq("root"),
+                                           eq(STUNNER_PREFERENCES),
+                                           anyString(),
+                                           anyString(),
+                                           anyString(),
+                                           any(PreferenceScope.class),
+                                           eq(AdminPageOptions.WITH_BREADCRUMBS));
     }
 
     private void mockConstants() {
