@@ -16,7 +16,6 @@
 
 package org.kie.workbench.common.stunner.client.widgets.palette;
 
-import org.kie.workbench.common.stunner.client.widgets.palette.categories.DefinitionPaletteCategoryWidget;
 import org.kie.workbench.common.stunner.core.client.components.glyph.ShapeGlyphDragHandler;
 import org.uberfire.client.mvp.UberElement;
 
@@ -34,9 +33,9 @@ public interface BS3PaletteWidgetView extends UberElement<BS3PaletteWidget> {
 
     void showEmptyView(boolean showEmptyView);
 
-    void add(DefinitionPaletteCategoryWidget widget);
+    void add(BS3PaletteWidgetPresenter widget);
 
     void clear();
 
     void destroy();
-}
+}
\ No newline at end of file
