@@ -44,11 +44,6 @@ public abstract class AbstractCanvasViewer<T, H extends AbstractCanvasHandler, V
      */
     protected abstract void enableControls();
 
-    /**
-     * Implementations must disable here the controls, at least, the zoom control instance.
-     */
-    protected abstract void disableControls();
-
     /**
      * Implementations must destroy here the controls, at least, the zoom control instance.
      */
@@ -60,7 +55,6 @@ public abstract class AbstractCanvasViewer<T, H extends AbstractCanvasHandler, V
      */
     @Override
     public void clear() {
-        disableControls();
         getHandler().clear();
         getView().clear();
     }
@@ -73,7 +67,13 @@ public abstract class AbstractCanvasViewer<T, H extends AbstractCanvasHandler, V
     @Override
     public void destroy() {
         destroyControls();
-        getHandler().destroy();
+        destroyInstances();
+    }
+
+    protected void destroyInstances() {
+        if (getHandler() != null) {
+            getHandler().destroy();
+        }
         getView().clear();
     }
 
