@@ -145,8 +145,8 @@ public abstract class AbstractCanvasHandler<D extends Diagram, C extends Abstrac
      * @param parent The parent graph element.
      * @param child The graph element to set as a docked child.
      */
-    public abstract void dock(final Element parent,
-                              final Element child);
+    public abstract boolean dock(final Element parent,
+                                 final Element child);
 
     /**
      * This method removes the given <code>child</code> instance as docked child for the given
@@ -377,7 +377,6 @@ public abstract class AbstractCanvasHandler<D extends Diagram, C extends Abstrac
         if (null != getCanvas()) {
             notifyCanvasClear();
             getCanvas().clear();
-            getCanvas().draw();
         }
     }
 
@@ -400,9 +399,7 @@ public abstract class AbstractCanvasHandler<D extends Diagram, C extends Abstrac
      */
     @Override
     public void destroy() {
-        if (null != getCanvas()) {
-            getCanvas().destroy();
-        }
+        getCanvas().destroy();
         doDestroy();
         listeners.clear();
     }
