@@ -17,12 +17,12 @@
 package org.kie.workbench.common.stunner.core.client.canvas.controls.builder.impl;
 
 import java.util.List;
+
 import javax.enterprise.context.Dependent;
 import javax.enterprise.inject.Default;
 import javax.inject.Inject;
 
 import org.kie.workbench.common.stunner.core.client.api.ClientDefinitionManager;
-import org.kie.workbench.common.stunner.core.client.api.ShapeManager;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.AbstractCanvasHandlerControl;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.builder.NodeBuilderControl;
@@ -38,7 +38,7 @@ import org.kie.workbench.common.stunner.core.client.shape.MutationContext;
 import org.kie.workbench.common.stunner.core.client.shape.Shape;
 import org.kie.workbench.common.stunner.core.command.Command;
 import org.kie.workbench.common.stunner.core.command.CommandResult;
-import org.kie.workbench.common.stunner.core.command.impl.CompositeCommandImpl;
+import org.kie.workbench.common.stunner.core.command.impl.CompositeCommand;
 import org.kie.workbench.common.stunner.core.command.util.CommandUtils;
 import org.kie.workbench.common.stunner.core.graph.Edge;
 import org.kie.workbench.common.stunner.core.graph.Node;
@@ -48,40 +48,32 @@ import org.kie.workbench.common.stunner.core.graph.content.view.View;
 import org.kie.workbench.common.stunner.core.graph.content.view.ViewConnector;
 
 @Dependent
-public class NodeBuilderControlImpl extends AbstractCanvasHandlerControl<AbstractCanvasHandler> implements NodeBuilderControl<AbstractCanvasHandler> {
+@Default
+public class NodeBuilderControlImpl
+        extends AbstractCanvasHandlerControl<AbstractCanvasHandler>
+        implements NodeBuilderControl<AbstractCanvasHandler> {
 
     private final ClientDefinitionManager clientDefinitionManager;
-    private final ShapeManager shapeManager;
     private final CanvasCommandFactory<AbstractCanvasHandler> commandFactory;
     private final AbstractElementBuilderControl elementBuilderControl;
 
-    protected NodeBuilderControlImpl() {
-        this(null,
-             null,
-             null,
-             null);
-    }
-
     @Inject
     public NodeBuilderControlImpl(final ClientDefinitionManager clientDefinitionManager,
-                                  final ShapeManager shapeManager,
                                   final CanvasCommandFactory<AbstractCanvasHandler> commandFactory,
                                   final @Default @Element AbstractElementBuilderControl elementBuilderControl) {
         this.clientDefinitionManager = clientDefinitionManager;
-        this.shapeManager = shapeManager;
         this.commandFactory = commandFactory;
         this.elementBuilderControl = elementBuilderControl;
     }
 
     @Override
-    public void enable(final AbstractCanvasHandler canvasHandler) {
-        super.enable(canvasHandler);
-        this.elementBuilderControl.enable(canvasHandler);
+    protected void doInit() {
+        this.elementBuilderControl.init(canvasHandler);
     }
 
     @Override
-    protected void doDisable() {
-        this.elementBuilderControl.disable();
+    protected void doDestroy() {
+        this.elementBuilderControl.destroy();
     }
 
     @Override
@@ -93,7 +85,7 @@ public class NodeBuilderControlImpl extends AbstractCanvasHandlerControl<Abstrac
     public boolean allows(final NodeBuildRequest request) {
         final double x = request.getX();
         final double y = request.getY();
-        final Node<View<?>, Edge> node = request.getNode();
+        final Node<? extends View<?>, Edge> node = request.getNode();
         if (null != node) {
             final ElementBuildRequest<AbstractCanvasHandler> request1 = new ElementBuildRequestImpl(x,
                                                                                                     y,
@@ -109,8 +101,8 @@ public class NodeBuilderControlImpl extends AbstractCanvasHandlerControl<Abstrac
                       final BuildCallback buildCallback) {
         final double x = request.getX();
         final double y = request.getY();
-        final Node<View<?>, Edge> node = request.getNode();
-        final Edge<View<?>, Node> inEdge = request.getInEdge();
+        final Node<? extends View<?>, Edge> node = request.getNode();
+        final Edge<? extends ViewConnector<?>, Node> inEdge = request.getInEdge();
         final Connection sourceConnection = request.getSourceConnection();
         final Connection targetConnection = request.getTargetConnection();
         if (null != node) {
@@ -125,13 +117,14 @@ public class NodeBuilderControlImpl extends AbstractCanvasHandlerControl<Abstrac
             final String ssid = canvasHandler.getDiagram().getMetadata().getShapeSetId();
             ebc.getElementCommands(node,
                                    parent,
+                                   ebc.getParentAssignment(parent, nodeDef),
                                    childCoordinates.getX(),
                                    childCoordinates.getY(),
                                    new AbstractElementBuilderControl.CommandsCallback() {
                                        @Override
                                        public void onComplete(final String uuid,
                                                               final List<Command<AbstractCanvasHandler, CanvasViolation>> commands) {
-                                           final CompositeCommandImpl.CompositeCommandBuilder commandBuilder = new CompositeCommandImpl.CompositeCommandBuilder().addCommands(commands);
+                                           final CompositeCommand.Builder commandBuilder = new CompositeCommand.Builder().addCommands(commands);
                                            if (inEdge != null) {
                                                final Object edgeDef = inEdge.getContent().getDefinition();
                                                final String edgeId = clientDefinitionManager.adapters().forDefinition().getId(edgeDef);
@@ -144,8 +137,10 @@ public class NodeBuilderControlImpl extends AbstractCanvasHandlerControl<Abstrac
                                                                                                       inEdge,
                                                                                                       targetConnection));
                                            }
-                                           final CommandResult<CanvasViolation> results = elementBuilderControl.getCommandManager().execute(canvasHandler,
-                                                                                                                                            commandBuilder.build());
+                                           final CommandResult<CanvasViolation> results = elementBuilderControl
+                                                   .getCommandManager().execute(canvasHandler,
+                                                                                commandBuilder.build());
+
                                            if (!CommandUtils.isError(results)) {
                                                updateConnectorShape(inEdge,
                                                                     node,
@@ -164,7 +159,7 @@ public class NodeBuilderControlImpl extends AbstractCanvasHandlerControl<Abstrac
     }
 
     @SuppressWarnings("unchecked")
-    protected void updateConnectorShape(final Edge<View<?>, Node> inEdge,
+    protected void updateConnectorShape(final Edge<? extends ViewConnector<?>, Node> inEdge,
                                         final Node targetNode,
                                         final Connection sourceConnection,
                                         final Connection targetConnection) {
