@@ -33,12 +33,11 @@ import org.kie.workbench.common.stunner.core.client.canvas.controls.builder.requ
 import org.kie.workbench.common.stunner.core.client.canvas.controls.builder.request.ElementBuildRequestImpl;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.event.BuildCanvasShapeEvent;
 import org.kie.workbench.common.stunner.core.client.canvas.event.selection.CanvasSelectionEvent;
-import org.kie.workbench.common.stunner.core.client.canvas.util.CanvasLayoutUtils;
 import org.kie.workbench.common.stunner.core.client.command.CanvasCommandFactory;
+import org.kie.workbench.common.stunner.core.client.i18n.ClientTranslationMessages;
 import org.kie.workbench.common.stunner.core.client.service.ClientFactoryService;
 import org.kie.workbench.common.stunner.core.client.service.ClientRuntimeError;
 import org.kie.workbench.common.stunner.core.graph.processing.index.bounds.GraphBoundsIndexer;
-import org.kie.workbench.common.stunner.core.graph.util.GraphUtils;
 import org.kie.workbench.common.stunner.core.rule.RuleManager;
 
 import static org.kie.soup.commons.validation.PortablePreconditions.checkNotNull;
@@ -53,33 +52,20 @@ public class ObserverBuilderControl extends AbstractElementBuilderControl
 
     private final Event<CanvasSelectionEvent> canvasSelectionEvent;
 
-    protected ObserverBuilderControl() {
-        this(null,
-             null,
-             null,
-             null,
-             null,
-             null,
-             null,
-             null);
-    }
-
     @Inject
     public ObserverBuilderControl(final ClientDefinitionManager clientDefinitionManager,
                                   final ClientFactoryService clientFactoryServices,
-                                  final GraphUtils graphUtils,
                                   final RuleManager ruleManager,
                                   final CanvasCommandFactory<AbstractCanvasHandler> canvasCommandFactory,
+                                  final ClientTranslationMessages translationMessages,
                                   final GraphBoundsIndexer graphBoundsIndexer,
-                                  final CanvasLayoutUtils canvasLayoutUtils,
                                   final Event<CanvasSelectionEvent> canvasSelectionEvent) {
         super(clientDefinitionManager,
               clientFactoryServices,
-              graphUtils,
               ruleManager,
               canvasCommandFactory,
-              graphBoundsIndexer,
-              canvasLayoutUtils);
+              translationMessages,
+              graphBoundsIndexer);
         this.canvasSelectionEvent = canvasSelectionEvent;
     }
 
@@ -103,14 +89,13 @@ public class ObserverBuilderControl extends AbstractElementBuilderControl
                                                   new BuildCallback() {
                                                       @Override
                                                       public void onSuccess(final String uuid) {
-                                                          canvasHandler.getCanvas().draw();
                                                           canvasSelectionEvent.fire(new CanvasSelectionEvent(canvasHandler,
                                                                                                              uuid));
                                                       }
 
                                                       @Override
                                                       public void onError(final ClientRuntimeError error) {
-                                                          LOGGER.log(Level.SEVERE,
+                                                          LOGGER.log(Level.WARNING,
                                                                      error.toString());
                                                       }
                                                   });
