@@ -19,7 +19,6 @@ package org.kie.workbench.common.stunner.core.client.canvas.controls.select;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.HashMap;
-import java.util.List;
 import java.util.Map;
 import java.util.function.Consumer;
 import java.util.function.Predicate;
@@ -68,8 +67,7 @@ public final class MapSelectionControl<H extends AbstractCanvasHandler>
     }
 
     @Override
-    public void enable(final H canvasHandler) {
-        super.enable(canvasHandler);
+    protected void doInit() {
         final Layer layer = canvasHandler.getCanvas().getLayer();
         // Click handler for the canvas area - cleans current selection, if any.
         final MouseClickHandler clickHandler = new MouseClickHandler() {
@@ -97,8 +95,7 @@ public final class MapSelectionControl<H extends AbstractCanvasHandler>
          * - element is not registered
          * - element has visible representation
          */
-        if (isEnabled()
-                && !itemsRegistered().test(element.getUUID())
+        if (!itemsRegistered().test(element.getUUID())
                 && element.getContent() instanceof View) {
             items.put(element.getUUID(),
                       false);
@@ -134,15 +131,18 @@ public final class MapSelectionControl<H extends AbstractCanvasHandler>
                 .collect(Collectors.toList());
     }
 
+    private Collection<String> getUnselectedItems() {
+        return items.entrySet().stream()
+                .filter(entry -> !entry.getValue())
+                .map(Map.Entry::getKey)
+                .collect(Collectors.toList());
+    }
+
     @Override
     public SelectionControl<H, Element> clearSelection() {
         return clearSelection(true);
     }
 
-    public boolean isEnabled() {
-        return super.isEnabled() && null != canvasHandler.getCanvas();
-    }
-
     public boolean isReadonly() {
         return readonly;
     }
@@ -154,9 +154,8 @@ public final class MapSelectionControl<H extends AbstractCanvasHandler>
     public SelectionControl<H, Element> select(final Collection<String> uuids) {
         uuids.stream()
                 .filter(itemsRegistered())
-                .forEach(uuid -> items.put(uuid,
-                                           true));
-        updateViewShapesState();
+                .forEach(uuid -> items.put(uuid, true));
+        updateViewShapesState(getSelectedItems());
         fireSelectedItemsEvent();
         return this;
     }
@@ -164,9 +163,8 @@ public final class MapSelectionControl<H extends AbstractCanvasHandler>
     public SelectionControl<H, Element> deselect(final Collection<String> uuids) {
         uuids.stream()
                 .filter(itemsRegistered())
-                .forEach(uuid -> items.put(uuid,
-                                           false));
-        updateViewShapesState();
+                .forEach(uuid -> items.put(uuid, false));
+        updateViewShapesState(getUnselectedItems());
         return this;
     }
 
@@ -176,9 +174,6 @@ public final class MapSelectionControl<H extends AbstractCanvasHandler>
 
     private SelectionControl<H, Element> clearSelection(final boolean fireEvent) {
         deselect(getSelectedItems());
-        if (null != getCanvas()) {
-            getCanvas().draw();
-        }
         if (fireEvent) {
             fireCanvasClear();
         }
@@ -186,32 +181,28 @@ public final class MapSelectionControl<H extends AbstractCanvasHandler>
     }
 
     @SuppressWarnings("unchecked")
-    private void updateViewShapesState() {
-        if (isEnabled()) {
-            final List<Shape> shapes = getCanvas().getShapes();
-            for (final Shape shape : shapes) {
-                final boolean isSelected = isSelected(shape.getUUID());
-                if (isSelected && isReadonly()) {
-                    shape.applyState(ShapeState.HIGHLIGHT);
-                }else if(isSelected) {
-                    shape.applyState(ShapeState.SELECTED);
-                } else {
-                    shape.applyState(ShapeState.NONE);
-                }
-            }
-            // Batch a show operation.
-            getCanvas().draw();
-        }
+    private void updateViewShapesState(Collection<String> uuids) {
+        uuids.stream()
+                .map(uuid -> getCanvas().getShape(uuid))
+                .forEach(shape -> {
+                    final boolean isSelected = isSelected(shape.getUUID());
+                    if (isSelected && isReadonly()) {
+                        shape.applyState(ShapeState.HIGHLIGHT);
+                    } else if (isSelected) {
+                        shape.applyState(ShapeState.SELECTED);
+                    } else {
+                        shape.applyState(ShapeState.NONE);
+                    }
+                });
     }
 
     @Override
-    protected void doDisable() {
-        if (isEnabled()
-                && null != layerClickHandler
-                && null != getCanvas().getLayer()) {
+    protected void doDestroy() {
+        if (null != layerClickHandler) {
             getCanvas().getLayer().removeHandler(layerClickHandler);
             this.layerClickHandler = null;
         }
+        items.clear();
     }
 
     public void onShapeRemoved(final CanvasShapeRemovedEvent shapeRemovedEvent) {
@@ -220,7 +211,7 @@ public final class MapSelectionControl<H extends AbstractCanvasHandler>
         if (null == canvasHandler) {
             return;
         }
-        if (isEnabled() && getCanvas().equals(shapeRemovedEvent.getCanvas())) {
+        if (getCanvas().equals(shapeRemovedEvent.getCanvas())) {
             final Shape<?> shape = shapeRemovedEvent.getShape();
             deselect(Collections.singletonList(shape.getUUID()));
         }
