@@ -16,6 +16,7 @@
 
 package org.kie.workbench.common.stunner.core.client.canvas.util;
 
+import javax.annotation.PreDestroy;
 import javax.enterprise.context.Dependent;
 import javax.inject.Inject;
 
@@ -24,10 +25,8 @@ import org.kie.workbench.common.stunner.core.client.canvas.CanvasHandler;
 import org.kie.workbench.common.stunner.core.diagram.Diagram;
 import org.kie.workbench.common.stunner.core.graph.Edge;
 import org.kie.workbench.common.stunner.core.graph.Element;
-import org.kie.workbench.common.stunner.core.graph.Graph;
 import org.kie.workbench.common.stunner.core.graph.Node;
 import org.kie.workbench.common.stunner.core.graph.content.Bounds;
-import org.kie.workbench.common.stunner.core.graph.content.definition.DefinitionSet;
 import org.kie.workbench.common.stunner.core.graph.content.view.Point2D;
 import org.kie.workbench.common.stunner.core.graph.content.view.View;
 import org.kie.workbench.common.stunner.core.graph.content.view.ViewConnector;
@@ -89,6 +88,11 @@ public class CanvasLayoutUtils {
         return PADDING_Y;
     }
 
+    @PreDestroy
+    public void destroy() {
+        graphBoundsIndexer.destroy();
+    }
+
     @SuppressWarnings("unchecked")
     public Point2D getNext(final CanvasHandler canvasHandler,
                            final Node<View<?>, Edge> root,
