@@ -36,7 +36,6 @@ import org.kie.workbench.common.stunner.core.client.shape.view.ShapeView;
 import org.kie.workbench.common.stunner.core.client.shape.view.event.MouseClickEvent;
 import org.kie.workbench.common.stunner.core.client.shape.view.event.MouseClickHandler;
 import org.kie.workbench.common.stunner.core.client.shape.view.event.ViewEventType;
-import org.kie.workbench.common.stunner.core.client.shape.view.event.ViewHandler;
 import org.kie.workbench.common.stunner.core.diagram.Diagram;
 import org.kie.workbench.common.stunner.core.diagram.Metadata;
 import org.kie.workbench.common.stunner.core.graph.Element;
@@ -52,7 +51,6 @@ import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertTrue;
 import static org.mockito.Matchers.any;
 import static org.mockito.Matchers.eq;
-import static org.mockito.Mockito.atLeastOnce;
 import static org.mockito.Mockito.never;
 import static org.mockito.Mockito.times;
 import static org.mockito.Mockito.verify;
@@ -100,14 +98,13 @@ public class MapSelectionControlTest {
     @Mock
     private HasControlPoints<ShapeViewExtStub> hasControlPoints;
 
-    private ShapeViewExtStub shapeView;
     private MapSelectionControl<AbstractCanvasHandler> tested;
 
     @Before
     @SuppressWarnings("unchecked")
     public void setup() throws Exception {
-        this.shapeView = new ShapeViewExtStub(shapeEventHandler,
-                                              hasControlPoints);
+        ShapeViewExtStub shapeView = new ShapeViewExtStub(shapeEventHandler,
+                                                          hasControlPoints);
         when(element.getUUID()).thenReturn(ELEMENT_UUID);
         when(element.getContent()).thenReturn(new ViewImpl<>(definition,
                                                              BoundsImpl.build(0, 0, 10, 10)));
@@ -128,7 +125,7 @@ public class MapSelectionControlTest {
 
     @Test
     public void testEnable() {
-        tested.enable(canvasHandler);
+        tested.init(canvasHandler);
         verify(layer,
                times(1)).addHandler(eq(ViewEventType.MOUSE_CLICK),
                                     any(MouseClickHandler.class));
@@ -136,7 +133,7 @@ public class MapSelectionControlTest {
 
     @Test
     public void testLayerClickAndSelectRootElement() {
-        tested.enable(canvasHandler);
+        tested.init(canvasHandler);
         final ArgumentCaptor<MouseClickHandler> clickHandlerArgumentCaptor =
                 ArgumentCaptor.forClass(MouseClickHandler.class);
         verify(layer,
@@ -164,7 +161,7 @@ public class MapSelectionControlTest {
     @Test
     public void testLayerClickAndClear() {
         when(metadata.getCanvasRootUUID()).thenReturn(null);
-        tested.enable(canvasHandler);
+        tested.init(canvasHandler);
         final ArgumentCaptor<MouseClickHandler> clickHandlerArgumentCaptor =
                 ArgumentCaptor.forClass(MouseClickHandler.class);
         verify(layer,
@@ -186,7 +183,7 @@ public class MapSelectionControlTest {
 
     @Test
     public void testRegisterElement() {
-        tested.enable(canvasHandler);
+        tested.init(canvasHandler);
         assertFalse(isRegistered(element));
         tested.register(element);
         assertTrue(isRegistered(element));
@@ -195,24 +192,15 @@ public class MapSelectionControlTest {
     @Test
     @SuppressWarnings("unchecked")
     public void testDeregisterElement() {
-        tested.enable(canvasHandler);
+        tested.init(canvasHandler);
         tested.register(element);
         tested.deregister(element);
         assertFalse(isRegistered(element));
     }
 
-    @Test
-    @SuppressWarnings("unchecked")
-    public void testDisable() {
-        tested.enable(canvasHandler);
-        tested.disable();
-        verify(layer,
-               times(1)).removeHandler(any(ViewHandler.class));
-    }
-
     @Test
     public void testSelect() {
-        tested.enable(canvasHandler);
+        tested.init(canvasHandler);
         tested.register(element);
         tested.select(element);
         assertEquals(1, tested.getSelectedItems().size());
@@ -231,8 +219,8 @@ public class MapSelectionControlTest {
     }
 
     @Test
-    public void testSelectReadOnly(){
-        tested.enable(canvasHandler);
+    public void testSelectReadOnly() {
+        tested.init(canvasHandler);
         tested.register(element);
         tested.setReadonly(true);
         tested.select(element);
@@ -244,7 +232,7 @@ public class MapSelectionControlTest {
 
     @Test
     public void testDeselect() {
-        tested.enable(canvasHandler);
+        tested.init(canvasHandler);
         tested.register(element);
         tested.select(element);
         tested.deselect(element);
@@ -257,12 +245,11 @@ public class MapSelectionControlTest {
 
     @Test
     public void testClearSelection() {
-        tested.enable(canvasHandler);
+        tested.init(canvasHandler);
         tested.register(element);
         tested.select(element);
         tested.clearSelection();
         assertTrue(tested.getSelectedItems().isEmpty());
-        verify(canvas, atLeastOnce()).draw();
         verify(shape, times(1)).applyState(eq(ShapeState.SELECTED));
         verify(shape, times(1)).applyState(eq(ShapeState.NONE));
         verify(shape, never()).applyState(eq(ShapeState.INVALID));
@@ -273,7 +260,7 @@ public class MapSelectionControlTest {
 
     @Test
     public void testOnShapeRemovedEvent() {
-        tested.enable(canvasHandler);
+        tested.init(canvasHandler);
         tested.register(element);
         tested.select(element);
         CanvasShapeRemovedEvent shapeRemovedEvent = new CanvasShapeRemovedEvent(canvas,
@@ -288,13 +275,12 @@ public class MapSelectionControlTest {
 
     @Test
     public void testOnClearSelectionEvent() {
-        tested.enable(canvasHandler);
+        tested.init(canvasHandler);
         tested.register(element);
         tested.select(element);
         CanvasClearSelectionEvent event = new CanvasClearSelectionEvent(canvasHandler);
         tested.onCanvasClearSelection(event);
         assertTrue(tested.getSelectedItems().isEmpty());
-        verify(canvas, atLeastOnce()).draw();
         verify(shape, times(1)).applyState(eq(ShapeState.SELECTED));
         verify(shape, times(1)).applyState(eq(ShapeState.NONE));
         verify(shape, never()).applyState(eq(ShapeState.INVALID));
@@ -305,7 +291,7 @@ public class MapSelectionControlTest {
 
     @Test
     public void testOnSelectEvent() {
-        tested.enable(canvasHandler);
+        tested.init(canvasHandler);
         tested.register(element);
         CanvasSelectionEvent event = new CanvasSelectionEvent(canvasHandler,
                                                               ELEMENT_UUID);
