@@ -230,8 +230,6 @@ public class CreateConnectorActionTest {
                      edgeBuildRequest.getOutNode());
         final BuilderControl.BuildCallback completeCallback = completeCallbackCaptor.getValue();
         completeCallback.onSuccess(TARGET_NODE_UUID);
-        verify(edgeBuilderControl,
-               times(1)).disable();
         verify(edgeBuilderControl,
                times(1)).setCommandManagerProvider(eq(null));
         verify(canvasHighlight,
@@ -257,6 +255,7 @@ public class CreateConnectorActionTest {
                times(1)).highLight(eq(targetNode));
     }
 
+    @SuppressWarnings("unchecked")
     private DragProxyCallback testStartDrag() {
         final MouseClickEvent event = mock(MouseClickEvent.class);
         when(event.getX()).thenReturn(100d);
@@ -293,7 +292,7 @@ public class CreateConnectorActionTest {
         verify(graphBoundsIndexer,
                times(1)).build(eq(graph));
         verify(edgeBuilderControl,
-               times(1)).enable(eq(canvasHandler));
+               times(1)).init(eq(canvasHandler));
         ArgumentCaptor<RequiresCommandManager.CommandManagerProvider> providerArgumentCaptor =
                 ArgumentCaptor.forClass(RequiresCommandManager.CommandManagerProvider.class);
         verify(edgeBuilderControl,
