@@ -21,9 +21,9 @@ import java.util.Objects;
 import javax.validation.Valid;
 
 import org.jboss.errai.common.client.api.annotations.MapsTo;
-import org.jboss.errai.common.client.api.annotations.NonPortable;
 import org.jboss.errai.common.client.api.annotations.Portable;
 import org.jboss.errai.databinding.client.api.Bindable;
+import org.kie.workbench.common.forms.adf.definitions.annotations.FieldParam;
 import org.kie.workbench.common.forms.adf.definitions.annotations.FormDefinition;
 import org.kie.workbench.common.forms.adf.definitions.annotations.FormField;
 import org.kie.workbench.common.forms.adf.definitions.settings.FieldPolicy;
@@ -40,9 +40,12 @@ import org.kie.workbench.common.stunner.core.rule.annotation.RuleExtension;
 import org.kie.workbench.common.stunner.core.rule.ext.impl.ConnectorParentsMatchHandler;
 import org.kie.workbench.common.stunner.core.util.HashUtil;
 
+import static org.kie.workbench.common.forms.adf.engine.shared.formGeneration.processing.fields.fieldInitializers.nestedForms.SubFormFieldInitializer.COLLAPSIBLE_CONTAINER;
+import static org.kie.workbench.common.forms.adf.engine.shared.formGeneration.processing.fields.fieldInitializers.nestedForms.SubFormFieldInitializer.FIELD_CONTAINER_PARAM;
+
 @Portable
 @Bindable
-@Definition(graphFactory = EdgeFactory.class, builder = SequenceFlow.SequenceFlowBuilder.class)
+@Definition(graphFactory = EdgeFactory.class)
 // *** Connection rules for sequence flows ****
 @CanConnect(startRole = "sequence_start", endRole = "sequence_end")
 @CanConnect(startRole = "choreography_sequence_start", endRole = "choreography_sequence_end")
@@ -59,6 +62,10 @@ import org.kie.workbench.common.stunner.core.util.HashUtil;
 @EdgeOccurrences(role = "messageflow_start", type = EdgeOccurrences.EdgeType.OUTGOING, max = 1)
 // A single outgoing sequence flows for event types that can be docked (boundary) such as Intermediate Timer Event
 @EdgeOccurrences(role = "IntermediateEventOnActivityBoundary", type = EdgeOccurrences.EdgeType.OUTGOING, max = 1)
+@EdgeOccurrences(role = "IntermediateEventCatching", type = EdgeOccurrences.EdgeType.INCOMING, max = 1)
+@EdgeOccurrences(role = "IntermediateEventThrowing", type = EdgeOccurrences.EdgeType.INCOMING, max = 1)
+@EdgeOccurrences(role = "IntermediateEventThrowing", type = EdgeOccurrences.EdgeType.OUTGOING, min = 1)
+@EdgeOccurrences(role = "IntermediateEventThrowing", type = EdgeOccurrences.EdgeType.OUTGOING, max = 1)
 // Sequence flows cannot exceed bounds when any of the nodes are in an embedded subprocess context.
 @RuleExtension(handler = ConnectorParentsMatchHandler.class,
         typeArguments = {EmbeddedSubprocess.class},
@@ -66,7 +73,8 @@ import org.kie.workbench.common.stunner.core.util.HashUtil;
                 "Both source and target nodes must be in same parent process."})
 @FormDefinition(
         startElement = "general",
-        policy = FieldPolicy.ONLY_MARKED
+        policy = FieldPolicy.ONLY_MARKED,
+        defaultFieldSettings = {@FieldParam(name = FIELD_CONTAINER_PARAM, value = COLLAPSIBLE_CONTAINER)}
 )
 public class SequenceFlow extends BaseConnector {
 
@@ -77,21 +85,13 @@ public class SequenceFlow extends BaseConnector {
     @Valid
     protected SequenceFlowExecutionSet executionSet;
 
-    @NonPortable
-    public static class SequenceFlowBuilder extends BaseConnectorBuilder<SequenceFlow> {
-
-        @Override
-        public SequenceFlow build() {
-            return new SequenceFlow(new BPMNGeneralSet(),
-                                    new SequenceFlowExecutionSet(),
-                                    new BackgroundSet(COLOR,
-                                                      BORDER_COLOR,
-                                                      BORDER_SIZE),
-                                    new FontSet());
-        }
-    }
-
     public SequenceFlow() {
+        this(new BPMNGeneralSet(),
+             new SequenceFlowExecutionSet(),
+             new BackgroundSet(COLOR,
+                               BORDER_COLOR,
+                               BORDER_SIZE),
+             new FontSet());
     }
 
     public SequenceFlow(final @MapsTo("general") BPMNGeneralSet general,
