@@ -17,6 +17,7 @@
 package org.kie.workbench.common.stunner.bpmn.definition.property.task;
 
 import java.util.Set;
+
 import javax.validation.ConstraintViolation;
 import javax.validation.Validation;
 import javax.validation.Validator;
@@ -27,7 +28,8 @@ import org.junit.Test;
 import org.kie.workbench.common.stunner.bpmn.definition.UserTask;
 import org.kie.workbench.common.stunner.bpmn.definition.property.general.Name;
 
-import static org.junit.Assert.*;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertTrue;
 
 public class UserTaskTest {
 
@@ -92,7 +94,7 @@ public class UserTaskTest {
 
     @Test
     public void testUserTaskTaskNameValid() {
-        UserTask userTask = new UserTask.UserTaskBuilder().build();
+        UserTask userTask = new UserTask();
         userTask.getExecutionSet().setTaskName(new TaskName(TASK_NAME_VALID));
         Set<ConstraintViolation<UserTask>> violations = this.validator.validate(userTask);
         assertTrue(violations.isEmpty());
@@ -100,7 +102,7 @@ public class UserTaskTest {
 
     @Test
     public void testUserTaskTaskNameInvalid() {
-        UserTask userTask = new UserTask.UserTaskBuilder().build();
+        UserTask userTask = new UserTask();
         userTask.getExecutionSet().setTaskName(new TaskName(TASK_NAME_INVALID));
         Set<ConstraintViolation<UserTask>> violations = this.validator.validate(userTask);
         assertEquals(1,
@@ -109,7 +111,7 @@ public class UserTaskTest {
 
     @Test
     public void testUserTaskNameValid() {
-        UserTask userTask = new UserTask.UserTaskBuilder().build();
+        UserTask userTask = new UserTask();
         userTask.getGeneral().setName(new Name(TASK_NAME_VALID));
         Set<ConstraintViolation<UserTask>> violations = this.validator.validate(userTask);
         assertTrue(violations.isEmpty());
@@ -117,7 +119,7 @@ public class UserTaskTest {
 
     @Test
     public void testUserTaskNameEmpty() {
-        UserTask userTask = new UserTask.UserTaskBuilder().build();
+        UserTask userTask = new UserTask();
         userTask.getGeneral().setName(new Name(""));
         Set<ConstraintViolation<UserTask>> violations = this.validator.validate(userTask);
         assertTrue(violations.isEmpty());
