@@ -17,6 +17,7 @@
 package org.kie.workbench.common.stunner.bpmn.client.forms.fields.variablesEditor;
 
 import java.io.IOException;
+
 import javax.annotation.PostConstruct;
 import javax.enterprise.event.Event;
 import javax.inject.Inject;
@@ -232,6 +233,13 @@ public class VariableListItemWidgetViewImpl implements VariableListItemWidgetVie
         }
     }
 
+    @Override
+    public void setReadOnly(final boolean readOnly) {
+        deleteButton.setEnabled(!readOnly);
+        dataTypeComboBox.setReadOnly(readOnly);
+        name.setEnabled(!readOnly);
+    }
+
     @Override
     public boolean isDuplicateName(final String name) {
         return parentWidget.isDuplicateName(name);
