@@ -37,7 +37,6 @@ import org.kie.workbench.common.stunner.bpmn.definition.SequenceFlow;
 import org.kie.workbench.common.stunner.bpmn.definition.StartNoneEvent;
 import org.kie.workbench.common.stunner.bpmn.definition.StartSignalEvent;
 import org.kie.workbench.common.stunner.bpmn.definition.UserTask;
-import org.kie.workbench.common.stunner.bpmn.definition.property.general.BPMNGeneralSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.general.Name;
 import org.kie.workbench.common.stunner.bpmn.definition.property.general.TaskGeneralSet;
 import org.mockito.ArgumentCaptor;
@@ -51,6 +50,7 @@ import static org.mockito.Mockito.any;
 import static org.mockito.Mockito.anyBoolean;
 import static org.mockito.Mockito.anyString;
 import static org.mockito.Mockito.doCallRealMethod;
+import static org.mockito.Mockito.times;
 import static org.mockito.Mockito.verify;
 import static org.mockito.Mockito.when;
 
@@ -145,6 +145,7 @@ public class AssignmentsEditorWidgetTest extends AssignmentBaseTest {
         doCallRealMethod().when(widget).formatDataTypes(any(List.class));
         doCallRealMethod().when(widget).getTaskName();
         doCallRealMethod().when(widget).getDisallowedPropertyNames();
+        doCallRealMethod().when(widget).setReadOnly(anyBoolean());
         when(userTask.getGeneral()).thenReturn(taskGeneralSet);
         when(taskGeneralSet.getName()).thenReturn(taskName);
         when(taskName.getValue()).thenReturn(TASK_NAME);
@@ -407,5 +408,19 @@ public class AssignmentsEditorWidgetTest extends AssignmentBaseTest {
         assertEquals(false,
                      widget.isSingleOutputVar);
     }
+
+    @Test
+    public void testSetReadOnlyTrue() {
+        widget.setReadOnly(true);
+        verify(activityDataIOEditor,
+               times(1)).setReadOnly(true);
+    }
+
+    @Test
+    public void testSetReadOnlyFalse() {
+        widget.setReadOnly(false);
+        verify(activityDataIOEditor,
+               times(1)).setReadOnly(false);
+    }
 }
 
