@@ -16,32 +16,21 @@
 
 package org.kie.workbench.common.stunner.bpmn.project.client.editor;
 
-import java.util.function.Predicate;
 import java.util.logging.Level;
 
 import com.google.gwtmockito.GwtMockitoTestRunner;
-import org.guvnor.common.services.shared.metadata.model.Metadata;
-import org.jboss.errai.ioc.client.api.ManagedInstance;
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
 import org.kie.workbench.common.stunner.bpmn.project.client.resources.BPMNClientConstants;
 import org.kie.workbench.common.stunner.bpmn.project.client.type.BPMNDiagramResourceType;
 import org.kie.workbench.common.stunner.client.widgets.popups.PopupUtil;
-import org.kie.workbench.common.stunner.client.widgets.presenters.session.SessionPresenter;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
-import org.kie.workbench.common.stunner.core.client.i18n.ClientTranslationService;
 import org.kie.workbench.common.stunner.core.client.service.ServiceCallback;
 import org.kie.workbench.common.stunner.core.client.session.command.ClientSessionCommand;
-import org.kie.workbench.common.stunner.core.client.session.command.impl.ValidateSessionCommand;
-import org.kie.workbench.common.stunner.core.client.session.impl.AbstractClientFullSession;
-import org.kie.workbench.common.stunner.forms.client.session.command.GenerateDiagramFormsSessionCommand;
-import org.kie.workbench.common.stunner.forms.client.session.command.GenerateProcessFormsSessionCommand;
-import org.kie.workbench.common.stunner.forms.client.session.command.GenerateSelectedFormsSessionCommand;
 import org.kie.workbench.common.stunner.project.client.editor.AbstractProjectDiagramEditor;
 import org.kie.workbench.common.stunner.project.client.editor.AbstractProjectDiagramEditorTest;
-import org.kie.workbench.common.stunner.project.diagram.ProjectDiagram;
-import org.kie.workbench.common.widgets.metadata.client.widget.OverviewWidgetPresenter;
+import org.kie.workbench.common.stunner.project.client.editor.ProjectEditorMenuSessionItems;
 import org.mockito.ArgumentCaptor;
 import org.mockito.Mock;
 import org.uberfire.backend.vfs.ObservablePath;
@@ -71,40 +60,20 @@ public class BPMNDiagramEditorTest extends AbstractProjectDiagramEditorTest {
     private static final String MIGRATE_CONFIRM_ACTION = "MIGRATE_CONFIRM_ACTION";
     private static final String COMMIT_MESSAGE = "COMMIT_MESSAGE";
 
-    @Mock
-    private ManagedInstance<GenerateProcessFormsSessionCommand> generateProcessFormSessionCommands;
-    @Mock
-    private GenerateProcessFormsSessionCommand generateProcessFormsSessionCommand;
-    @Mock
-    private ManagedInstance<GenerateDiagramFormsSessionCommand> generateDiagramFormsSessionCommands;
-    @Mock
-    private GenerateDiagramFormsSessionCommand generateDiagramFormsSessionCommand;
-    @Mock
-    private ManagedInstance<GenerateSelectedFormsSessionCommand> generateSelectedFormsSessionCommands;
-    @Mock
-    private GenerateSelectedFormsSessionCommand generateSelectedFormsSessionCommand;
-    @Mock
-    private BPMNDiagramEditorMenuItemsBuilder bpmnDiagramEditorMenuItemsBuilder;
-    @Mock
-    private ClientTranslationService translationService;
     @Mock
     private EventSourceMock<BPMNMigrateDiagramEvent> migrateDiagramEvent;
+
     @Mock
     private PopupUtil popupUtil;
+
     @Mock
     private PlaceRequest currentPlace;
-    @Mock
-    private SessionPresenter sessionPresenter;
-    @Mock
-    private SessionPresenter.View sessionPresenterView;
-    @Mock
-    private AbstractClientFullSession clientFullSession;
+
     @Mock
     private AbstractCanvasHandler canvasHandler;
+
     @Mock
-    private ProjectDiagram diagram;
-    @Mock
-    private OverviewWidgetPresenter overviewWidget;
+    private BPMNProjectEditorMenuSessionItems bpmnMenuSessionItems;
 
     private ArgumentCaptor<Command> commandCaptor;
 
@@ -121,23 +90,14 @@ public class BPMNDiagramEditorTest extends AbstractProjectDiagramEditorTest {
     @Before
     @SuppressWarnings("unchecked")
     public void setUp() {
+        super.setUp();
         commandCaptor = ArgumentCaptor.forClass(Command.class);
         migrateDiagramEventCaptor = ArgumentCaptor.forClass(BPMNMigrateDiagramEvent.class);
         sessionCommandCallback = ArgumentCaptor.forClass(ClientSessionCommand.Callback.class);
         parameterizedCommandCaptor = ArgumentCaptor.forClass(ParameterizedCommand.class);
         serviceCallbackCaptor = ArgumentCaptor.forClass(ServiceCallback.class);
-
-        when(sessionPresenterFactory.newPresenterEditor()).thenReturn(sessionPresenter);
-        when(sessionPresenter.getInstance()).thenReturn(clientFullSession);
-        when(sessionPresenter.getView()).thenReturn(sessionPresenterView);
-        when(clientFullSession.getCanvasHandler()).thenReturn(canvasHandler);
         when(canvasHandler.getDiagram()).thenReturn(diagram);
 
-        when(generateDiagramFormsSessionCommands.get()).thenReturn(generateDiagramFormsSessionCommand);
-        when(generateProcessFormSessionCommands.get()).thenReturn(generateProcessFormsSessionCommand);
-        when(generateSelectedFormsSessionCommands.get()).thenReturn(generateSelectedFormsSessionCommand);
-        when(generateSelectedFormsSessionCommand.setElementAcceptor(any(Predicate.class))).thenReturn(generateSelectedFormsSessionCommand);
-
         when(translationService.getValue(BPMNClientConstants.EditorMigrateActionTitle)).thenReturn(MIGRATE_ACTION_TITLE);
         when(translationService.getValue(BPMNClientConstants.EditorMigrateActionWarning)).thenReturn(MIGRATE_ACTION_WARNING);
         when(translationService.getValue(BPMNClientConstants.EditorMigrateAction)).thenReturn(MIGRATE_ACTION);
@@ -146,9 +106,17 @@ public class BPMNDiagramEditorTest extends AbstractProjectDiagramEditorTest {
         super.setUp();
     }
 
+    @Override
+    protected ProjectEditorMenuSessionItems getMenuSessionItems() {
+        return bpmnMenuSessionItems;
+    }
+
     @Override
     protected BPMNDiagramResourceType mockResourceType() {
-        return mock(BPMNDiagramResourceType.class);
+        final BPMNDiagramResourceType resourceType = mock(BPMNDiagramResourceType.class);
+        when(resourceType.getSuffix()).thenReturn("bpmn");
+        when(resourceType.getShortName()).thenReturn("Business Process");
+        return resourceType;
     }
 
     @SuppressWarnings("unchecked")
@@ -161,30 +129,28 @@ public class BPMNDiagramEditorTest extends AbstractProjectDiagramEditorTest {
                                                   savePopUpPresenter,
                                                   (BPMNDiagramResourceType) getResourceType(),
                                                   clientProjectDiagramService,
-                                                  sessionManager,
-                                                  sessionPresenterFactory,
-                                                  sessionCommandFactory,
-                                                  projectMenuItemsBuilder,
+                                                  sessionEditorPresenters,
+                                                  sessionViewerPresenters,
+                                                  bpmnMenuSessionItems,
                                                   onDiagramFocusEvent,
                                                   onDiagramLostFocusEvent,
                                                   projectMessagesListener,
                                                   diagramClientErrorHandler,
-                                                  generateProcessFormSessionCommands,
-                                                  generateDiagramFormsSessionCommands,
-                                                  generateSelectedFormsSessionCommands,
-                                                  bpmnDiagramEditorMenuItemsBuilder,
                                                   translationService,
+                                                  projectDiagramResourceServiceCaller,
                                                   migrateDiagramEvent,
-                                                  popupUtil) {
+                                                  popupUtil,
+                                                  xmlEditorView) {
             {
-                super.fileMenuBuilder = BPMNDiagramEditorTest.this.fileMenuBuilder;
+                fileMenuBuilder = BPMNDiagramEditorTest.this.fileMenuBuilder;
                 workbenchContext = BPMNDiagramEditorTest.this.workbenchContext;
                 projectController = BPMNDiagramEditorTest.this.projectController;
                 versionRecordManager = BPMNDiagramEditorTest.this.versionRecordManager;
                 alertsButtonMenuItemBuilder = BPMNDiagramEditorTest.this.alertsButtonMenuItemBuilder;
                 place = BPMNDiagramEditorTest.this.currentPlace;
-                presenter = BPMNDiagramEditorTest.this.sessionPresenter;
+                kieView = BPMNDiagramEditorTest.this.kieView;
                 overviewWidget = BPMNDiagramEditorTest.this.overviewWidget;
+                notification = BPMNDiagramEditorTest.this.notification;
             }
 
             @Override
@@ -226,7 +192,6 @@ public class BPMNDiagramEditorTest extends AbstractProjectDiagramEditorTest {
         ObservablePath currentPath = mock(ObservablePath.class);
         when(versionRecordManager.getCurrentPath()).thenReturn(currentPath);
         doReturn(true).when(diagramEditor).isDirty(any(Integer.class));
-
         diagramEditor.onMigrate();
         verify(popupUtil,
                times(1)).showConfirmPopup(eq(MIGRATE_ACTION_TITLE),
@@ -237,38 +202,7 @@ public class BPMNDiagramEditorTest extends AbstractProjectDiagramEditorTest {
                                           eq(MIGRATE_CONFIRM_ACTION),
                                           commandCaptor.capture());
         commandCaptor.getValue().execute();
-
-        ValidateSessionCommand validateSessionCommand = sessionCommandFactory.newValidateCommand();
-        verify(validateSessionCommand,
-               times(1)).execute(sessionCommandCallback.capture());
-        sessionCommandCallback.getValue().onSuccess();
-
-        verify(savePopUpPresenter,
-               times(1)).show(eq(currentPath),
-                              parameterizedCommandCaptor.capture());
-        parameterizedCommandCaptor.getValue().execute(COMMIT_MESSAGE);
-
-        verify(clientProjectDiagramService,
-               times(1)).saveOrUpdate(eq(currentPath),
-                                      any(ProjectDiagram.class),
-                                      any(Metadata.class),
-                                      eq(COMMIT_MESSAGE),
-                                      serviceCallbackCaptor.capture());
-        serviceCallbackCaptor.getValue().onSuccess(diagram);
-        verify(migrateDiagramEvent,
-               times(1)).fire(migrateDiagramEventCaptor.capture());
-        assertEquals(currentPath,
-                     migrateDiagramEventCaptor.getValue().getSourcePath());
-        assertEquals(currentPlace,
-                     migrateDiagramEventCaptor.getValue().getSourcePlace());
-    }
-
-    @Test
-    @Override
-    public void testCloseEditor() {
-        super.testCloseEditor();
-        verify(generateDiagramFormsSessionCommand, times(1)).unbind();
-        verify(generateProcessFormsSessionCommand, times(1)).unbind();
-        verify(generateSelectedFormsSessionCommand, times(1)).unbind();
+        verify(diagramEditor,
+               times(1)).saveAndMigrate();
     }
 }
